<?php
/**
*
* acp_profile [Belarusian]
*
* @package language
* @version $Id: profile.php,v 1.26 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Custom profile fields
$lang = array_merge($lang, array(
	'ADDED_PROFILE_FIELD'	=> 'Дадатковае поле паспяхова дададзена ў профіль.',
	'ALPHA_ONLY'			=> 'Толькі літарна-лічбавыя',
	'ALPHA_SPACERS'			=> 'Толькі літарна-лічбавыя і падзельнікі',
	'ALWAYS_TODAY'			=> 'Заўсёды дзеючая дата',

	'BOOL_ENTRIES_EXPLAIN'	=> 'Увядзіце магчымыя варыянты',
	'BOOL_TYPE_EXPLAIN'		=> 'Выгляд варыянтаў выбару: сцяжкі або перамыкачы. Сцяжкі будуць адлюстраваныя толькі ў выпадку, калі яны пазначаныя для дадзенага карыстальніка. У гэтым выпадку будзе скарыстаная <strong>другая</strong> моўная опцыя. Перамыкачы будуць адлюстраваныя незалежна ад іх стану.',

	'CHANGED_PROFILE_FIELD'		=> 'Поле профіля паспяхова зменена.',
	'CHARS_ANY'					=> 'Любыя',
	'CHECKBOX'					=> 'Сцяжкі',
	'COLUMNS'					=> 'слупкоў',
	'CP_LANG_DEFAULT_VALUE'		=> 'Значэнне па змаўчанні',
	'CP_LANG_EXPLAIN'			=> 'Апісанне поля',
	'CP_LANG_EXPLAIN_EXPLAIN'	=> 'Падказка да поля, паказваемая карыстальніку',
	'CP_LANG_NAME'				=> 'Імя поля/загаловак, паказваемы карыстальніку',
	'CP_LANG_OPTIONS'			=> 'Варыянты',
	'CREATE_NEW_FIELD'			=> 'Дадаць новае поле',
	'CUSTOM_FIELDS_NOT_TRANSLATED'	=> 'Прынамсі адно дадатковае поле профіля пакуль не перакладзена. Увядзіце неабходныя дадзеныя, пяройдучы па спасылцы «Перавесці».',

	'DEFAULT_ISO_LANGUAGE'			=> 'Мова па змаўчанні [%s]',
	'DEFAULT_LANGUAGE_NOT_FILLED'	=> 'Для поля профіля не запоўненыя пераменныя мовы па змаўчанні.',
	'DEFAULT_VALUE'					=> 'Значэнне па змаўчанні',
	'DELETE_PROFILE_FIELD'			=> 'Выдаленне поля профіля',
	'DELETE_PROFILE_FIELD_CONFIRM'	=> 'Вы сапраўды жадаеце выдаліць гэтае поле?',
	'DISPLAY_AT_PROFILE'			=> 'У асабістым раздзеле',
	'DISPLAY_AT_PROFILE_EXPLAIN'	=> 'Карыстальнік можа змяніць значэнне поля ў асабістым раздзеле.',
	'DISPLAY_AT_REGISTER'			=> 'У форме рэгістрацыі',
	'DISPLAY_AT_REGISTER_EXPLAIN'	=> 'Калі ўключана, поле можна запоўніць пры рэгістрацыі і змяніць у асабістым раздзеле.',
	'DISPLAY_ON_VT'					=> 'На старонках тэм',
	'DISPLAY_ON_VT_EXPLAIN'			=> 'Пры ўключэнні гэтай опцыі поле будзе адлюстроўвацца на старонках тэм пад аватарам карыстальнікаў.',
	'DISPLAY_PROFILE_FIELD'			=> 'Адлюстроўваць поле',
	'DISPLAY_PROFILE_FIELD_EXPLAIN'	=> 'Поле профіля будзе паказана там, дзе гэта дазволена ў наладах нагрузкі на сервер. Калі ўсталявана значэнне «Не», дадзенае поле будзе ўтоена пры праглядзе тэм, профіляў, спісу карыстальнікаў.',
	'DROPDOWN_ENTRIES_EXPLAIN'		=> 'Увядзіце варыянты адказу, па адным адказу на радок',

	'EDIT_DROPDOWN_LANG_EXPLAIN'	=> 'Улічыце, што вы можаце змяняць тэкст варыянтаў выбару і дадаваць новыя варыянты ў канец спісу. Не рэкамендуецца дадаваць новыя варыянты паміж наяўнымі, гэта можа прывесці да таму, што ў профілях карыстальнікаў апынуцца іншыя варыянты выбару. Гэта таксама можа адбыцца, калі вы выдаліце варыянты з сярэдзіны спісу. Выдаленне варыянту з канца спісу прывядзе да таго, у карыстальнікаў, абралых у профілі гэты варыянт, ён зменіцца на варыянт па змаўчанні.',
	'EMPTY_FIELD_IDENT'				=> 'Вы не ўвялі ідэнтыфікатар поля',
	'EMPTY_USER_FIELD_NAME'			=> 'Увядзіце імя поля/загаловак',
	'ENTRIES'						=> 'Значэнні',
	'EVERYTHING_OK'					=> 'Усё ў парадку',

	'FIELD_BOOL'				=> 'Лагічнае поле (Так ці не)',
	'FIELD_DATE'				=> 'Дата',
	'FIELD_DESCRIPTION'			=> 'Апісанне поля',
	'FIELD_DESCRIPTION_EXPLAIN'	=> 'Падказка да поля, паказваемая карыстальніку',
	'FIELD_DROPDOWN'			=> 'Які расчыняецца спіс',
	'FIELD_IDENT'				=> 'Ідэнтыфікатар поля',
	'FIELD_IDENT_ALREADY_EXIST'	=> 'Поле з такім ідэнтыфікатарам ужо існуе. Увядзіце іншы ідэнтыфікатар.',
	'FIELD_IDENT_EXPLAIN'		=> 'Назва поля для яго пазначэння ў базе дадзеных і файлах шаблонаў.',
	'FIELD_INT'					=> 'Лік',
	'FIELD_LENGTH'				=> 'Памер поля ўводу',
	'FIELD_NOT_FOUND'			=> 'Поле не знойдзена.',
	'FIELD_STRING'				=> 'Аднарадковае тэкставае поле',
	'FIELD_TEXT'				=> 'Шматрадковае тэкставае поле',
	'FIELD_TYPE'				=> 'Тып поля',
	'FIELD_TYPE_EXPLAIN'		=> 'Вы не зможаце змяняць тып поля.',
	'FIELD_VALIDATION'			=> 'Дапушчальныя знакі',
	'FIRST_OPTION'				=> 'Першы варыянт',

	'HIDE_PROFILE_FIELD'			=> 'Утоенае поле',
	'HIDE_PROFILE_FIELD_EXPLAIN'	=> 'Толькі адміністратары і мадэратары змогуць бачыць і змяняць гэтае поле. Калі ўключана, то поле будзе адлюстроўвацца толькі ў профілях карыстальнікаў.',

	'INVALID_CHARS_FIELD_IDENT'	=> 'Ідэнтыфікатар поля можа ўтрымоўваць толькі лацінскія малой літары і _ (знак ніжняга падкрэслення)',
	'INVALID_FIELD_IDENT_LEN'	=> 'Ідэнтыфікатар поля можа быць даўжынёй не больш 17 знакаў',
	'ISO_LANGUAGE'				=> 'Мова [%s]',

	'LANG_SPECIFIC_OPTIONS'		=> 'Налады для мовы [<strong>%s</strong>]',

	'MAX_FIELD_CHARS'		=> 'Максімальны лік знакаў',
	'MAX_FIELD_NUMBER'		=> 'Максімальна дапушчальны лік',
	'MIN_FIELD_CHARS'		=> 'Мінімальны лік знакаў',
	'MIN_FIELD_NUMBER'		=> 'Мінімальна дапушчальны лік',

	'NO_FIELD_ENTRIES'			=> 'Не зададзеныя магчымыя варыянты выбару',
	'NO_FIELD_ID'				=> 'Не паказаны ідэнтыфікатар поля.',
	'NO_FIELD_TYPE'				=> 'Не паказаны тып поля.',
	'NO_VALUE_OPTION'			=> 'Нязначны варыянт',
	'NO_VALUE_OPTION_EXPLAIN'	=> 'Калі поле абавязкова да запаўнення і вылучаны гэты варыянт, карыстальніку выводзіцца паведамленне аб памылцы',
	'NUMBERS_ONLY'				=> 'Толькі лічбы (0-9)',

	'PROFILE_BASIC_OPTIONS'		=> 'Асноўныя налады',
	'PROFILE_FIELD_ACTIVATED'	=> 'Поле профіля паспяхова ўключана.',
	'PROFILE_FIELD_DEACTIVATED'	=> 'Поле профіля паспяхова адключана.',
	'PROFILE_LANG_OPTIONS'		=> 'Моўныя параметры',
	'PROFILE_TYPE_OPTIONS'		=> 'Налады выгляду поля',

	'RADIO_BUTTONS'				=> 'Перамыкачы',
	'REMOVED_PROFILE_FIELD'		=> 'Поле профіля паспяхова выдаленае.',
	'REQUIRED_FIELD'			=> 'Абавязковае поле',
	'REQUIRED_FIELD_EXPLAIN'	=> 'Карыстальніку неабходна запоўніць або выставіць значэнне поля. Поле даступна пры рэгістрацыі і ў асабістым раздзеле.',
	'ROWS'						=> 'радкоў',

	'SAVE'							=> 'Захаваць',
	'SECOND_OPTION'					=> 'Другі варыянт',
	'SHOW_NOVALUE_FIELD'			=> 'Адлюстроўваць поле без значэння',
	'SHOW_NOVALUE_FIELD_EXPLAIN'	=> 'Усталёўвае, ці будзе адлюстравана поле профілю ў выпадку, калі абраны варыянт без значэння для неабавязковага поля, альбо не было абрана значэнне для абавязковага поля.',
	'STEP_1_EXPLAIN_CREATE'			=> 'Тут вы можаце ўвесці асноўныя параметры новага поля профіля. Гэтая інфармацыя патрэбна для другога кроку, на якім вы зможаце ўсталяваць пакінутыя налады, зрабіць папярэдні прагляд будучыні палі і занесці неабходныя выпраўленні, калі неабходна.',
	'STEP_1_EXPLAIN_EDIT'			=> 'Тут вы можаце змяніць асноўныя параметры новага поля профіля. На другім кроку адпаведныя значэнні будуць пералічаныя і вы зможаце праглядзець і пратэставаць змененыя налады.',
	'STEP_1_TITLE_CREATE'			=> 'Даданне поля ў профіль',
	'STEP_1_TITLE_EDIT'				=> 'Рэдагаванне поля профіля',
	'STEP_2_EXPLAIN_CREATE'			=> 'Тут вы можаце задаць агульныя налады будучыні палі. Затым можна будзе паглядзець, як будзе выглядаць для карыстальніка створанае поле. Пайграйце з наладамі, пакуль не будзеце здаволеныя тым, як працуе поле.',
	'STEP_2_EXPLAIN_EDIT'			=> 'Тут вы можаце змяніць агульныя налады будучыні палі. <br /><strong>Улічыце, што гэтыя змены не паўплываюць на ўжо наяўныя палі профіля, запоўненыя карыстальнікамі.</strong>',
	'STEP_2_TITLE_CREATE'			=> 'Налады выгляду поля',
	'STEP_2_TITLE_EDIT'				=> 'Налады выгляду поля',
	'STEP_3_EXPLAIN_CREATE'			=> 'Бо на канферэнцыі ўсталявана больш аднаго мовы, неабходна ўвесці дадзеныя для астатніх моў. Назва поля, падказка і пачатковае значэнне будуць адлюстроўвацца на мове па змаўчанні. Моўныя пераменныя іншых моў можна будзе ўвесці пазней.',
	'STEP_3_EXPLAIN_EDIT'			=> 'Бо на канферэнцыі ўсталявана больш аднаго мовы, вы можаце змяніць або дадаць дадзеныя для астатніх моў. Назва поля, падказка і пачатковае значэнне будуць адлюстроўвацца на мове па змаўчанні.',
	'STEP_3_TITLE_CREATE'			=> 'Моўныя пераменныя іншых моў',
	'STEP_3_TITLE_EDIT'				=> 'Моўныя азначэнні',
	'STRING_DEFAULT_VALUE_EXPLAIN'	=> 'Увядзіце радок, па змаўчанні якая адлюстроўваецца ў поле. Не ўводзіце радок, калі жадаеце пакінуць поле пустым.',

	'TEXT_DEFAULT_VALUE_EXPLAIN'	=> 'Увядзіце тэкст, па змаўчанні які адлюстроўваецца ў поле. Не ўводзіце тэкст, калі жадаеце пакінуць поле пустым.',
	'TRANSLATE'						=> 'Перавесці',

	'USER_FIELD_NAME'	=> 'Імя поля/загаловак, паказваемы карыстальніку',

	'VISIBILITY_OPTION'				=> 'Бачнасць поля',
));

?>