<?php
/**
*
* acp_search [Belarusian]
*
* @package language
* @version $Id: search.php,v 1.21 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_SEARCH_INDEX_EXPLAIN'				=> 'Тут вы можаце кіраваць індэксамі пошукавага механізму. Паколькі звычайна выкарыстоўваецца толькі адзін механізм, неабходна выдаляць усе нявыкарыстаныя індэксы. Пасля змены якія-небудзь налад пошуку (напрыклад, мінімальнай максімальнай колькасці знакаў) мае сэнс паўторна стварыць пошукавыя індэксы для таго, каб яны адлюстроўвалі вырабленыя змены.',
	'ACP_SEARCH_SETTINGS_EXPLAIN'			=> 'Тут вы можаце паказаць пошукавы механізм, які будзе выкарыстоўвацца для індэксацыі паведамленняў і ажыццяўленні пошуку. Таксама вы можаце ўсталёўваць розныя налады, якія могуць уплываць на колькасць рэсурсаў, патрабаваных для апрацоўкі пошукавых запытаў. Некаторыя з гэтых налад аднолькавыя для ўсіх пошукавых механізмаў.',

	'COMMON_WORD_THRESHOLD'					=> 'Парог агульных слоў',
	'COMMON_WORD_THRESHOLD_EXPLAIN'			=> 'Словы, якія змяшчаюцца ў асноўнай масе ўсіх паведамленняў, будуць лічыцца агульнымі. Агульныя словы ігнаруюцца ў пошукавых запытах. Увядзіце 0 для адключэння гэтай функцыі. Функцыя працуе толькі пры наяўнасці больш 100 паведамленняў.',
	'CONFIRM_SEARCH_BACKEND'				=> 'Вы сапраўды жадаеце пераключыцца на іншы пошукавы механізм? Пасля пераключэння трэба будзе стварыць пошукавыя індэксы для выкарыстання новага пошукавага механізму. Калі вы не плануеце перамыкацца зваротна на стары пошукавы механізм, то можаце выдаліць пошукавыя індэксы ад яго для вызвалення сістэмных рэсурсаў.',
	'CONTINUE_DELETING_INDEX'				=> 'Працягнуць папярэдні працэс выдалення індэксаў',
	'CONTINUE_DELETING_INDEX_EXPLAIN'		=> 'Раней быў запушчаны працэс выдалення пошукавых індэксаў. Неабходна дачакацца завяршэння гэтага працэсу для атрымання доступу да старонкі пошукавых індэксаў або адмяніць яго.',
	'CONTINUE_INDEXING'						=> 'Працягнуць папярэдні працэс індэксавання',
	'CONTINUE_INDEXING_EXPLAIN'				=> 'Раней быў запушчаны працэс індэксацыі. Неабходна дачакацца завяршэння гэтага працэсу для атрымання доступу да старонкі пошукавых індэксаў або адмяніць яго.',
	'CREATE_INDEX'							=> 'Стварыць індэксы',

	'DELETE_INDEX'							=> 'Выдаліць індэксы',
	'DELETING_INDEX_IN_PROGRESS'			=> 'Выдаленне пошукавых індэксаў…',
	'DELETING_INDEX_IN_PROGRESS_EXPLAIN'	=> 'Ідзе выдаленне пошукавых індэксаў. Гэты працэс можа заняць некалькі хвілін.',

	'FULLTEXT_MYSQL_INCOMPATIBLE_VERSION'	=> 'Механізм паўнатэкставага пошуку MySQL можа выкарыстоўвацца толькі на MySQL4 і вышэй.',
	'FULLTEXT_MYSQL_NOT_SUPPORTED'			=> 'Паўнатэкставыя індэксы MySQL могуць выкарыстоўвацца толькі з табліцамі MyISAM ці InnoDB.',
	'FULLTEXT_MYSQL_TOTAL_POSTS'			=> 'Агульная колькасць індэксаваных паведамленняў',
	'FULLTEXT_MYSQL_MBSTRING'				=> 'Падтрымка нелацінскіх знакаў UTF-8, выкарыстоўвалых mbstring:',
	'FULLTEXT_MYSQL_PCRE'					=> 'Падтрымка нелацінскіх знакаў UTF-8, выкарыстоўвалых PCRE:',
	'FULLTEXT_MYSQL_MBSTRING_EXPLAIN'		=> 'Калі PCRE не мае ўласцівасцяў знакаў юнікода, то пошукавы механізм паспрабуе выкарыстаць механізм рэгулярных выразаў mbstring.',
	'FULLTEXT_MYSQL_PCRE_EXPLAIN'			=> 'Для гэтага пошукавага механізму патрабуюцца ўласцівасці знакаў юнікод PCRE, даступныя толькі на PHP 4.4, 5.1 і вышэй, калі вы жадаеце шукаць нелацінскія знакі.',
	'FULLTEXT_MYSQL_MIN_SEARCH_CHARS_EXPLAIN'	=> 'Словы з, па меншай меры, гэтай колькасцю сімвалаў будуць праіндэксаваныя для пошуку. Вы або ваш сервер можа змяніць гэтую наладу шляхам змены канфігурацыі MySQL.',
	'FULLTEXT_MYSQL_MAX_SEARCH_CHARS_EXPLAIN'	=> 'Словы з не больш, чым гэта, колькасцю сімвалаў будуць праіндэксаваныя для пошуку. Вы або ваш сервер можа змяніць гэтую наладу шляхам змены канфігурацыі MySQL.',

	'GENERAL_SEARCH_SETTINGS'				=> 'Агульныя налады пошуку',
	'GO_TO_SEARCH_INDEX'					=> 'Перайсці на старонку пошукавых індэксаў',

	'INDEX_STATS'							=> 'Статыстыка індэксацыі',
	'INDEXING_IN_PROGRESS'					=> 'Ідзе індэксацыя…',
	'INDEXING_IN_PROGRESS_EXPLAIN'			=> 'Ідзе індэксацыя ўсіх наяўных паведамленняў. Гэты працэс можа заняць ад некалькіх хвілін да некалькіх гадзін у залежнасці ад аб\'ёму дадзеных.',

	'LIMIT_SEARCH_LOAD'						=> 'Абмежаванне пошуку пры загрузцы сістэмы',
	'LIMIT_SEARCH_LOAD_EXPLAIN'				=> 'Калі загрузка сістэмы на працягу адной хвіліны перавышае гэтае значэнне, то пошукавая старонка будзе недаступная. Значэнне 1.0 эквівалентна стоадсоткаваму выкарыстанню аднаго працэсара. Гэтая опцыя функцыянуе толькі на UNIX-падобных серверах.',

	'MAX_SEARCH_CHARS'						=> 'Максімум знакаў для індэксацыі',
	'MAX_SEARCH_CHARS_EXPLAIN'				=> 'Словы з меншым лікам знакаў будуць праіндэксаваныя і даступныя для пошуку.',
	'MAX_NUM_SEARCH_KEYWORDS'				=> 'Максімальная колькасць слоў для пошуку',
	'MAX_NUM_SEARCH_KEYWORDS_EXPLAIN'		=> 'Максімальная колькасць слоў, якія карыстальнік можа шукаць адначасова. Усталюеце 0 для здымання абмежаванняў.',
	'MIN_SEARCH_CHARS'						=> 'Мінімум знакаў для індэксацыі',
	'MIN_SEARCH_CHARS_EXPLAIN'				=> 'Словы з вялікім лікам знакаў будуць праіндэксаваныя і даступныя для пошуку.',
	'MIN_SEARCH_AUTHOR_CHARS'				=> 'Мінімальны лік знакаў у імёнах',
	'MIN_SEARCH_AUTHOR_CHARS_EXPLAIN'		=> 'Карыстальнікі павінны будуць увесці не менш паказанай колькасці знакаў пры ажыццяўленні пошуку аўтара па масцы. Калі імя аўтара карацей паказанага значэння, то можна здзяйсняць пошук па поўным імі аўтара.',

	'PROGRESS_BAR'							=> 'Індыкатар выканання',

	'SEARCH_GUEST_INTERVAL'					=> 'Інтэрвал паміж запытамі для госцяў',
	'SEARCH_GUEST_INTERVAL_EXPLAIN'			=> 'Час у секундах, якое госць павінен вычакаць перад выкананнем наступнага пошукавага запыту. Калі пошукам карыстаецца адзін госць, то ўсё астатнія ў гэты час чакаюць паказаны тут час.',
	'SEARCH_INDEX_CREATE_REDIRECT'			=> 'Усё паведамленні да паведамлення пад нумарам %1$d паспяхова праіндэксаваныя, з якіх у дзеючым кроку індэксацыі праіндэксавана %2$d паведамленняў.<br />Дзеючая хуткасць індэксацыі — прыкладна %3$.1f паведамленняў у секунду.<br />Ідзе індэксацыя…',
	'SEARCH_INDEX_DELETE_REDIRECT'			=> 'Усё паведамленні да паведамлення пад нумарам %1$d паспяхова выдаленыя з пошукавых індэксаў.<br />Ідзе выдаленне пошукавых індэксаў…',
	'SEARCH_INDEX_CREATED'					=> 'Усё паведамленні ў базе дадзеных паспяхова праіндэксаваныя.',
	'SEARCH_INDEX_REMOVED'					=> 'Пошукавыя індэксы паспяхова выдаленыя.',
	'SEARCH_INTERVAL'						=> 'Інтэрвал паміж пошукавымі запытамі',
	'SEARCH_INTERVAL_EXPLAIN'				=> 'Час у секундах, якое карыстальнік павінен вычакаць перад выкананнем наступнага пошукавага запыту. Гэты інтэрвал правяраецца для кожнага карыстальніка.',
	'SEARCH_STORE_RESULTS'					=> 'Кэшаванне вынікаў пошуку',
	'SEARCH_STORE_RESULTS_EXPLAIN'			=> 'Працягласць кэшавання вынікаў пошуку (у секундах). Увядзіце 0 для адключэння кэшавання вынікаў.',
	'SEARCH_TYPE'							=> 'Пошукавы механізм',
	'SEARCH_TYPE_EXPLAIN'					=> 'phpBB дазваляе вылучыць механізм для ажыццяўлення пошуку ў паведамленнях. Па змаўчанні выкарыстоўваецца ўбудаваны паўнатэкставы пошукавы механізм phpBB.',
	'SWITCHED_SEARCH_BACKEND'				=> 'Вы пераключыліся на іншы пошукавы механізм. Упэўніцеся, што маюцца індэксы для гэтага пошукавага механізму, і, у выпадку неабходнасці, стварыце іх.',

	'TOTAL_WORDS'							=> 'Агульная колькасць індэксаваных слоў',
	'TOTAL_MATCHES'							=> 'Лік слоў, звязаных з паведамленнямі',

	'YES_SEARCH'							=> 'Уключыць пошукавыя магчымасці',
	'YES_SEARCH_EXPLAIN'					=> 'Уключэнне пошукавых магчымасцяў, уключаючы пошук карыстальнікаў.',
	'YES_SEARCH_UPDATE'						=> 'Уключыць паўнатэкставае абнаўленне',
	'YES_SEARCH_UPDATE_EXPLAIN'				=> 'Абнаўленне паўнатэкставых індэксаў пры адпраўцы паведамленняў. Опцыя не працуе, калі пошукавыя магчымасці адключаныя.',
));

?>
