<?php
/** 
*
* install [Belarusian]
*
* @package language
* @version $Id: install.php,v 1.131 2007/11/18 11:48:18 acydburn Exp $
* @copyright (c) 2005 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
   exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ADMIN_CONFIG'				=> 'Налады адміністратара',
	'ADMIN_PASSWORD'			=> 'Пароль адміністратара',
	'ADMIN_PASSWORD_CONFIRM'	=> 'Пацвердзіце пароль адміністратара',
	'ADMIN_PASSWORD_EXPLAIN'	=> 'Увядзіце пароль даўжынёй ад 6 да 30 знакаў.',
	'ADMIN_TEST'				=> 'Праверка налад адміністратара',
	'ADMIN_USERNAME'			=> 'Імя адміністратара',
	'ADMIN_USERNAME_EXPLAIN'	=> 'Увядзіце імя даўжынёй ад 3 да 20 знакаў.',
	'APP_MAGICK'				=> 'Падтрымка Imagemagick [ Укладанні ]',
	'AUTHOR_NOTES'				=> 'Нататкі аўтара<br />» %s',
	'AVAILABLE'					=> 'Даступна',
	'AVAILABLE_CONVERTORS'		=> 'Даступныя канвертары',

	'BEGIN_CONVERT'					=> 'Пачаць канвертаванне',
	'BLANK_PREFIX_FOUND'			=> 'Прагляд вашых табліц паказаў наяўнасць прыдатнай канферэнцыі без прэфікса табліц.',
	'BOARD_NOT_INSTALLED'			=> 'phpBB3 не ўсталяваны',
	'BOARD_NOT_INSTALLED_EXPLAIN'	=> 'Для працы адзінай сістэмы канвертавання патрабуецца ўсталяваная па змаўчанні версія phpBB3, калі ласка, <a href="%s">спачатку перайдзіце да ўсталёўкі phpBB3</a>.',
	'BACKUP_NOTICE'					=> 'Стварыце рэзервовую копію канферэнцыі на выпадак ўзнікнення праблем у працэсе абнаўлення.',

	'CATEGORY'					=> 'Катэгорыя',
	'CACHE_STORE'				=> 'Тып кэша',
	'CACHE_STORE_EXPLAIN'		=> 'Фізічнае размяшчэнне дадзеных кэша, пераважна файлавая сістэма.',
	'CAT_CONVERT'				=> 'Канвертаванне',
	'CAT_INSTALL'				=> 'Усталёўка',
	'CAT_OVERVIEW'				=> 'Агляд',
	'CAT_UPDATE'				=> 'Абнаўленне',
	'CHANGE'					=> 'Змяніць',
	'CHECK_TABLE_PREFIX'		=> 'Калі ласка, праверце правільнасць прэфікса табліц, і паспрабуйце зноўку.',
	'CLEAN_VERIFY'				=> 'Ачыстка і праверка канчатковай структуры',
	'CLEANING_USERNAMES'		=> 'Ачыстка імёнаў карыстальнікаў',
	'COLLIDING_CLEAN_USERNAME'	=> 'Вычышчанае імя <strong>%s</strong> адпавядае імёнам карыстальнікаў:',
	'COLLIDING_USERNAMES_FOUND'	=> 'На вашай старой канферэнцыі знойдзеныя канфліктуючыя імёны карыстальнікаў. Для завяршэння канвертавання, выдаліце або пераназавіце гэтых карыстальнікаў, так каб кожнаму вычышчанаму імю адпавядаў толькі адзін карыстальнік старой канферэнцыі.',
	'COLLIDING_USER'			=> '» ідэнтыфікатар карыстальніка: <strong>%d</strong> імя карыстальніка: <strong>%s</strong> (паведамленняў: %d)',
	'CONFIG_CONVERT'			=> 'Канвертаванне канфігурацыі',
	'CONFIG_FILE_UNABLE_WRITE'	=> 'Не атрымалася запісаць файл канфігурацыі. Іншыя спосабы стварэння гэтага файла паказаныя ніжэй.',
	'CONFIG_FILE_WRITTEN'		=> 'Файл канфігурацыі запісаны. Зараз вы можаце прыступіць да наступнага этапу ўсталёўкі.',
	'CONFIG_PHPBB_EMPTY'		=> 'Пераменная канфігурацыі phpBB3 для "%s" пустая.',
	'CONFIG_RETRY'				=> 'Паўтарыць',
	'CONTACT_EMAIL_CONFIRM'		=> 'Пацверджанне кантактнага адрасу email',
	'CONTINUE_CONVERT'			=> 'Працягнуць канвертаванне',
	'CONTINUE_CONVERT_BODY'		=> 'Выяўленая папярэдняя спроба канвертавання. Вы можаце пачаць новае канвертаванне або працягнуць папярэдняе',
	'CONTINUE_LAST'				=> 'Працягнуць заключныя аперацыі',
	'CONTINUE_OLD_CONVERSION'	=> 'Працягнуць раней пачатае канвертаванне',
	'CONVERT'					=> 'Канвертаваць',
	'CONVERT_COMPLETE'			=> 'Канвертаванне завершанае',
	'CONVERT_COMPLETE_EXPLAIN'	=> 'Вы паспяхова сканвертавалі вашу канферэнцыю ў фармат phpBB 3.0. Вы можаце <a href="../">увайсці на канферэнцыю</a>. Упэўніцеся, што ўсе налады паспяхова перанесеныя, перш чым запусціце канферэнцыю, выдаліўшы папку install. Падушыце, што дапаможную інфармацыю па выкарыстанні phpBB можна атрымаць у інтэрнэце, вывучыўшы <a href="https://www.phpbb.com/support/documentation/3.0/">дакументацыю</a>, а таксама на <a href="https://www.phpbb.com/phpBB/viewforum.php?f=46">форуме падтрымкі</a>.',
	'CONVERT_INTRO'				=> 'Вас прывітае ўніфікаваная сістэма канвертавання phpBB',
	'CONVERT_INTRO_BODY'		=> 'Тут вы маеце магчымасць імпартаваць дадзеныя з іншых (усталяваных) тыпаў канферэнцый. У спісе ніжэй утрымоўваюцца даступныя ў цяперашні час модулі для канвертавання. Калі ў ім адсутнічае канферэнцыя, якую вы жадалі бы канвертаваць, калі ласка, наведаеце наш вэбсайт, на якім могуць быць даступныя для запампоўкі дадатковыя модулі.',
	'CONVERT_NEW_CONVERSION'	=> 'Новае канвертаванне',
	'CONVERT_NOT_EXIST'			=> 'Паказаны канвертар не існуе.',
	'CONVERT_OPTIONS'			=> 'Налады',
	'CONVERT_SETTINGS_VERIFIED'	=> 'Праверка паказанай вамі інфармацыі завершаная. Каб пачаць канвертаванне, націсніце кнопку ніжэй.',
	'CONV_ERR_FATAL'					=> 'Крытычная памылка пры канвертаванні',

	'CONV_ERROR_ATTACH_FTP_DIR'			=> 'Загрузка ўкладанняў праз FTP на старым форуме была дазволеная. Калі ласка, адключыце гэтую функцыю і ўпэўніцеся ў правільнасці паказанай папкі для загрузкі, потым скапіюйце ўсе файлы ўкладанняў у гэтую новую папку, даступную праз вэб. Затым перазапусціце канвертар.',
	'CONV_ERROR_CONFIG_EMPTY'			=> 'Адсутнічае даступная інфармацыя аб канфігурацыі для канвертавання.',
	'CONV_ERROR_FORUM_ACCESS'			=> 'Не атрымалася атрымаць інфармацыю аб правах доступу.',
	'CONV_ERROR_GET_CATEGORIES'			=> 'Не атрымалася атрымаць інфармацыю аб катэгорыях.',
	'CONV_ERROR_GET_CONFIG'				=> 'Не атрымалася атрымаць інфармацыю аб канфігурацыі форумаў.',
	'CONV_ERROR_COULD_NOT_READ'			=> 'Не атрымалася атрымаць доступ/прачытаць "%s".',
	'CONV_ERROR_GROUP_ACCESS'			=> 'Не атрымалася атрымаць інфармацыю аб правах доступу для груп.',
	'CONV_ERROR_INCONSISTENT_GROUPS'	=> 'Выяўлена парушэнне цэласнасці табліцы груп у add_bots() - вам неабходна дадаць усе адмысловыя групы ўручную.',
	'CONV_ERROR_INSERT_BOT'				=> 'Не атрымалася дадаць бота ў табліцу карыстальнікаў.',
	'CONV_ERROR_INSERT_BOTGROUP'		=> 'Не атрымалася дадаць бота ў табліцу ботаў.',
	'CONV_ERROR_INSERT_USER_GROUP'		=> 'Не атрымалася дадаць карыстальніка ў табліцу user_group.',
	'CONV_ERROR_MESSAGE_PARSER'			=> 'Памылка апрацоўкі паведамлення',
	'CONV_ERROR_NO_AVATAR_PATH'			=> 'Заўвага для распрацоўніка: вы павінны паказаць $convertor[\'avatar_path\'] для выкарыстання %s.',
	'CONV_ERROR_NO_FORUM_PATH'			=> 'Не паказаны адносны шлях да зыходнай канферэнцыі.',
	'CONV_ERROR_NO_GALLERY_PATH'		=> 'Заўвага для распрацоўніка: вы павінны паказаць $convertor[\'avatar_gallery_path\'] для выкарыстання %s.',
	'CONV_ERROR_NO_GROUP'				=> 'Не атрымалася знайсці групу "%1$s" у %2$s.',
	'CONV_ERROR_NO_RANKS_PATH'			=> 'Заўвага для распрацоўніка: вы павінны паказаць $convertor[\'ranks_path\'] для выкарыстання %s.',
	'CONV_ERROR_NO_SMILIES_PATH'		=> 'Заўвага для распрацоўніка: вы павінны паказаць $convertor[\'smilies_path\'] для выкарыстання %s.',
	'CONV_ERROR_NO_UPLOAD_DIR'			=> 'Заўвага для распрацоўніка: вы павінны паказаць $convertor[\'upload_path\'] для выкарыстання %s.',
	'CONV_ERROR_PERM_SETTING'			=> 'Не атрымалася дадаць/абнавіць налады мае рацыю доступу.',
	'CONV_ERROR_PM_COUNT'				=> 'Не атрымалася адабраць колькасць асабістых паведамленняў у папцы.',
	'CONV_ERROR_REPLACE_CATEGORY'		=> 'Не атрымалася дадаць новы форум замест старой катэгорыі.',
	'CONV_ERROR_REPLACE_FORUM'			=> 'Не атрымалася дадаць новы форум замест старога форума.',
	'CONV_ERROR_USER_ACCESS'			=> 'Не атрымалася атрымаць дадзеныя аўтэнтыфікацыі карыстальніка.',
	'CONV_ERROR_WRONG_GROUP'			=> 'Выяўленая няправільная група "%1$s" у %2$s.',
	'CONV_OPTIONS_BODY'					=> 'На гэтай старонцы вам прапаноўваецца ўвесці дадзеныя, неабходныя для доступу да зыходнай канферэнцыі. Пакажыце інфармацыю аб базе дадзеных вашай старой канферэнцыі; канвертар не будзе ўносіць у яе ніякіх змен. Для забеспячэння паўнавартаснай канвертацыі зыходную канферэнцыю варта адключыць.',
	'CONV_SAVED_MESSAGES'				=> 'Захаваныя паведамленні',

	'COULD_NOT_COPY'			=> 'Не атрымалася скапіяваць файл <strong>%1$s</strong> у <strong>%2$s</strong><br /><br />Калі ласка, праверце, што папка для капіявання існуе і ў яе можа здзяйсняцца запіс.',
	'COULD_NOT_FIND_PATH'		=> 'Не атрымалася знайсці шлях да старога форума. Калі ласка, праверце ўсталёўкі і паспрабуйце зноўку.<br />» Шлях %s быў паказаны як зыходны.',

	'DBMS'						=> 'Тып базы дадзеных',
	'DB_CONFIG'					=> 'Канфігурацыя базы дадзеных (БД)',
	'DB_CONNECTION'				=> 'Падлучэнне да базы дадзеных',
	'DB_ERR_INSERT'				=> 'Памылка пры апрацоўцы запыту <code>INSERT</code>.',
	'DB_ERR_LAST'				=> 'Памылка пры апрацоўцы <var>query_last</var>.',
	'DB_ERR_QUERY_FIRST'		=> 'Памылка пры выкананні <var>query_first</var>.',
	'DB_ERR_QUERY_FIRST_TABLE'	=> 'Памылка пры выкананні <var>query_first</var>, %s ("%s").',
	'DB_ERR_SELECT'				=> 'Памылка пры апрацоўцы запыту <code>SELECT</code>.',
	'DB_HOST'					=> 'Імя сервера БД або DSN',
	'DB_HOST_EXPLAIN'			=> 'DSN - імя крыніцы дадзеных пры ўсталёўцы з выкарыстаннем ODBC. Для PostgreSQL выкарыстайце лакальнае падключэнне да лакальнага сервера праз UNIX сокет і 127.0.0.1 для падлучэння праз TCP. Для SQLite задайце поўны шлях да файла базы дадзеных.',
	'DB_NAME'					=> 'Назоў базы дадзеных',
	'DB_PASSWORD'				=> 'Пароль да БД',
	'DB_PORT'					=> 'Порт сервера БД',
	'DB_PORT_EXPLAIN'			=> 'Пакіньце поле пустым, калі сервер выкарыстае порт па змаўчанні.',
	'DB_UPDATE_NOT_SUPPORTED'	=> 'Нажаль, дадзены сцэнар не падтрымлівае абнаўленне з версій phpBB да «%1$s». Усталяваная вамі версія — «%2$s». Абнавіце папярэднюю версію перад выкананнем гэтага сцэнара. Дапамогу па гэтай праблеме можна знайсці на форумах падтрымкі на бачыне phpBB.com.',
	'DB_USERNAME'				=> 'Імя карыстальніка БД',
	'DB_TEST'					=> 'Тэставае падлучэнне',
	'DEFAULT_LANG'				=> 'Мова па змаўчанні',
	'DEFAULT_PREFIX_IS'			=> 'Канвертару не атрымалася знайсці табліцы phpBB3 з паказаным прэфіксам. Упэўніцеся, што вы ўвялі правільныя дадзеныя аб старой канферэнцыі. У табліц канферэнцыі %1$s прэфікс <strong>%2$s</strong>',
	'DEV_NO_TEST_FILE'			=> 'У канвертары не паказана значэнне пераменнай test_file. Калі вы карыстальнік канвертара, калі ласка, паведаміце аб гэтай памылцы яго аўтару, так як яна не павінна ўзнікаць. Калі вы аўтар канвертара, то вы павінны задаць імя наяўнага файла канвертоўнай канферэнцыі, для таго каб праверыць правільнасць шляху да яе.',
	'DIRECTORIES_AND_FILES'		=> 'Налада папак і файлаў',
	'DISABLE_KEYS'				=> 'Дэактывацыя ключоў',
	'DLL_FIREBIRD'				=> 'Firebird',
	'DLL_FTP'					=> 'Падтрымка выдаленага FTP [ Усталёўка ]',
	'DLL_GD'					=> 'Падтрымка графічнай бібліятэкі GD [ Візуальнае пацверджанне ]',
	'DLL_MBSTRING'				=> 'Падтрымка шматбайтавых знакаў',
	'DLL_MSSQL'					=> 'MSSQL Server 2000+',
	'DLL_MSSQL_ODBC'			=> 'MSSQL Server 2000+ праз ODBC',
	'DLL_MSSQLNATIVE'			=> 'MSSQL Server 2005+ [ Родны ]',
	'DLL_MYSQL'					=> 'MySQL',
	'DLL_MYSQLI'				=> 'MySQL з пашырэннем MySQLi',
	'DLL_ORACLE'				=> 'Oracle',
	'DLL_POSTGRES'				=> 'PostgreSQL',
	'DLL_SQLITE'				=> 'SQLite',
	'DLL_XML'					=> 'Падтрымка XML [ Jabber ]',
	'DLL_ZLIB'					=> 'Падтрымка zlib-кампрэсіі [ gz, .tar.gz, .zip ]',
	'DL_CONFIG'					=> 'Запампаваць файл канфігурацыі',
	'DL_CONFIG_EXPLAIN'			=> 'Вы можаце цалкам запампаваць файл config.php да сабе на кампутар. Затым вам будзе трэба ўручную запампаваць гэты файл у каранёвую папку phpBB 3.0, замяніўшы зыходны config.php. Падушыце, што файл павінен быць запампаваны на сервер у фармаце ASCII (калі вы не ведаеце як гэтага дабіцца, звернецеся да дакументацыі вашага FTP-кліента). Пасля таго, як запампуеце config.php, пстрыкніце «Гатова» для пераходу да наступнага кроку.',
	'DL_DOWNLOAD'				=> 'Запампаваць',
	'DONE'						=> 'Гатова',

	'ENABLE_KEYS'				=> 'Рэактывацыя ключоў. Гэтая аперацыя можа заняць некаторы час.',

	'FILES_OPTIONAL'			=> 'Неабавязковыя файлы і папкі',
	'FILES_OPTIONAL_EXPLAIN'	=> '<strong>Неабавязкова</strong> - файлы, папкі або правы доступу, не якія з\'яўляюцца абавязковымі. Сістэма ўсталёўкі прапануе розныя спосабы іх стварэння, калі яны не існуюць, або для іх няма мае рацыю на запіс. Тым не менш, іх наяўнасць паскорыць працэс усталёўкі.',
	'FILES_REQUIRED'			=> 'Файлы і папкі',
	'FILES_REQUIRED_EXPLAIN'	=> '<strong>Неабходна</strong> - для правільнай працы phpBB патрэбен доступ на чытанне або запіс вызначаных файлаў і папак. Калі вы бачыце надпіс «Не знойдзена», неабходна стварыць адпаведны файл або папку. Калі напісана «Няма мае рацыю на запіс», неабходна змяніць правы на файл або папку, каб дазволіць запіс у іх для phpBB.',
	'FILLING_TABLE'				=> 'Запаўненне табліцы <strong>%s</strong>',
	'FILLING_TABLES'			=> 'Запаўненне табліц',

	'FIREBIRD_DBMS_UPDATE_REQUIRED'		=> 'phpBB больш не падтрымлівае Firebird/Interbase да версіі 2.1. Перад працягам працэсу абнаўлення абновіце Firebird, прынамсі, да версіі 2.1.0.',

	'FINAL_STEP'				=> 'Заключны крок',
	'FORUM_ADDRESS'				=> 'Адрас канферэнцыі',
	'FORUM_ADDRESS_EXPLAIN'		=> 'URL старой канферэнцыі, напрыклад, <samp>http://www.example.com/phpBB2/</samp>. Калі вы запоўніце гэтае поле, то ва ўсіх паведамленнях, АП і подпісах гэты адрас будзе заменены на адрас новай канферэнцыі.',
	'FORUM_PATH'				=> 'Шлях да канферэнцыі',
	'FORUM_PATH_EXPLAIN'		=> '<strong>Адносны</strong> шлях да старой канферэнцыі ад <strong>каранёвай папкі ўсталяванага phpBB3</strong>.',
	'FOUND'						=> 'Знойдзена',
	'FTP_CONFIG'				=> 'Перанесці файл канфігурацыі па FTP',
	'FTP_CONFIG_EXPLAIN'		=> 'Выяўлена наяўнасць модуля FTP на серверы. Калі жадаеце, можна паспрабаваць усталяваць config.php з яго дапамогай. Вам будзе трэба ўвесці інфармацыю ў палі паказаныя ніжэй. Падушыце, што гэтае імя карыстальніка і пароль ставяцца да FTP вашага сервера! (калі вы іх не ведаеце, звернецеся за дапамогай да хосцера).',
	'FTP_PATH'					=> 'Шлях FTP',
	'FTP_PATH_EXPLAIN'			=> 'Шлях ад каранёвай папкі FTP да каранёвай папкі phpBB, напрыклад, <samp>htdocs/phpBB3/</samp>',
	'FTP_UPLOAD'				=> 'Запампаваць',

	'GPL'						=> 'General Public License',
	
	'INITIAL_CONFIG'			=> 'Базавая канфігурацыя',
	'INITIAL_CONFIG_EXPLAIN'	=> 'Праграма ўсталёўкі вызначыла, што phpBB можа працаваць на вашым серверы, зараз неабходна ўвесці вашы дадзеныя. Калі вы не ведаеце, як падлучыцца да вашай базы дадзеных, звяжыцеся з хосцерам (у першую чаргу) або звернецеся на форум тэхпадтрымкі phpBB. Пасля ўводу дадзеных дбайна праверце іх перад адпраўкай.',
	'INSTALL_CONGRATS'			=> 'Віншуем!',
	'INSTALL_CONGRATS_EXPLAIN'	=> '
		Вы паспяхова ўсталявалі phpBB %1$s. Зараз у вас ёсць два варыянту, як паступіць з толькі што ўсталяваным phpBB3:</p>
		<h2>Сканвертаваць наяўную канферэнцыю ў phpBB3</h2>
		<p>Адзіная сістэма канвертавання phpBB падтрымлівае канвертаванне з phpBB 2.0.x і іншых тыпаў канферэнцый у phpBB3. Калі ў вас ёсць канферэнцыя, якую вы жадаеце сканвертаваць, <a href="%2$s">перайдзіце ў сістэму канвертавання</a>.</p>
		<h2>Пачаць карыстацца phpBB3!</h2>
		<p>Націсніце на кнопку ніжэй, каб перайсці ў адміністратарскі раздзел. Надасце некаторы час вывучэнню даступных пунктаў меню і налад. Падушыце аб даступнай у інтэрнэце <a href="https://www.phpbb.com/support/documentation/3.0/">дакументацыі</a> і <a href="https://www.phpbb.com/community/viewforum.php?f=46">форуме тэхпадтрымкі</a> (на ангельскім) а таксама <a href="http://anderson.phpbbguru.net">Рускамоўным форуме перакладу Olympus</a>, за дадатковай інфармацыяй звернецеся да <a href="%3$s">README</a>.<br /><br /><strong>Выдаліце, перамесціце або пераназавіце папку install перш чым пачнеце карыстацца канферэнцыяй. У адваротным выпадку будзе даступны толькі адміністратарскі раздзел.</strong>',
	'INSTALL_INTRO'				=> 'Вас прывітае праграма ўсталёўкі phpBB',

	'INSTALL_INTRO_BODY'		=> 'Тут можна ўсталяваць phpBB3 на ваш сервер.</p><p>Для гэтага запатрабуецца інфармацыя аб базе дадзеных. Калі вы не ведаеце яе налад, звяжыцеся з вашым хосцерам. Вы не зможаце працягнуць усталёўку без гэтых дадзеных. Вам трэба шляхта:</p>

	<ul>
		<li>Тып базы дадзеных (БД) - той, якую вы будзеце выкарыстаць.</li>
		<li>Імя сервера БД або DSN - адрас сервера базы дадзеных.</li>
		<li>Порт сервера БД - порт сервера базы дадзеных (не трэба паказваць у большасці выпадкаў).</li>
		<li>Назоў базы дадзеных - імя базы дадзеных на серверы.</li>
		<li>Імя карыстальніка БД і Пароль да БД - дадзеныя для доступу да базы дадзеных.</li>
	</ul>

	<p><strong>Нататка:</strong> калі вылучыце SQLite, вам будзе трэба ўвесці поўны шлях да файла вашай базы дадзеных у поле "Імя сервера БД або DSN" і пакінуць пустымі палі імя карыстальніка і пароля. Па меркаваннях бяспекі, вам неабходна пераканацца, што гэты файл недаступны праз вэб.</p>

	<p>phpBB3 падтрымлівае наступныя тыпы баз дадзеных:</p>
	<ul>
		<li>MySQL 3.23 і вышэй (падтрымліваецца MySQLi)</li>
		<li>PostgreSQL 7.3+</li>
		<li>SQLite 2.8.2+</li>
		<li>Firebird 2.0+</li>
		<li>MS SQL Server 2000 і вышэй (напроста або праз ODBC)</li>
		<li>MS SQL Server 2005 і вышэй (родны)</li>
		<li>Oracle</li>
	</ul>
	
	<p>У спісе выбару тыпу базы дадзеных будуць адлюстроўвацца толькі тыя, якія падтрымлівае ваш сервер.',
	'INSTALL_INTRO_NEXT'		=> 'Каб пачаць усталёўку, націсніце кнопку ніжэй.',
	'INSTALL_LOGIN'				=> 'Увайсці',
	'INSTALL_NEXT'				=> 'Наступны крок',
	'INSTALL_NEXT_FAIL'			=> 'Частка тэстаў завяршылася няўдачай, вам неабходна выправіць гэтую праблему перш, чым вы пяройдзеце да наступнага кроку. У адваротным выпадку ўсталёўка канферэнцыі будзе няскончанай.',
	'INSTALL_NEXT_PASS'			=> 'Усе асноўныя тэсты пройдзеныя, вы можаце перайсці да наступнага кроку ўсталёўкі. У выпадку, калі вы змянілі якія-небудзь правы, модулі, і т.п. і жадаеце правесці тэсты яшчэ раз, націсніце кнопку "Пераправерыць".',
	'INSTALL_PANEL'				=> 'Усталёўка канферэнцыі',
	'INSTALL_SEND_CONFIG'		=> 'Нажаль, не атрымалася запісаць канфігурацыю phpBB напроста ў файл config.php. Гэта адбылося таму, што файл не існуе або адсутнічаюць правы на запіс. Ніжэй прадстаўлены спіс варыянтаў, якія дазваляюць завяршыць усталёўку config.php.',
	'INSTALL_START'				=> 'Пачаць усталёўку',
	'INSTALL_TEST'				=> 'Пераправерыць',
	'INST_ERR'					=> 'Памылка пры ўсталёўцы',
	'INST_ERR_DB_CONNECT'		=> 'Не атрымалася падлучыцца да базы дадзеных. Ніжэй паказаны тэкст паведамлення аб памылцы.',
	'INST_ERR_DB_FORUM_PATH'	=> 'Файл базы дадзеных находзіцца ў папцы форума. Неабходна перамясціць яго ў папку, недаступную праз вэб.',
	'INST_ERR_DB_INVALID_PREFIX'=> 'Паказаны няправільны прэфікс. Ён павінен пачынацца з літары і можа ўтрымліваць толькі літары, лікі і знакі падкрэслення.',
	'INST_ERR_DB_NO_ERROR'		=> 'Паведамленне аб памылцы адсутнічае.',
	'INST_ERR_DB_NO_MYSQLI'		=> 'Усталяваная на серверы версія MySQL несумяшчальная з вылучаным варыянтам «MySQL з пашырэннем MySQLi». Замест яго паспрабуйце вылучыць варыянт «MySQL».',
	'INST_ERR_DB_NO_SQLITE'		=> 'У вас усталяваная састарэлая версія пашырэння SQLite, яе неабходна абнавіць прынамсі да версіі 2.8.2.',
	'INST_ERR_DB_NO_ORACLE'		=> 'Для ўсталяванай на серверы версіі Oracle неабходна ўсталяваць значэнне параметру <var>NLS_CHARACTERSET</var> роўным <var>UTF8</var>. Альбо абновіце базу дадзеных да версіі 9.2 або вышэй, альбо зменіце значэнне параметру.',
	'INST_ERR_DB_NO_FIREBIRD'	=> 'Усталяваная на серверы версія Firebird больш старая, чым 2.0, калі ласка, абновіце базу дадзеных да новай версіі.',
	'INST_ERR_DB_NO_FIREBIRD_PS'=> 'Вылучаная база дадзеных Firebird мае памер старонкі меней 8192, памер старонкі павінен быць не меней 8192.',
	'INST_ERR_DB_NO_POSTGRES'	=> 'Вылучаная база дадзеных была створаная не з кадыроўкай <var>UNICODE</var> або <var>UTF8</var>. Паспрабуйце ўсталяваць канферэнцыю ў базу дадзеных з кадыроўкай <var>UNICODE</var> або <var>UTF8</var>.',
	'INST_ERR_DB_NO_NAME'		=> 'Не паказана назоў базы дадзеных.',
	'INST_ERR_EMAIL_INVALID'	=> 'Уведзены адрас email недапушчальны.',
	'INST_ERR_EMAIL_MISMATCH'	=> 'Уведзеныя адрасы email не супадаюць.',
	'INST_ERR_FATAL'			=> 'Крытычная памылка пры ўсталёўцы',
	'INST_ERR_FATAL_DB'			=> 'Адбылася крытычная памылка пры працы з базай дадзеных, усталёўка перарваная. Чыннікам магло быць адсутнасць мае рацыю на выкананне аперацый стварэння і даданні дадзеных <code>CREATE TABLES</code>, <code>INSERT</code> або аналагічных. Больш падрабязная інфармацыя можа быць прадстаўленая ніжэй. Калі ласка, перш звяжыцеся з вашым хосцерам або звернецеся на форумы падтрымкі phpBB за дадатковай дапамогай.',
	'INST_ERR_FTP_PATH'			=> 'Не атрымалася перайсці ў зададзеную папку, упэўніцеся ў правільнасці адноснага шляху.',
	'INST_ERR_FTP_LOGIN'		=> 'Не атрымалася ўвайсці на FTP-сервер, упэўніцеся ў правільнасці імя карыстальніка і пароля.',
	'INST_ERR_MISSING_DATA'		=> 'Вы павінны запоўніць усе палі з гэтага раздзелу.',
	'INST_ERR_NO_DB'			=> 'Не атрымалася загрузіць PHP-модуль для вылучанага тыпу базы дадзеных.',
	'INST_ERR_PASSWORD_MISMATCH'	=> 'Уведзеныя паролі не супадаюць.',
	'INST_ERR_PASSWORD_TOO_LONG'	=> 'Уведзены пароль занадта доўгі. Максімальная даўжыня 30 знакаў.',
	'INST_ERR_PASSWORD_TOO_SHORT'	=> 'Уведзены пароль занадта кароткі. Мінімальная даўжыня 6 знакаў.',
	'INST_ERR_PREFIX'			=> 'Табліцы з паказаным прэфіксам ужо існуюць, калі ласка, вылучыце іншы прэфікс.',
	'INST_ERR_PREFIX_INVALID'	=> 'Паказаны прэфікс табліц недапушчальны для вашай базы дадзеных. Вылучыце іншы прэфікс, без спецсімвалаў, тыпу злучка.',
	'INST_ERR_PREFIX_TOO_LONG'	=> 'Паказаны прэфікс табліц занадта доўгі. Максімальная даўжыня ў знаках: %d.',
	'INST_ERR_USER_TOO_LONG'	=> 'Уведзенае імя карыстальніка занадта доўгае. Максімальная даўжыня 20 знакаў.',
	'INST_ERR_USER_TOO_SHORT'	=> 'Уведзенае імя карыстальніка занадта кароткае. Мінімальная даўжыня 3 знака.',
	'INVALID_PRIMARY_KEY'		=> 'Недапушчальны першасны ключ: %s',

	'LONG_SCRIPT_EXECUTION'		=> 'Выкананне можа заняць некаторы час... Калі ласка, не спыняйце працэс.',

	// mbstring
	'MBSTRING_CHECK'						=> 'Праверка пашырэння <samp>mbstring</samp>',
	'MBSTRING_CHECK_EXPLAIN'				=> '<strong>Неабходна</strong> - <samp>mbstring</samp> - пашырэнне, якое забяспечвае працу шматбайтавых радковых функцый. Вызначаныя магчымасці mbstring несумяшчальныя з phpBB і павінны быць адключаныя.',
	'MBSTRING_FUNC_OVERLOAD'				=> 'Перагрузка функцыі',
	'MBSTRING_FUNC_OVERLOAD_EXPLAIN'		=> 'Значэнне <var>mbstring.func_overload</var> павінна быць усталявана роўным 0 альбо 4.',
	'MBSTRING_ENCODING_TRANSLATION'			=> 'Празрыстае кадаванне знакаў',
	'MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> 'Значэнне <var>mbstring.encoding_translation</var> павінна быць усталявана роўным 0.',
	'MBSTRING_HTTP_INPUT'					=> 'Кадыроўка ўваходных знакаў',
	'MBSTRING_HTTP_INPUT_EXPLAIN'			=> 'Значэнне <var>mbstring.http_input</var> павінна быць усталявана роўным <samp>pass</samp>.',
	'MBSTRING_HTTP_OUTPUT'					=> 'Кадыроўка выходных знакаў',
	'MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> 'Значэнне <var>mbstring.http_output</var> павінна быць усталявана роўным <samp>pass</samp>.',

	'MAKE_FOLDER_WRITABLE'		=> 'Упэўніцеся, што гэтая папка існуе і ў сервера ёсць правы на запіс у яе, затым паўторыце спробу:<br />»<strong>%s</strong>.',
	'MAKE_FOLDERS_WRITABLE'		=> 'Упэўніцеся, што гэтыя папкі існуюць і ў сервера ёсць правы на запіс у іх, затым паўторыце спробу:<br />»<strong>%s</strong>.',

	'MYSQL_SCHEMA_UPDATE_REQUIRED'	=> 'Схема вашай базы дадзеных MySQL састарэлая. phpBB выяўлена, што выкарыстоўваецца схема для MySQL 3.x/4.x, але сервер працуе на MySQL %2$s.<br /><strong>Перад пачаткам агульнага абнаўлення, вам неабходна вырабіць абнаўленне схемы базы дадзеных.</strong><br /><br />Звернецеся да <a href="https://www.phpbb.com/kb/article/doesnt-have-a-default-value-errors/">артыкулу базы ведаў па пытанні абнаўлення схемы базы дадзеных MySQL</a>.',

	'NAMING_CONFLICT'			=> 'Канфлікт імёнаў: абодва імя %s і %s з\'яўляюцца псеўданімамі<br /><br />%s',
	'NEXT_STEP'					=> 'Наступны крок',
	'NOT_FOUND'					=> 'Не знойдзена',
	'NOT_UNDERSTAND'			=> 'Не атрымалася разабраць выраз %s #%d, табліца %s ("%s")',
	'NO_CONVERTORS'				=> 'Няма даступных для выкарыстання канвертараў.',
	'NO_CONVERT_SPECIFIED'		=> 'Не вылучаны канвертар.',
	'NO_LOCATION'				=> 'Не атрымалася знайсці прыкладанне. Калі вы ведаеце, што Imagemagick усталяваны, вы можаце паказаць шлях да яго ў адміністратарскім раздзеле пасля ўсталёўкі.',
	'NO_TABLES_FOUND'			=> 'Табліц не знойдзена.',

	'OVERVIEW_BODY'					=> 'Сардэчна запрашаем у phpBB3!<br /><br />phpBB® з\'яўляецца найболей распаўсюджаным рашэннем з адчыненым кодам для арганізацыі канферэнцый у інтэрнэце. phpBB3 стаў чарговым этапам сямігадовай распрацоўкі праграмнага прадукта. Як і яго папярэднікі, phpBB3 з\'яўляецца функцыянальным, мае дружалюбны інтэрфейс і поўнасцю падтрымліваецца phpBB Team. У phpBB3 істотна палепшаныя якасці, якія зрабілі папулярным phpBB2, дададзеныя найболей неабходныя функцыі, якія адсутнічалі ў папярэдніх версіях. Спадзяемся, што гэта перасягне вашы чаканні.<br /><br />Гэтая сістэма правядзе вас праз працэсы ўсталёўкі phpBB3, абнаўленні папярэдніх рэлізаў да апошняй версіі phpBB3, а таксама канвертаванні ў phpBB3 іншага праграмнага забеспячэння для канферэнцый (уключаючы phpBB2). Для атрымання дадатковай інфармацыі мы прапаноўваем вам азнаёміцца з <a href="../docs/INSTALL.html">кіраўніцтвам па ўсталёўцы</a>.<br /><br />Каб азнаёміцца з ліцэнзійнымі ўмовамі phpBB3 або пазнаць аб падтрымцы, вылучыце адпаведны пункт у бакавым меню. Для працягу вылучыце патрэбную закладку вышэй.',

	'PCRE_UTF_SUPPORT'				=> 'Падтрымка UTF-8 у PCRE',
	'PCRE_UTF_SUPPORT_EXPLAIN'		=> 'phpBB <strong>не будзе</strong> працаваць, калі PHP сабраны без падтрымкі UTF-8 для пашырэння PCRE.',
	'PHP_GETIMAGESIZE_SUPPORT'			=> 'Функцыя PHP getimagesize() даступная',
	'PHP_GETIMAGESIZE_SUPPORT_EXPLAIN'	=> '<strong>Неабходна</strong> - Для правільнай працы phpBB неабходна наяўнасць функцыі getimagesize.',
	'PHP_OPTIONAL_MODULE'			=> 'Дадатковыя модулі',
	'PHP_OPTIONAL_MODULE_EXPLAIN'	=> 'Гэтыя модулі і прыкладанні <strong>не з\'яўляюцца абавязковымі</strong>. Аднак, калі яны даступныя, гэта адчыніць дадатковыя функцыі.',
	'PHP_SUPPORTED_DB'				=> 'Падтрымоўваемыя базы дадзеных',
	'PHP_SUPPORTED_DB_EXPLAIN'		=> '<strong>Неабходна</strong> - Ваша версія PHP павінна падтрымліваць як мінімум адну з пералічаных баз дадзеных. У адваротным выпадку звяжыцеся з вашым правайдэрам або звернецеся да адпаведнага раздзелу дакументацыі PHP.',
	'PHP_REGISTER_GLOBALS'			=> 'Параметр PHP <var>register_globals</var> адключаны',
	'PHP_REGISTER_GLOBALS_EXPLAIN'	=> 'phpBB будзе працаваць і ў выпадку, калі параметр register_globals уключаны, але, калі гэта магчыма, яго рэкамендуецца адключыць у мэтах бяспекі.',
	'PHP_SAFE_MODE'					=> 'Бяспечны рэжым (Safe mode)',
	'PHP_SETTINGS'					=> 'Версія і налады PHP',
	'PHP_SETTINGS_EXPLAIN'			=> '<strong>Неабходна</strong> - Для ўсталёўкі phpBB3 патрабуецца версія PHP не малодшай 4.3.3. Калі ніжэй напісана <var>Бяспечны рэжым (Safe mode)</var>, то ваш PHP працуе ў абароненым рэжыме. Гэта накладзе абмежаванні на выдаленае адміністраванне і аналагічныя функцыі.',
	'PHP_URL_FOPEN_SUPPORT'			=> 'Параметр PHP <var>allow_url_fopen</var> уключаны',
	'PHP_URL_FOPEN_SUPPORT_EXPLAIN'	=> '<strong>Неабавязкова</strong> - Хоць гэты параметр не з\'яўляецца абавязковым, некаторыя функцыі phpBB, тыпу знешніх аватар, не будуць працаваць належнай выявай. ',
	'PHP_VERSION_REQD'				=> 'Версія PHP >= 4.3.3',
	'POST_ID'						=> 'Ідэнтыфікатар паведамлення',
	'PREFIX_FOUND'					=> 'Прагляд вашых табліц паказаў наяўнасць прыдатнай канферэнцыі з прэфіксам табліц <strong>%s</strong>.',
	'PREPROCESS_STEP'				=> 'Выкананне папярэдніх функцый/запытаў',
	'PRE_CONVERT_COMPLETE'			=> 'Усе этапы падрыхтоўкі да канвертавання паспяхова завершаныя. Зараз вы можаце пачаць працэс канвертавання. Улічыце, што вам, магчыма, прыйдзецца ўручную вырабіць некаторыя дзеянні і налады. Пасля канвертавання абавязкова праверце прызначаныя правы доступу, адновіце пошукавы індэкс, які не падлягаў канвертаванню, калі неабходна, а таксама пераканайцеся, што ўсе файлы былі паспяхова скапіяваныя (напрыклад, аватары і смайлікі).',
	'PROCESS_LAST'					=> 'Выкананне заключных запытаў',

	'REFRESH_PAGE'				=> 'Абнаўляць старонку для працягу канвертавання',
	'REFRESH_PAGE_EXPLAIN'		=> '«Так» азначае, што канвертар будзе аўтаматычна перазагружаць старонку, каб працягнуць канвертаванне пасля завяршэння чарговага этапу. Калі гэта ваша першая канвертацыя з мэтай тэставання і праверкі на памылкі, мы раім усталяваць значэнне гэтага параметру ў «Не».',
	'REQUIREMENTS_TITLE'		=> 'Праграмная сумяшчальнасць',
	'REQUIREMENTS_EXPLAIN'		=> 'Перад усталёўкай phpBB3 будуць праведзеныя праверкі файлаў і канфігурацыі сервера, каб пераканацца ў тым, што phpBB3 можна ўсталяваць і запусціць. Уважліва азнаёмцеся з вынікамі і не пераходзіце да наступнага кроку ўсталёўкі датуль, пакуль неабходныя праверкі не будуць пройдзеныя. Калі вам патрэбныя якія-небудзь з дадатковых магчымасцяў канферэнцыі, упэўніцеся, што адпаведныя ім тэсты таксама паспяхова пройдзеныя.',
	'RETRY_WRITE'				=> 'Паўтарыць спробу запісу канфігурацыі',
	'RETRY_WRITE_EXPLAIN'		=> 'Пры жаданні вы можаце змяніць правы на файл config.php, каб дазволіць phpBB запіс у яго. У гэтым выпадку націсніце на кнопку «Паўтарыць» ніжэй. Не забудзьце вярнуць правы на файл config.php пасля завяршэння ўсталёўкі.',

	'SCRIPT_PATH'				=> 'Шлях да канферэнцыі',
	'SCRIPT_PATH_EXPLAIN'		=> 'Шлях да папкі, якая змяшчае phpBB, адносна кораня бачыны, напрыклад, <samp>/phpBB3</samp>.',
	'SELECT_LANG'				=> 'Вылучыце мову',
	'SERVER_CONFIG'				=> 'Канфігурацыя сервера',
	'SEARCH_INDEX_UNCONVERTED'	=> 'Пошукавы індэкс не быў сканвертаваны',
	'SEARCH_INDEX_UNCONVERTED_EXPLAIN'	=> 'Ваш стары пошукавы індэкс не быў сканвертаваны. Любы пошукавы запыт верне пусты вынік. Каб стварыць новы пошукавы індэкс, перайдзіце ў адміністратарскі раздзел, вылучыце падраздзел Абслугоўванне і ў ім пункт Пошукавы індэкс.',
	'SOFTWARE'					=> 'Тып канферэнцыі',
	'SPECIFY_OPTIONS'			=> 'Азначэнне налад канвертавання',
	'STAGE_ADMINISTRATOR'		=> 'Звесткі аб адміністратару',
	'STAGE_ADVANCED'			=> 'Пашыраныя налады',
	'STAGE_ADVANCED_EXPLAIN'	=> 'Змяняць параметры на гэтай старонцы неабходна толькі ў выпадку, калі вы ведаеце, што вам не падыдуць налады па змаўчанні. Калі вы не ўпэўненыя, пераходзіце да наступнага кроку, гэтыя налады можна будзе змяніць пазней у адміністратарскім раздзеле.',
	'STAGE_CONFIG_FILE'			=> 'Файл канфігурацыі',
	'STAGE_CREATE_TABLE'		=> 'Стварэнне табліц базы дадзеных',
	'STAGE_CREATE_TABLE_EXPLAIN'	=> 'Табліцы базы дадзеных phpBB 3.0 былі створаныя і запоўненыя пачатковымі дадзенымі. Пераходзіце да наступнага кроку для завяршэння ўсталёўкі phpBB.',
	'STAGE_DATABASE'			=> 'Налады базы дадзеных',
	'STAGE_FINAL'				=> 'Заключны крок',
	'STAGE_INTRO'				=> 'Уводзіны',
	'STAGE_IN_PROGRESS'			=> 'Канвертаванне',
	'STAGE_REQUIREMENTS'		=> 'Патрабаванні',
	'STAGE_SETTINGS'			=> 'Налады',
	'STARTING_CONVERT'			=> 'Пачатак канвертаванні',
	'STEP_PERCENT_COMPLETED'	=> 'Крок <strong>%d</strong> з <strong>%d</strong>',
	'SUB_INTRO'					=> 'Уводзіны',
	'SUB_LICENSE'				=> 'Ліцэнзія',
	'SUB_SUPPORT'				=> 'Падтрымка',
	'SUCCESSFUL_CONNECT'		=> 'Паспяховае падлучэнне',
	'SUPPORT_BODY'				=> 'Поўная падтрымка падаецца для апошняга стабільнага рэлізу phpBB3 бясплатна. Яна ўключае:</p><ul><li>усталёўку</li><li>канфігурацыю</li><li>тэхнічныя пытанні</li><li>праблемы, звязаныя з патэнцыйнымі памылкамі праграмнага забеспячэння</li><li>абнаўленне версій - кандыдатаў на рэліз (RC) да апошняй стабільнай версіі</li><li>канвертаванне phpBB 2.0.x у phpBB3</li><li>канвертаванне ў phpBB3 іншага праграмнага забеспячэння для канферэнцый (глядзіце <a href="https://www.phpbb.com/community/viewforum.php?f=65">Convertors Forum</a>)</li></ul><p>Мы прапаноўваем карыстальнікам, дагэтуль выкарыстоўвалым бэта-версіі phpBB3, зноўку ўсталяваць апошнюю версію. </p><h2>Моды / Стылі</h2><p>Пытанні, звязаныя з Модамі, абмяркоўваюцца ў адпаведным форуме <a href="https://www.phpbb.com/community/viewforum.php?f=81">Modifications Forum</a>.<br />Пытанні, звязаныя са стылямі, абмяркоўваюцца ў адпаведным форуме <a href="https://www.phpbb.com/community/viewforum.php?f=80">Styles Forum</a>.<br /><br />Калі ваша пытанне звязаны з пэўным прадуктам, задавайце яго ў тэме, прысвечанай гэтаму прадукту.</p><h2>Атрыманне падтрымкі</h2><p><a href="https://www.phpbb.com/community/viewtopic.php?f=14&amp;t=571070">З чаго пачаць</a><br /><a href="https://www.phpbb.com/support/">Падтрымка</a><br /><a href="https://www.phpbb.com/support/documentation/3.0/quickstart/">Кароткае кіраўніцтва</a><br /><br />Каб быць у курсе апошніх навін і рэлізаў, вы можаце падпісацца на <a href="https://www.phpbb.com/support/">наша рассыланне</a>.<br /><br />',
	'SYNC_FORUMS'				=> 'Сінхранізацыя форумаў',
	'SYNC_POST_COUNT'			=> 'Сінхранізацыя колькасці паведамленняў',
	'SYNC_POST_COUNT_ID'		=> 'Сінхранізацыя колькасці паведамленняў з <var>entry</var> ад %1$s да %2$s.',
	'SYNC_TOPICS'				=> 'Сінхранізацыя тэм',
	'SYNC_TOPIC_ID'				=> 'Сінхранізацыя тэм з <var>topic_id</var> ад %1$s да %2$s.',

	'TABLES_MISSING'			=> 'Не атрымалася знайсці табліцы<br />» <strong>%s</strong>.',
	'TABLE_PREFIX'				=> 'Прэфікс для табліц у базе дадзеных',
	'TABLE_PREFIX_EXPLAIN'		=> 'Прэфікс павінен пачынацца з літары і можа ўтрымліваць толькі літары, лікі і знакі падкрэслення.',
	'TABLE_PREFIX_SAME'			=> 'Прэфікс табліц павінен быць тым жа, што выкарыстоўваецца канвертоўным форумам.<br />» Вы паказалі прэфікс %s.',
	'TESTS_PASSED'				=> 'Праверка пройдзеная',
	'TESTS_FAILED'				=> 'Праверка не пройдзеная',

	'UNABLE_WRITE_LOCK'			=> 'Не атрымалася запісаць файл блакоўкі',
	'UNAVAILABLE'				=> 'Недаступна',
	'UNWRITABLE'				=> 'Няма мае рацыю на запіс',
	'UPDATE_TOPICS_POSTED'		=> 'Генераванне пераліку тэм, у якіх пісаў карыстальнік',
	'UPDATE_TOPICS_POSTED_ERR'	=> 'Адбылася памылка пры генераванні пераліку тэм, у якіх пісаў карыстальнік. Вы можаце паўтарыць спробу выканаць гэты этап у адміністратарскім раздзеле пасля завяршэння працэсу канвертавання.',
	'VERIFY_OPTIONS'			=> 'Праверка налад канвертавання',
	'VERSION'					=> 'Версія',

	'WELCOME_INSTALL'			=> 'Вас прывітае праграма ўсталёўкі phpBB3',
	'WRITABLE'					=> 'Запіс дазволеная',
));

// Updater
$lang = array_merge($lang, array(
	'ALL_FILES_UP_TO_DATE'		=> 'Усе файлы адпавядаюць самой апошняй версіі phpBB. Зараз <a href="../ucp.php?mode=login">увайдзіце на канферэнцыю</a> і праверце, што ўсё працуе нармалёва. Не забудзьце выдаліць, пераназваць або перамясціць папку «install»! Калі ласка, адпраўце нам абноўленую інфармацыю аб вашым серверы і канфігурацыі канферэнцыі з дапамогай старонкі <a href="../ucp.php?mode=login&amp;redirect=adm/index.php%3Fi=send_statistics%26mode=send_statistics">Статыстычныя дадзеныя</a> у адміністратарскай частцы.',
	'ARCHIVE_FILE'				=> 'Файл-крыніца ў архіве',

	'BACK'				=> 'Назад',
	'BINARY_FILE'		=> 'Бінарны файл',
	'BOT'				=> 'Павук/Робат',
	
	'CHANGE_CLEAN_NAMES'			=> 'Метад, выкарыстоўваны для праверкі на выкарыстанне аднаго і таго жа імя некалькімі карыстальнікамі, быў зменены. Маецца некалькіх карыстальнікаў, якія маюць адно і тое ж імя пры параўнанні новым метадам. Для працягу вы павінны выдаліць або пераназваць гэтых карыстальнікаў, каб пераканацца, што кожнае імя выкарыстоўваецца толькі адным карыстальнікам.',
	'CHECK_FILES'					=> 'Параўнаць файлы',
	'CHECK_FILES_AGAIN'				=> 'Паўторна параўнаць файлы',
	'CHECK_FILES_EXPLAIN'			=> 'На наступным кроку ўсе файлы phpBB будуць параўнаныя з файламі абнаўлення, гэта можа заняць некаторы час, калі параўнанне файлаў праводзіцца ўпершыню.',
	'CHECK_FILES_UP_TO_DATE'		=> 'Паводле базе дадзеных, ваша версія phpBB самая новая. Вы можаце перайсці да параўнання файлаў, каб упэўніцца ў тым, што ўсе файлы сапраўды адпавядаюць самой апошняй версіі phpBB.',
	'CHECK_UPDATE_DATABASE'			=> 'Працягнуць абнаўленне',
	'COLLECTED_INFORMATION'			=> 'Звесткі аб файле',
	'COLLECTED_INFORMATION_EXPLAIN'	=> 'Спіс ніжэй дэманструе звесткі аб файлах, якія жывуць у нястачы ў абнаўленні. Прачытайце інфармацыю, папярэднюю блоку файлаў кожнага тыпу, каб зразумець іх сэнс і што патрабуецца зрабіць для выканання паспяховага абнаўлення.',
	'COLLECTING_FILE_DIFFS'			=> 'Праверка адрозненняў у файлах',
	'COMPLETE_LOGIN_TO_BOARD'		=> '<a href="../ucp.php?mode=login">Увайдзіце на канферэнцыю</a> і праверце, што ўсё працуе нармалёва. Не забудзьце выдаліць, пераназваць або перамясціць папку install!',
	'CONTINUE_UPDATE_NOW'			=> 'Працягвайце працэс абнаўлення',		// Shown within the database update script at the end if called from the updater
	'CONTINUE_UPDATE'				=> 'Працягвайце абнаўленне',				// Shown after file upload to indicate the update process is not yet finished
	'CURRENT_FILE'					=> 'Пачатак дзеючага зыходнага файла',
	'CURRENT_VERSION'				=> 'Дзеючая версія',

	'DATABASE_TYPE'						=> 'Тып базы дадзеных',
	'DATABASE_UPDATE_INFO_OLD'			=> 'Файл абнаўлення базы дадзеных у папцы install састарэлы. Упэўніцеся што запампавалі спраўную версію гэтага файла.',
	'DELETE_USER_REMOVE'				=> 'Выдаліць карыстальніка і яго паведамлення',
	'DELETE_USER_RETAIN'				=> 'Выдаліць карыстальніка, але пакінуць яго паведамлення',
	'DESTINATION'						=> 'Файл-атрымальнік',
	'DIFF_INLINE'						=> 'Усярэдзіне тэксту',
	'DIFF_RAW'							=> 'Raw unified diff',
	'DIFF_SEP_EXPLAIN'					=> 'Канец дзеючага зыходнага файла/Пачатак новага файла',
	'DIFF_SIDE_BY_SIDE'					=> 'Паралельна',
	'DIFF_UNIFIED'						=> 'Unified diff',
	'DO_NOT_UPDATE'						=> 'Не абнаўляць гэты файл',
	'DONE'								=> 'Гатова',
	'DOWNLOAD'							=> 'Запампаваць',
	'DOWNLOAD_AS'						=> 'Запампаваць у фармаце',
	'DOWNLOAD_UPDATE_METHOD_BUTTON'		=> 'Запампаваць архіў з мадыфікаванымі файламі (рэкамендуецца)',
	'DOWNLOAD_CONFLICTS'				=> 'Запампаваць канфліктныя месцы для гэтага файла',
	'DOWNLOAD_CONFLICTS_EXPLAIN'		=> 'Шукаць &lt;&lt;&lt; для выяўлення канфліктаў',
	'DOWNLOAD_UPDATE_METHOD'			=> 'Запампаваць архіў з мадыфікаванымі файламі',
	'DOWNLOAD_UPDATE_METHOD_EXPLAIN'	=> 'Запампаваўшы архіў, распакуйце яго. У ім вы знойдзеце змененыя файлы, якія трэба запампаваць у корань phpBB, пры гэтым кожны файл павінен апынуцца ў адпаведнай яму папцы. Пасля гэтага зноўку правядзіце параўнанне файлаў, націснуўшы якая адказвае за гэта кнопку ніжэй.',

	'ERROR'			=> 'Памылка',
	'EDIT_USERNAME'	=> 'Рэдагаваць імя карыстальніка',
	
	'FILE_ALREADY_UP_TO_DATE'		=> 'Файл ужо адпавядае новай версіі.',
	'FILE_DIFF_NOT_ALLOWED'			=> 'Няма мае рацыю на выкананне каманды diff для гэтага файла.',
	'FILE_USED'						=> 'Інфармацыя з файла',			// Single file
	'FILES_CONFLICT'				=> 'Канфліктуючыя файлы',
	'FILES_CONFLICT_EXPLAIN'		=> 'Наступныя файлы мадыфікаваныя і не адпавядаюць арыгінальным файлам старой версіі. phpBB вызначыў, што гэтыя файлы будуць ствараць канфлікт пры аб\'яднанні з іх новымі версіямі. Вывучыце канфліктныя месцы і паспрабуйце выправіць іх уручную, альбо працягнеце абнаўленне, вылучыўшы прыдатны тып аб\'яднання файлаў. Калі вы будзеце дазваляць канфлікт уручную, зноўку правядзіце параўнанне файлаў пасля таго, як занясеце ў іх змены. Для кожнага файла ў асобнасці вы можаце вылучыць пераважны метад аб\'яднання з новай версіяй. Вынікам працы першага метаду будзе файл, у якім адкінутыя канфліктуючыя радкі з вашага старога файла, у другім метадзе будуць адкінутыя канфліктуючыя радкі з новай версіі.',
	'FILES_MODIFIED'				=> 'Змененыя файлы',
	'FILES_MODIFIED_EXPLAIN'		=> 'Наступныя файлы мадыфікаваныя і не адпавядаюць арыгінальным файлам старой версіі. Абноўлены файл будзе вынікам аб\'яднання вашага мадыфікаванага і новага файла.',
	'FILES_NEW'						=> 'Новыя файлы',
	'FILES_NEW_EXPLAIN'				=> 'Наступных файлаў няма ў вашай версіі phpBB. Гэтыя файлы будуць дададзеныя.',
	'FILES_NEW_CONFLICT'			=> 'Новыя канфліктуючыя файлы',
	'FILES_NEW_CONFLICT_EXPLAIN'	=> 'Наступныя файлы з\'явіліся толькі ў апошняй версіі. Але файл з тым жа імем у тым жа месцы ўжо існуе. Гэты файл будзе перазапісаны файлам з новай версіі.',
	'FILES_NOT_MODIFIED'			=> 'Нязменныя файлы',
	'FILES_NOT_MODIFIED_EXPLAIN'	=> 'Наступныя файлы не мадыфікаваныя і ўяўляюць сабою арыгінальныя файлы phpBB той версіі, якую вы жадаеце абнавіць.',
	'FILES_UP_TO_DATE'				=> 'Ужо абноўленыя файлы',
	'FILES_UP_TO_DATE_EXPLAIN'		=> 'Наступныя файлы ўжо адпавядаюць файлам новай версіі і не патрабуюцца ў абнаўленні.',
	'FTP_SETTINGS'					=> 'Налады FTP',
	'FTP_UPDATE_METHOD'				=> 'Запампаваць па FTP',

	'INCOMPATIBLE_UPDATE_FILES'		=> 'Знойдзеныя файлы абнаўлення не падыходзяць для ўсталяванай версіі phpBB. Ваша версія - %1$s, а файл абнаўлення прызначаны для пераходу з версіі %2$s да версіі %3$s.',
	'INCOMPLETE_UPDATE_FILES'		=> 'Няпоўны набор файлаў абнаўлення.',
	'INLINE_UPDATE_SUCCESSFUL'		=> 'Абнаўленне базы дадзеных прайшло паспяхова. Зараз вам неабходна працягнуць працэс абнаўлення.',

	'KEEP_OLD_NAME'		=> 'Пакінуць ранейшае імя',

	'LATEST_VERSION'		=> 'Апошняя версія',
	'LINE'					=> 'Радок',
	'LINE_ADDED'			=> 'Дададзена',
	'LINE_MODIFIED'			=> 'Зменена',
	'LINE_REMOVED'			=> 'Выдаленае',
	'LINE_UNMODIFIED'		=> 'Не зменена',
	'LOGIN_UPDATE_EXPLAIN'	=> 'Для таго, каб абнавіць версію phpBB, перш неабходна ўвайсці на канферэнцыю.',

	'MAPPING_FILE_STRUCTURE'	=> 'Для палягчэння запампоўкі файлаў тут паказаныя адпаведнасці размяшчэнняў файлаў у архіве і ў вашай версіі phpBB.',

	'MERGE_MODIFICATIONS_OPTION'	=> 'Аб\'яднаць змены',

	'MERGE_NO_MERGE_NEW_OPTION'	=> 'Не аб\'ядноўваць - выкарыстаць новы файл',
	'MERGE_NO_MERGE_MOD_OPTION'	=> 'Не аб\'ядноўваць - выкарыстаць наяўны файл',
	'MERGE_MOD_FILE_OPTION'		=> 'Аб\'яднаць файлы і выкарыстаць мадыфікаваныя радкі ў канфліктных месцах',
	'MERGE_NEW_FILE_OPTION'		=> 'Аб\'яднаць файлы і выкарыстаць радкі новага файла ў канфліктных месцах',
	'MERGE_SELECT_ERROR'		=> 'Няслушна вылучаныя спосабы аб\'яднання канфліктнага файла з новай версіяй.',
	'MERGING_FILES'				=> 'Аб\'яднанне адрозненняў',
	'MERGING_FILES_EXPLAIN'		=> 'Зараз вырабляецца канчатковая змена файлаў.<br /><br />Дачакайцеся канчатка ўсіх аперацый над змененымі файламі.',

	'NEW_FILE'						=> 'Канец новага файла',
	'NEW_USERNAME'					=> 'Новае імя',
	'NO_AUTH_UPDATE'				=> 'У вас няма мае рацыю на выкананне абнаўлення phpBB',
	'NO_ERRORS'						=> 'Без памылак',
	'NO_UPDATE_FILES'				=> 'Наступныя файлы не будуць абноўленыя',
	'NO_UPDATE_FILES_EXPLAIN'		=> 'Наступныя файлы з\'явіліся або былі змененыя ў апошняй версіі, але папка, у якой яны павінны нахадзіцца, не знойдзеная ў вашай дзеючай версіі phpBB. Прысутнасць у спісе файлаў, не якія адносяцца да папкі моў (language/) або стыляў (styles/), можа азначаць, што вы змянілі структуру дырэкторый і абнаўленне будзе няпоўным.',
	'NO_UPDATE_FILES_OUTDATED'		=> 'Не знойдзеная папка з абнаўленнямі, упэўніцеся, што вы запампавалі адпаведныя файлы.<br /><br />Ваша версія phpBB %1$s <strong>не</strong> самая апошняя, для яе даступныя абнаўленні. Зайдзіце на старонку <a href="https://www.phpbb.com/downloads/" rel="external">https://www.phpbb.com/downloads/</a>, каб запампаваць патрэбны вам пакет абнаўлення з версіі %2$s да версіі %3$s.',
	'NO_UPDATE_FILES_UP_TO_DATE'	=> 'Ваша версія phpBB самая апошняя. Няма неабходнасці запускаць праграму абнаўлення. Калі вы жадаеце правесці праверку цэласнасці файлаў, пераканайцеся, што запампавалі прыдатныя файлы абнаўлення.',
	'NO_UPDATE_INFO'				=> 'Не знойдзеныя дадзеныя файла абнаўлення.',
	'NO_UPDATES_REQUIRED'			=> 'Абнаўленне не патрабуецца',
	'NO_VISIBLE_CHANGES'			=> 'Няма бачных змен',
	'NOTICE'						=> 'Папярэджанне',
	'NUM_CONFLICTS'					=> 'Лік канфліктных месцаў',
	'NUMBER_OF_FILES_COLLECTED'	=> 'Знойдзеныя адрозненні ў %1$d файлах з from %2$d.<br />Дачакайцеся канчатка аперацыі.',

	'OLD_UPDATE_FILES'		=> 'Наяўныя файлы абнаўлення phpBB састарэлі, яны прызначаныя для абнаўлення з версіі %1$s да версіі %2$s, але апошняя версія phpBB - %3$s.',

	'PACKAGE_UPDATES_TO'				=> 'Дзеючы пакет абнаўляе да версіі',
	'PERFORM_DATABASE_UPDATE'			=> 'Абнаўленне базы дадзеных',
	'PERFORM_DATABASE_UPDATE_EXPLAIN'	=> 'Ніжэй вы знойдзеце кнопку абнаўлення базы дадзеных. Абнаўленне можа заняць некаторы час, таму не перарывайце працэс яго выканання, калі вам здасца, што ён завіс. Пасля завяршэння прытрымлівайцеся інструкцыям для працягу працэсу абнаўлення.',
	'PREVIOUS_VERSION'					=> 'Папярэдняя версія',
	'PROGRESS'							=> 'Выкананне',

	'RESULT'					=> 'Вынік',
	'RUN_DATABASE_SCRIPT'		=> 'Абнавіць базу дадзеных',

	'SELECT_DIFF_MODE'			=> 'Вылучыце рэжым diff',
	'SELECT_DOWNLOAD_FORMAT'	=> 'Вылучыце фармат архіва для запампоўкі',
	'SELECT_FTP_SETTINGS'		=> 'Усталёўка налад FTP',
	'SHOW_DIFF_CONFLICT'		=> 'Адрозненні/канфліктныя месцы',
	'SHOW_DIFF_FINAL'			=> 'Выніковы файл',
	'SHOW_DIFF_MODIFIED'		=> 'Адрозненні з аб\'яднаным файлам',
	'SHOW_DIFF_NEW'				=> 'Змесціва файла',
	'SHOW_DIFF_NEW_CONFLICT'	=> 'Адрозненні ў файлах',
	'SHOW_DIFF_NOT_MODIFIED'	=> 'Адрозненні ў файлах',
	'SOME_QUERIES_FAILED'		=> 'Выкананне некаторых запытаў завяршылася няўдачай, тэксты запытаў і памылак прыведзеныя ніжэй.',
	'SQL'						=> 'SQL-запыт',
	'SQL_FAILURE_EXPLAIN'		=> 'Хутчэй усяго хвалявацца не аб чым, працэс абнаўлення будзе працягнуты. У адваротным выпадку вам можа спатрэбіцца дапамога, якую можна атрымаць на форуме падтрымкі. Звернецеся да <a href="../docs/README.html">README-файлу</a> (на ангельскім), каб пазнаць, як атрымаць кансультацыю.',
	'STAGE_FILE_CHECK'			=> 'Параўнанне файлаў',
	'STAGE_UPDATE_DB'			=> 'Абнаўленне базы дадзеных',
	'STAGE_UPDATE_FILES'		=> 'Абнаўленне файлаў',
	'STAGE_VERSION_CHECK'		=> 'Праверка версіі',
	'STATUS_CONFLICT'			=> 'Зменены файл, які стварае канфліктныя месцы',
	'STATUS_MODIFIED'			=> 'Зменены файл',
	'STATUS_NEW'				=> 'Новы файл',
	'STATUS_NEW_CONFLICT'		=> 'Канфліктуючы новы файл',
	'STATUS_NOT_MODIFIED'		=> 'Нязменны файл',
	'STATUS_UP_TO_DATE'			=> 'Ужо абноўлены файл',
  
	'TOGGLE_DISPLAY'			=> 'Паказаць/схаваць спіс файлаў',
 	'TRY_DOWNLOAD_METHOD'		=> 'Вы можаце паспрабаваць загрузіць мадыфікаваныя файлы.<br />Гэты метад найболей надзейны і з\'яўляецца рэкамендуемым спосабам абнаўлення.',
	'TRY_DOWNLOAD_METHOD_BUTTON'=> 'Паспрабаваць зараз',

	'UPDATE_COMPLETED'				=> 'Абнаўленне завершанае',
	'UPDATE_DATABASE'				=> 'Абнавіць',
	'UPDATE_DATABASE_EXPLAIN'		=> 'На наступным кроку будуць занесеныя змены ў базу дадзеных.',
	'UPDATE_DATABASE_SCHEMA'		=> 'Абнаўленне структуры базы дадзеных',
	'UPDATE_FILES'					=> 'Абнавіць файлы',
	'UPDATE_FILES_NOTICE'			=> 'Упэўніцеся, што таксама абнавілі файлы канферэнцыі, гэты файл толькі абнаўляе вашу базу дадзеных.',
	'UPDATE_INSTALLATION'			=> 'Абнаўленне версіі phpBB',
	'UPDATE_INSTALLATION_EXPLAIN'	=> 'Тут вы можаце абнавіць вашу версію phpBB да апошняй.<br />Падчас гэтага працэсу ўсе вашы файлы будуць правераныя на цэласнасць. Вы зможаце праглядзець файлы і ўносныя ў іх змены перад абнаўленнем.<br /><br />Само абнаўленне можа быць выканана двума спосабамі.</p><h2>Абнаўленне ўручную</h2><p>Гэты спосаб складаецца ў тым, што вы запампоўваеце індывідуальны набор абноўленых файлаў, каб не страціць зробленыя вамі змены ў наяўных файлах. Запампаваўшы гэты архіў, вы павінны ўручную запампаваць файлы з яго ў адпаведныя ім месцазнаходжання адносна каранёвай папкі phpBB. Пасля гэтага вам будзе дадзеная магчымасць правесці праверку, што ўсе файлы займаюць якія належаць ім месца.</p><h2>Аўтаматычнае абнаўленне па FTP</h2><p>Гэты спосаб падобны на першы, але без неабходнасці запампоўваць абноўленыя файлы і запампоўваць іх на сервер самастойна, гэта будзе зроблена за вас. Каб скарыстацца гэтым спосабам, вам трэба шляхта запытваемыя праграмай абнаўлення дадзеныя аб вашым FTP-серверы. Па канчатку вы будзеце накіраваныя на паўторнае параўнанне файлаў з мэтай пераканацца, што абнаўленне прайшло паспяхова.<br /><br />',
	'UPDATE_INSTRUCTIONS'			=> '

		<h1>Аб\'ява аб выхадзе новай версіі</h1>

		<p>Перш чым працягнуць працэс абнаўлення, прачытайце <a href="%1$s" title="%1$s"><strong>аб\'ява аб выпуску апошняй версіі</strong></a>, яно можа ўтрымоўваць карысную для вас інфармацыю. Акрамя таго, у ім прысутнічаюць спасылкі на запампоўку новай версіі, абнаўленняў, а таксама пералік змен.</p>

		<br />

		<h1>Як абнавіць сваю версію phpBB з дапамогай пакета аўтаматычнага абнаўлення</h1>

		<p>Рэкамендаваны тут спосаб абнаўлення phpBB прыдатны толькі для пакета аўтаматычнага абнаўлення. Вы таксама можаце вырабіць абнаўленне, выкарыстаючы метады, паказаныя ў дакуменце INSTALL.html. Для аўтаматычнага абнаўлення трэба выканаць наступныя крокі:</p>

		<ul style="margin-left: 20px; font-size: 1.1em;">
			<li>Перайсці на <a href="https://www.phpbb.com/downloads/" title="https://www.phpbb.com/downloads/">старонку файлаў phpBB.com</a> і запампаваць архіў з пакетам аўтаматычнага абнаўлення ("Automatic Update Package").<br /><br /></li>
			<li>Распакаваць архіў.<br /><br /></li>
			<li>Запампаваць разархівіраваную папку install у корань phpBB (туды, дзе находзіцца файл config.php).<br /><br /></li>
		</ul>

		<p>Пасля гэтага канферэнцыя стане недаступная для звычайных карыстальнікаў, з-за таго, што зараз прысутнічае закочаная вамі папка install.<br /><br />
		<strong><a href="%2$s" title="%2$s">Зараз вы можаце пачаць працэс абнаўлення, пяройдучы ў папку install</a>.</strong><br />
		<br />
		Вам будуць дадзеныя ўказанні падчас працэсу абнаўлення, а па яго канчатку вам паведамяць аб гэтым.
		</p>
	',
	'UPDATE_INSTRUCTIONS_INCOMPLETE'	=> '

		<h1>Незавершанае аўтаматычнае абнаўленне</h1>

		<p>Выяўлена, што папярэдняе аўтаматычнае абнаўленне не было завершанае. Упэўніцеся ў тым, што ўсе крокі аўтаматычнага абнаўлення былі выкананыя. Перайдзіце па спасылцы ніжэй, або непасрэдна ў папку ўсталёўкі.</p>
	',
	'UPDATE_METHOD'					=> 'Спосаб абнаўлення',
	'UPDATE_METHOD_EXPLAIN'			=> 'Зараз вы можаце вылучыць зручны для вас спосаб запампоўкі файлаў. Калі вы ўпадабаеце запампоўку па FTP, вам будзе прапанавана запоўніць форму дадзеных аб уліковым запісе вашага FTP-сервера. Гэты спосаб забяспечвае аўтаматычнае перамяшчэнне файлаў у новыя месцазнаходжанні і стварэнне рэзервовых дзід іх старых версій з даданнем .bak да імя файла. Калі вы вылучыце запампоўку архіва з мадыфікаванымі файламі, то зможаце распакаваць яго і запампаваць файлы ў адпаведныя ім месцазнаходжання ўручную.',
	'UPDATE_REQUIRES_FILE'			=> 'Для абнаўлення неабходна наяўнасць наступнага файла: %s',
	'UPDATE_SUCCESS'				=> 'Абнаўленне паспяхова завершанае',
	'UPDATE_SUCCESS_EXPLAIN'		=> 'Усе файлы паспяхова абноўленыя. Наступны крок уключае ў сябе паўторную праверку адпаведнасці файлаў апошняй версіі phpBB.',
	'UPDATE_VERSION_OPTIMIZE'		=> 'Абнаўленне версіі і аптымізацыя табліц',
	'UPDATING_DATA'					=> 'Абнаўленне дадзеных',
	'UPDATING_TO_LATEST_STABLE'		=> 'Абнаўленне базы дадзеных да апошняй стабільнай версіі',
	'UPDATED_VERSION'				=> 'Абноўленая версія',
	'UPGRADE_INSTRUCTIONS'			=> 'Даступна новая версія <strong>%1$s</strong>. Калі ласка, прачытайце <a href="%2$s" title="%2$s"><strong>аб\'яву аб выпуску</strong></a>, каб даведацца пра тое, што яна можа прапанаваць, і як абнавіць.',
	'UPLOAD_METHOD'					=> 'Спосаб запампоўкі',

	'UPDATE_DB_SUCCESS'				=> 'База дадзеных паспяхова абноўленая.',
	'USER_ACTIVE'					=> 'Актываваны карыстальнік',
	'USER_INACTIVE'					=> 'Неактываваны карыстальнік',

	'VERSION_CHECK'				=> 'Праверка версіі',
	'VERSION_CHECK_EXPLAIN'		=> 'Правярае, што дзеючая версія phpBB самая апошняя.',
	'VERSION_NOT_UP_TO_DATE'	=> 'Ваша версія phpBB не самая апошняя. Працягвайце працэс абнаўлення.',
	'VERSION_NOT_UP_TO_DATE_ACP'=> 'Ваша версія phpBB не самая апошняя.<br />Ніжэй вы знойдзеце спасылку на аб\'яву аб выпуску апошняй версіі а таксама інструкцыю па абнаўленні phpBB.',
	'VERSION_NOT_UP_TO_DATE_TITLE'	=> 'Ваша версія phpBB не самая апошняя.',
	'VERSION_UP_TO_DATE'		=> 'Ваша версія phpBB самая апошняя, на дадзены момант для яе няма абнаўленняў. Тым не менш, вы можаце перайсці да праверкі файлаў на адпаведнасць апошняй версіі.',
	'VERSION_UP_TO_DATE_ACP'	=> 'Ваша версія phpBB самая апошняя, на дадзены момант для яе няма абнаўленняў. Вам не трэба абнаўляць вашу версію phpBB.',
	'VIEWING_FILE_CONTENTS'		=> 'Прагляд змесціва файла',
	'VIEWING_FILE_DIFF'			=> 'Прагляд адрозненняў у файлах',

	'WRONG_INFO_FILE_FORMAT'	=> 'Хібны фармат файла інфармацыі аб абнаўленні',
));

// Default database schema entries...
$lang = array_merge($lang, array(
	'CONFIG_BOARD_EMAIL_SIG'		=> 'Дзякуй, Адміністрацыя',
	'CONFIG_SITE_DESC'				=> 'Кароткае апісанне канферэнцыі',
	'CONFIG_SITENAME'				=> 'ваш_дамен.ru',

	'DEFAULT_INSTALL_POST'			=> 'Гэта прыклад паведамлення на вашай канферэнцыі phpBB3. Усё працуе правільна. Вы можаце выдаліць гэтае паведамленне і працягнуць наладу вашай канферэнцыі. У працэсе ўсталёўкі вашай першай катэгорыі і першаму форуму былі зададзеныя прыдатныя правы доступу для прадусталяваных груп адміністратараў, супермадэратараў, госцяў, зарэгістраваных карыстальнікаў і зарэгістраваных у адпаведнасці з COPPA карыстальнікаў. Калі вы рэшыце выдаліць вашу першую катэгорыю і першы форум, не забудзьце ўсталяваць правы доступу для ўсіх новых катэгорый і форумаў, якія вы ствараеце. Рэкамендуемы пераназваць вашу першую катэгорыю і першы форум і капіяваць правы доступу з іх ізноў ствараемым катэгорыям і форумам. Поспехі!',

	'FORUMS_FIRST_CATEGORY'			=> 'Ваша першая катэгорыя',
	'FORUMS_TEST_FORUM_DESC'		=> 'Апісанне вашага першага форума.',
	'FORUMS_TEST_FORUM_TITLE'		=> 'Ваш першы форум',

	'RANKS_SITE_ADMIN_TITLE'		=> 'Адміністратар',
	'REPORT_WAREZ'					=> 'Паведамленне ўтрымоўвае спасылкі на пазапраўныя або пірацкія праграмы.',
	'REPORT_SPAM'					=> 'Паведамленне мае адзінай мэтай рэкламу бачын, праграм або іншых прадуктаў, тавараў, паслуг і інш.',
	'REPORT_OFF_TOPIC'				=> 'Паведамленне не ставіцца да якая абмяркоўваецца тэмы.',
	'REPORT_OTHER'					=> 'Чыннік абскарджання не ставіцца не да адной з пералічаных, выкарыстайце поле дадатковай інфармацыі.',

	'SMILIES_ARROW'					=> 'Стрэлка',
	'SMILIES_CONFUSED'				=> 'Збянтэжаны',
	'SMILIES_COOL'					=> 'Усё шляхам',
	'SMILIES_CRYING'				=> 'Плача або моцна засмучаны',
	'SMILIES_EMARRASSED'			=> 'Збянтэжаны',
	'SMILIES_EVIL'					=> 'Злы або вельмі раздражнёны',
	'SMILIES_EXCLAMATION'			=> 'Усклік',
	'SMILIES_GEEK'					=> 'Вырадак',
	'SMILIES_IDEA'					=> 'Ідэя',
	'SMILIES_LAUGHING'				=> 'Смяецца',
	'SMILIES_MAD'					=> 'Раздражнёны',
	'SMILIES_MR_GREEN'				=> 'Зялёны',
	'SMILIES_NEUTRAL'				=> 'Нейтральны',
	'SMILIES_QUESTION'				=> 'Пытанне',
	'SMILIES_RAZZ'					=> 'Цвяліцца',
	'SMILIES_ROLLING_EYES'			=> 'Закочвае вочы',
	'SMILIES_SAD'					=> 'Смутны',
	'SMILIES_SHOCKED'				=> 'У шоку',
	'SMILIES_SMILE'					=> 'Усміхаецца',
	'SMILIES_SURPRISED'				=> 'Здзіўлены',
	'SMILIES_TWISTED_EVIL'			=> 'Вельмі злы',
	'SMILIES_UBER_GEEK'				=> 'Мегавырадак',
	'SMILIES_VERY_HAPPY'			=> 'Вельмі задаволены',
	'SMILIES_WINK'					=> 'Падморгвае',

	'TOPICS_TOPIC_TITLE'			=> 'Сардэчна запрашаем у phpBB3',
));

?>
