<?php
/**
*
* search_synonyms [Belarusian]
*
* @package language
* @version $Id: search_synonyms.php,v 1.3 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$synonyms = array(
	'абанент'			=> 'абнент',
	'першабытнік'			=> 'абариген',
	'скарот'		=> 'абревиатура',
	'авангард'			=> 'авангарт',
	'авіяпошта'			=> 'авіапошта',
	'аўтамабіль'		=> 'машына',
	'агрэсіўны'		=> 'агрэсіўный',
	'агрэсія'			=> 'агресія',
	'агрэсар'			=> 'агресар',
	'ад\'ютант'			=> 'адьютант',
	'адэкватны'		=> 'адэкватный',
	'ажыятаж'			=> 'ажиатаж',
	'акампанемент'		=> 'аккампанимент',
	'акліматызацыя'	=> 'аклиматизация',
	'аксіёма'			=> 'аксіома',
	'акумулятар'		=> 'аккумулятор',
	'амплітуда'			=> 'амплетуда',
	'анестэзія'			=> 'анастэзія',
	'апартаменты'		=> 'кватэра',
	'апарат'			=> 'аппарат',
	'апаратура'		=> 'аппаратура',
	'апеляцыя'			=> 'апэляцыя',
	'апендыцыт'		=> 'апендіцыт',
	'аранжоўка'		=> 'аранжыроўка',
	'асістэнт'			=> 'асістент',

	'барыкада'			=> 'барікада',
	'бландын'			=> 'бландзін',
	'бландынка'			=> 'бландзінка',
	'барацьба'			=> 'барба',
	'брашура'			=> 'брошура',
	'бюлетэнь'			=> 'бюлецень',

	'увесь'				=> 'весь',
	'погляд'			=> 'взгляд',
	'высокі'			=> 'высокій',

	'раздзел'				=> 'падзел',
	'гарыла'			=> 'гарылла',

	'дакумент'			=> 'дакмент',
	'дарога'			=> 'дорога',
	'іншы'			=> 'другой',

	'калі'				=> 'еслі',

	'загрузіць'			=> 'запампаваць',
	'загрузка'			=> 'запампоўка',

	'інжынер'			=> 'инжинер',
	'інцыдэнт'			=> 'инциндент',

	'камень'			=> 'камяні',
	'кампутар'			=> 'комп',
	'гарнітур'			=> 'убор',

	'названы'			=> 'названый',
	'нябачаны'		=> 'невиданый',
	'некалькі'			=> 'несколько',
	'нельга'			=> 'нельзя',
	'нечаканы'		=> 'неажыданы',
	'невропатолог'		=> 'нервопатолог',

	'перамяшчэнне'		=> 'перамяшчэнне',
	'паводзіны'			=> 'паведение',
	'пошук'				=> 'знаходжанне',
	'прыбор'			=> 'абсталяванне',
	'проста'			=> 'лёгка',
	'падарожжа'		=> 'паход',

	'развіццё'			=> 'развіціе',

	'выпадак'			=> 'случай',
	'паведамленне'			=> 'пост',
	'верш'		=> 'вершы',

	'танец'				=> 'скокі',
	'том'				=> 'раздзел',
	'цяжка'			=> 'складана',

	'прылада'		=> 'абсталяванне',

	'цэнтр'				=> 'ценцер',

	'шоў'				=> 'выступ',

	'энцыклапедыя'		=> 'энцыклапедзія',
	'эфект'			=> 'афект',
);
?>
