<?php
/** 
*
* ucp [Belarusian]
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
   exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Privacy policy and T&C
$lang = array_merge($lang, array(
	'TERMS_OF_USE_CONTENT'	=> 'Заходзячы на канферэнцыю «%1$s» (у далейшым «мы», «наш», «%1$s», «%2$s»), вы пацвярджаеце сваю згода са наступнымі ўмовамі. Калі вы не згодны з імі, калі ласка, не заходзіце і не карыстайцеся форумамі «%1$s». Мы пакідаем за сабою права змяняць гэтыя правілы ў любы час і зробім усё магчымае, каб апавясціць вас аб гэтым, аднак з вашага боку было бы разумным рэгулярна праглядаць гэты тэкст на прадмет змен, бо выкарыстанне канферэнцыі «%1$s» пасля абнаўлення/выпраўлення ўмоў азначае вашу згоду з імі.<br />
	<br />
	Нашы форумы працуюць пад кіраваннем праграмнага забеспячэння для стварэння канферэнцый phpBB (у далейшым «яны», «праграмнае забеспячэнне phpBB», «www.phpbb.com», «phpBB Group», «phpBB Teams»), выпушчанага па ліцэнзіі «<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>» (у далейшым «GPL»). Запампаваць яго можна па адрасе <a href="https://www.phpbb.com/">www.phpbb.com</a>. Абмежаванні ліцэнзіі GPL для праграмнага забеспячэння phpBB строга звязаныя з арганізацыяй і падтрымкай інтэрнэт-канферэнцый, і phpBB Group не нясе адказнасці за тое, што адміністрацыя канферэнцый вызначае ў якасці дапушчальнага зместа і/або паводзін у іх. За дадатковай інфармацыяй аб phpBB звяртайцеся па адрасе <a href="https://www.phpbb.com/">https://www.phpbb.com/</a>.<br />
	<br />
	Вы згаджаецеся не размяшчаць абразлівых, пагрозлівых, паклёпніцкіх паведамленняў, парнаграфічных паведамленняў, заклікаць да нацыянальнай розніцы і іншых паведамленняў, якія могуць парушыць законы вашай краіны, краіны, якая падае паслугі хостынгу для форумаў «%1$s», або міжнароднае права. Спробы размяшчэння такіх паведамленняў могуць прывесці да вашага неадкладнага адключэння ад канферэнцыі, пры гэтым ваш правайдэр будзе пастаўлены ў вядомасць, калі мы злічым гэта патрэбным. IP-адрасы ўсіх паведамленняў захоўваюцца для магчымасці правядзення такой палітыкі. Вы згаджаецеся з тым, што адміністратары форумаў «%1$s» маюць права выдаліць, адрэдагаваць, перанесці або зачыніць любую тэму ў любы час па сваім меркаванні. Як карыстальнік вы згодны з тым, што ўведзеная вамі інфармацыя будзе захоўвацца ў базе дадзеных. Хоць гэтая інфармацыя не будзе адчыненая трэцяй асобай без вашага дазволу, ні адміністрацыя канферэнцыі «%1$s», ні phpBB Group не можа быць адказная за дзеянні хакераў, якія могуць прывесці да несанкцыянаванага доступу да яе.
	',

	'PRIVACY_POLICY'		=> 'Гэтая дамова падрабязна тлумачыць, як «%1$s» і яго падпадзялення (у далейшым «мы», «наш», «%1$s», «%2$s») і phpBB (у далейшым «яны», «праграмнае забеспячэнне phpBB», «www.phpbb.com», «phpBB Group», «phpBB Teams») выкарыстаюць інфармацыю, атрыманую падчас любой з вашых карыстальніцкіх сесій (у далейшым «ваша інфармацыя»).<br />
	<br />
	Ваша інфармацыя збіраецца двума спосабамі. Па-першае, прагляд «%1$s» прывядзе да стварэння праграмным забеспячэннем phpBB вызначанага ліку "cookies" (невялікія тэкставыя файлы, загружаныя ў папку часовых файлаў вашага браўзэра). Першыя дзве "cookie" утрымоўваюць толькі ідэнтыфікатар карыстальніка (у далейшым «user-id») і ідэнтыфікатар ананімнай сесіі (у далейшым «session-id»), аўтаматычна прысвоеныя вам праграмным забеспячэннем phpBB. Трэцяя "cookie" будзе створаная пасля прагляду адной з тэм канферэнцыі «%1$s» і будзе выкарыстоўвацца для захоўвання інфармацыі аб прачытаных вамі тэмах, падвышаючы такім чынам выгоду працы з форумамі.<br />
	<br />
	Таксама, падчас прагляду канферэнцыі «%1$s», мы можам усталяваць cookies, знешнія па дачыненні да праграмнага забеспячэння phpBB, аднак яны выходзяць за рамкі гэтага дакумента, мэтай якога з\'яўляецца разгляд старонак, створаных выключна праграмным забеспячэннем phpBB. Другой крыніцай атрымання вашай інфармацыі з\'яўляюцца дадзеныя, якія вы адпраўляеце на форум. Гэтымі дадзенымі могуць быць, але не вычэрпваюцца, наступныя дадзеныя: паведамленні, размешчаныя пад уліковым запісам Госця (у далейшым «ананімныя паведамленні»), дадзеныя, паказаныя пры рэгістрацыі ў канферэнцыі «%1$s» (у далейшым «ваш уліковы запіс») і паведамленні, пакінутыя вамі пасля рэгістрацыі і аўтарызацыі (у далейшым «вашы паведамленні»).<br />
	<br />
	Ваш уліковы запіс будзе ўтрымоўваць, як мінімум, адназначна ідэнтыфікаванае імя (у далейшым «ваша імя карыстальніка»), індывідуальны пароль для ўваходу пад вашым уліковым запісам (далей «ваш пароль») і рэальны адрас email (у далейшым «ваш адрас email»). Ваша інфармацыя з вашага ўліковага запісу на форумах «%1$s» ахоўваецца законамі аб абароне кампутарнай інфармацыі, ужывальнымі ў краіне, якая прадстаўляе нам паслугі хостынгу. Любая інфармацыя, запытваемая пры рэгістрацыі ў канферэнцыі «%1$s», акрамя вашага імя карыстальніка, вашага пароля і вашага адрасу email, можа быць на наша меркаванне як неабходнай, так і неабавязковай да ўводу. У любым выпадку ў вас ёсць магчымасць вылучыць, якая інфармацыя з вашага ўліковага запісу будзе агульнадаступная. Акрамя таго, у вас ёсць магчымасць пагадзіцца/адмовіцца ад атрымання паведамленняў, аўтаматычна згенераваных праграмным забеспячэннем phpBB.<br />
	<br />
	Ваш пароль надзейна зашыфраваны (аднабаковым хэшаваннем). Аднак, не рэкамендуецца выкарыстаць гэты жа самы пароль, рэгіструючыся на іншых бачынах. Ваш пароль з\'яўляецца сродкам доступу да вашага ўліковага запісу на форумах «%1$s», калі ласка, захоўваеце яго ў таямніцы, не пры якіх акалічнасцях ні прадстаўнікі «%1$s», ні phpBB Group, ні іншая трэцяя асоба не ў праве пытаць ваш пароль. У выпадку, калі вы забудзеце ваш пароль да вашага ўліковага запісу, вы зможаце скарыстацца функцыяй аднаўлення пароля «Забылі пароль?», прадугледжанай праграмным забеспячэннем phpBB. Вам будзе неабходна ўвесці ваша імя карыстальніка і ваш адрас email, пасля чаго праграмнае забеспячэнне phpBB згенеруе вам новы пароль для вашага ўліковага запісу.<br />
	',
));

// Common language entries
$lang = array_merge($lang, array(
	'ACCOUNT_ACTIVE'				=> 'Ваш уліковы запіс быў актываваны. Дзякуй за рэгістрацыю.',
	'ACCOUNT_ACTIVE_ADMIN'			=> 'Ваш уліковы запіс быў актываваны.',
	'ACCOUNT_ACTIVE_PROFILE'		=> 'Ваш уліковы запіс паспяхова быў паўторна актываваны.',
	'ACCOUNT_ADDED'					=> 'Дзякуй за рэгістрацыю, уліковы запіс быў створаны. Вы можаце ўвайсці ў сістэму, выкарыстаючы ваша імя і пароль.',
	'ACCOUNT_COPPA'					=> 'Ваш уліковы запіс быў створаны, але зараз ён павінен быць ухвалены, больш падрабязная інфармацыя была высланая вам па email.',
	'ACCOUNT_EMAIL_CHANGED'			=> 'Ваш уліковы запіс быў абноўлены. Аднак, на гэтай канферэнцыі неабходна паўторна актываваць уліковы запіс пры змене адрасу e-mail. Ключ для актывавання быў адпраўлены на паказаны вамі новы адрас e-mail. Праверце сваю электронную пошту для атрымання больш падрабязнай інфармацыі.',
	'ACCOUNT_EMAIL_CHANGED_ADMIN'	=> 'Ваш уліковы запіс быў абноўлены. Аднак, на гэтай канферэнцыі неабходна паўторнае актываванне ўліковага запісу адміністратарам пры змене адрасу e-mail. Паведамленне e-mail было адпраўленае адміністратару. Вы будзеце апавешчаныя, калі ваш уліковы запіс будзе паўторна актываваны.',
	'ACCOUNT_INACTIVE'				=> 'Уліковы запіс быў створаны. Аднак, на гэтай канферэнцыі патрабуецца актывацыя ўліковага запісу, ключ для актывацыі быў высланы на ўведзены вамі адрас. Праверце сваю электронную пошту для атрымання больш падрабязнай інфармацыі.',
	'ACCOUNT_INACTIVE_ADMIN'		=> 'Уліковы запіс быў створаны. Аднак, на гэтай канферэнцыі патрабуецца актывацыя новага ўліковага запісу групай адміністратараў. Ім было адпраўленае паведамленне email. Вы будзеце апавешчаныя, калі ваш уліковы запіс будзе актываваная.',
	'ACTIVATION_EMAIL_SENT'			=> 'Ліст для актывацыі ўліковага запісу быў высланы на ваш адрас email.',
	'ACTIVATION_EMAIL_SENT_ADMIN'	=> 'Лісты для актывацыі ўліковага запісу былі высланыя на адрасы email адміністратараў.',
	'ADD'							=> 'Дадаць',
	'ADD_BCC'						=> 'Дадаць [Копія]',
	'ADD_FOES'						=> 'Дадаць новых злоснікаў',
	'ADD_FOES_EXPLAIN'				=> 'Вы можаце ўвесці некалькі імёнаў карыстальнікаў, кожнае на асобным радку.',
	'ADD_FOLDER'					=> 'Дадаць папку',
	'ADD_FRIENDS'					=> 'Дадаць новых сяброў',
	'ADD_FRIENDS_EXPLAIN'			=> 'Вы можаце ўвесці некалькі імёнаў карыстальнікаў, кожнае на асобным радку.',
	'ADD_NEW_RULE'					=> 'Дадаць новае правіла',
	'ADD_RULE'						=> 'Дадаць правіла',
	'ADD_TO'						=> 'Дадаць [Каму]',
	'ADD_USERS_UCP_EXPLAIN'			=> 'Тут вы можаце дадаваць новых карыстальнікаў у групу. Вы можаце выбраць, ці стане гэтая група групай па змоўчванні для дадання ў яе карыстальнікаў. Ўводзіце кожнае імя карыстальніка на асобным радку.',
	'ADMIN_EMAIL'					=> 'Атрымоўваць email-рассыланні адміністрацыі',
	'AGREE'							=> 'Я згодзен з гэтымі ўмовамі',
	'ALLOW_PM'						=> 'Дазволіць карыстальнікам пасылаць вам асабістыя паведамленні',
	'ALLOW_PM_EXPLAIN'				=> 'Улічыце, што адміністратары і мадэратары заўсёды змогуць пасылаць вам паведамлення.',
	'ALREADY_ACTIVATED'				=> 'Вы ўжо актывавалі свой уліковы запіс.',
	'ATTACHMENTS_EXPLAIN'			=> 'Гэта спіс укладанняў у паведамленнях, пакінутых на гэтай канферэнцыі.',
	'ATTACHMENTS_DELETED'			=> 'Укладанні паспяхова выдаленыя.',
	'ATTACHMENT_DELETED'			=> 'Укладанне паспяхова выдаленае.',
	'AVATAR_CATEGORY'				=> 'Катэгорыя',
	'AVATAR_EXPLAIN'				=> 'Максімальныя памеры ў піксэлах: шырыня - %1$d, вышыня - %2$d, памер файла - %3$.2f KiB.',
	'AVATAR_FEATURES_DISABLED'		=> 'Аватары ў цяперашні час адключаныя.',
	'AVATAR_GALLERY'				=> 'Галерэя аватар',
	'AVATAR_GENERAL_UPLOAD_ERROR'	=> 'Немагчыма запампаваць аватару ў %s.',
	'AVATAR_NOT_ALLOWED'			=> 'Ваша аватара не можа быць адлюстраваная, паколькі аватары забароненыя.',
	'AVATAR_PAGE'					=> 'Старонка',
	'AVATAR_TYPE_NOT_ALLOWED'		=> 'Ваша дзеючая аватара не можа быць адлюстраваная, паколькі яе тып забаронены.',

	'BACK_TO_DRAFTS'			=> 'Вярнуцца да захаваных чарнавікоў',
	'BACK_TO_LOGIN'				=> 'Вярнуцца на старонку ўваходу',
	'BIRTHDAY'					=> 'Дзень нараджэння',
	'BIRTHDAY_EXPLAIN'			=> 'Калі вы пакажаце год нараджэння, ваш узрост будзе адлюстроўвацца на форуме.',
	'BOARD_DATE_FORMAT'			=> 'Фармат даты',
	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Сінтаксіс ідэнтычны функцыі <a href="http://www.php.net/date">date()</a> мовы PHP.',
	'BOARD_DST'					=> 'Зараз дзейнічае летні час',
	'BOARD_LANGUAGE'			=> 'Мова',
	'BOARD_STYLE'				=> 'Стыль канферэнцыі',
	'BOARD_TIMEZONE'			=> 'Гадзінны пояс',
	'BOOKMARKS'					=> 'Закладкі',
	'BOOKMARKS_EXPLAIN'			=> 'Вы можаце дадаць дадзеную тэму ў закладкі для будучай звароты. Усталюйце сцяжок для любой закладкі, якую вы жадаеце выдаліць, затым націсніце кнопку <em>Выдаліць адзначаныя закладкі</em>.',
	'BOOKMARKS_DISABLED'		=> 'Закладкі на гэтай канферэнцыі адключаныя.',
	'BOOKMARKS_REMOVED'			=> 'Закладкі былі паспяхова выдаленыя.',

	'CANNOT_EDIT_MESSAGE_TIME'	=> 'Вы больш не можаце адрэдагаваць або выдаліць дадзенае паведамленне.',
	'CANNOT_MOVE_TO_SAME_FOLDER'=> 'Паведамленні не могуць быць перамешчаныя ў папку, якую вы збіраецеся выдаліць.',
	'CANNOT_MOVE_FROM_SPECIAL'	=> 'Паведамленні не могуць быць выдаленыя з папкі «Выходныя».',
	'CANNOT_RENAME_FOLDER'		=> 'Дадзеная папка не можа быць пераназваная.',
	'CANNOT_REMOVE_FOLDER'		=> 'Дадзеная папка не можа быць выдаленая.',
	'CHANGE_DEFAULT_GROUP'		=> 'Змяніць групу па змаўчанні',
	'CHANGE_PASSWORD'			=> 'Змяніць пароль',
	'CLICK_GOTO_FOLDER'			=> '%1$sПерайсці ў папку «%3$s»%2$s',
	'CLICK_RETURN_FOLDER'		=> '%1$sВернуться ў папку «%3$s»%2$s',
	'CONFIRMATION'				=> 'Пацверджанне рэгістрацыі',
	'CONFIRM_CHANGES'			=> 'Пацвердзіце змены',
	'CONFIRM_EMAIL'				=> 'Пацвердзіце email',
	'CONFIRM_EMAIL_EXPLAIN'		=> 'Паказвайце email толькі калі вы жадаеце яго памяняць.',
	'CONFIRM_EXPLAIN'			=> 'Для прадухілення аўтаматычных рэгістрацый на канферэнцыі патрабуецца ўвесці код пацверджання. Код паказаны на малюначку, якая находзіцца ніжэй. Калі вы не бачыце код на малюначку, то звернецеся да %sадминистратору%s.',
	'VC_REFRESH'				=> 'Абнавіць код пацверджання',
	'VC_REFRESH_EXPLAIN'		=> 'Калі немагчыма прачытаць дадзены код, вы можаце запытаць новы, націснуўшы на гэтую кнопку.',

	'CONFIRM_PASSWORD'			=> 'Пацвердзіце новы пароль',
	'CONFIRM_PASSWORD_EXPLAIN'	=> 'Паказвайце пароль толькі калі вы змянілі яго вышэй.',
	'COPPA_BIRTHDAY'			=> 'Для працягу рэгістрацыі, калі ласка, пакажыце дату нараджэння.',
	'COPPA_COMPLIANCE'			=> 'Згода па COPPA',
	'COPPA_EXPLAIN'				=> 'Улічыце, што ваш уліковы запіс будзе створаны пасля адпраўкі формы. Тым не менш, ён не будзе актываваны датуль, пакуль бацька або апякун не ўхваліць вашу рэгістрацыю. Вам будзе высланая копія email з неабходнай формай і ўказаннямі, куды яе трэба адправіць.',
	'CREATE_FOLDER'				=> 'Дадаць папку…',
	'CURRENT_IMAGE'				=> 'Дзеючы малюнак',
	'CURRENT_PASSWORD'			=> 'Дзеючы пароль',
	'CURRENT_PASSWORD_EXPLAIN'	=> 'Вы павінны паказаць дзеючы пароль, калі вы жадаеце змяніць імя карыстальніка або адрас email.',
	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'Вы павінны паказаць дзеючы пароль, калі вы жадаеце змяніць пароль, імя карыстальніка або адрас email.',
	'CUR_PASSWORD_EMPTY'		=> 'Вы не ўвялі свой дзеючы пароль.',
	'CUR_PASSWORD_ERROR'		=> 'Уведзены вамі пароль не супадае з дзеючым паролем',
	'CUSTOM_DATEFORMAT'			=> 'Іншы…',

	'DEFAULT_ACTION'			=> 'Дзеянне па змаўчанні',
	'DEFAULT_ACTION_EXPLAIN'	=> 'Гэтае дзеянне будзе выканана, калі не адно з вышэйпаказаных правілаў не можа быць ужыта.',
	'DEFAULT_ADD_SIG'			=> 'Заўсёды далучаць мой подпіс',
	'DEFAULT_BBCODE'			=> 'BBCode заўсёды ўключаны',
	'DEFAULT_NOTIFY'			=> 'Заўсёды паведамляць мне аб адказах',
	'DEFAULT_SMILIES'			=> 'Смайлікі заўсёды ўключаныя',
	'DEFINED_RULES'				=> 'Вызначаныя правілы',
	'DELETED_TOPIC'				=> 'Тэма была выдаленая.',
	'DELETE_ATTACHMENT'			=> 'Выдаліць укладанне',
	'DELETE_ATTACHMENTS'		=> 'Выдаліць укладанні',
	'DELETE_ATTACHMENT_CONFIRM'	=> 'Вы ўпэўненыя, што жадаеце выдаліць дадзенае ўкладанне?',
	'DELETE_ATTACHMENTS_CONFIRM'=> 'Вы ўпэўненыя, што жадаеце выдаліць дадзеныя ўкладанні?',
	'DELETE_AVATAR'				=> 'Выдаліць малюнак',
	'DELETE_COOKIES_CONFIRM'	=> 'Вы ўпэўненыя, што жадаеце выдаліць усё cookie, усталяваныя дадзеным форумам?',
	'DELETE_MARKED_PM'			=> 'Выдаліць адзначаныя',
	'DELETE_MARKED_PM_CONFIRM'	=> 'Вы ўпэўненыя, што жадаеце выдаліць усе адзначаныя паведамленні?',
	'DELETE_OLDEST_MESSAGES'	=> 'Выдаліць самыя старыя паведамленні',
	'DELETE_MESSAGE'			=> 'Выдаліць паведамленне',
	'DELETE_MESSAGE_CONFIRM'	=> 'Вы ўпэўненыя, што жадаеце выдаліць дадзенае паведамленне?',
	'DELETE_MESSAGES_IN_FOLDER'	=> 'Выдаліць усе паведамленні, якія ўтрымоўваюцца ў выдаляемай папцы',
	'DELETE_RULE'				=> 'Выдаліць правіла',
	'DELETE_RULE_CONFIRM'		=> 'Вы ўпэўненыя, што жадаеце выдаліць дадзенае правіла?',
	'DEMOTE_SELECTED'			=> 'Адмовіцца ад лідэрства',
	'DISABLE_CENSORS'			=> 'Дазволіць аўтацэнзар',
	'DISPLAY_GALLERY'			=> 'Паказаць галерэю',
	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Уведзены дамен email не мае карэктнага паштовага запісу ў DNS (MX запіс).',
	'DOWNLOADS'					=> 'Запампоўкі',
	'DRAFTS_DELETED'			=> 'Усе адзначаныя чарнавікі былі паспяхова выдаленыя.',
	'DRAFTS_EXPLAIN'			=> 'Тут вы можаце праглядзець, адрэдагаваць і выдаліць вашы захаваныя чарнавікі.',
	'DRAFT_UPDATED'				=> 'Чарнавік быў паспяхова абноўлены.',

	'EDIT_DRAFT_EXPLAIN'		=> 'Тут вы можаце рэдагаваць чарнавік. Чарнавікі не ўтрымоўваюць укладанняў і апытанняў.',
	'EMAIL_BANNED_EMAIL'		=> 'Уведзены адрас email забаронены да выкарыстання.',
	'EMAIL_REMIND'				=> 'Адрас email, звязаны з вашым уліковым запісам. Калі вы не змянілі яго ў Асабістым раздзеле, то гэта адрас e-mail, паказаны вамі пры рэгістрацыі.',
	'EMAIL_TAKEN_EMAIL'			=> 'Уведзены адрас email ужо выкарыстоўваецца іншым карыстальнікам.',
	'EMPTY_DRAFT'				=> 'Вы павінны ўвесці паведамленне, каб пацвердзіць змены.',
	'EMPTY_DRAFT_TITLE'			=> 'Вы павінны ўвесці назоў чарнавіка.',
	'EXPORT_AS_XML'				=> 'Экспарт у XML',
	'EXPORT_AS_CSV'				=> 'Экспарт у CSV',
	'EXPORT_AS_CSV_EXCEL'		=> 'Экспарт у CSV (Excel)',
	'EXPORT_AS_TXT'				=> 'Экспарт у TXT',
	'EXPORT_AS_MSG'				=> 'Экспарт у MSG',
	'EXPORT_FOLDER'				=> 'Гэты спіс',

	'FIELD_REQUIRED'					=> 'Не запоўнена поле «%s».',
	'FIELD_TOO_SHORT'					=> 'Значэнне поля «%1$s» занадта кароткае, мінімальна дапушчальная даўжыня складае %2$d знакаў.',
	'FIELD_TOO_LONG'					=> 'Значэнне поля «%1$s» занадта доўгае, максімальна дапушчальная даўжыня складае %2$d знакаў.',
	'FIELD_TOO_SMALL'					=> 'Значэнне поля «%1$s» занадта маленькае, мінімальна дапушчальным значэннем з\'яўляецца %2$d.',
	'FIELD_TOO_LARGE'					=> 'Значэнне поля «%1$s» занадта вялікае, максімальна дапушчальным значэннем з\'яўляецца %2$d.',
	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Поле «%s» утрымоўвае недапушчальныя знакі, дазволеныя толькі лічбы.',
	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Поле «%s» утрымоўвае недапушчальныя знакі, дазволеныя толькі літарна-лічбавыя знакі.',
	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Поле «%s» утрымоўвае недапушчальныя знакі, дазволеныя толькі літарна-лічбавыя знакі, прабелы, а таксама знакі -+_[].',
	'FIELD_INVALID_DATE'				=> 'Поле «%s» змяшчае недапушчальную дату.',
	'FIELD_INVALID_VALUE'				=> 'Поле «%s» змяшчае недапушчальнае значэнне.',

	'FOE_MESSAGE'				=> 'Паведамленне ад злосніка',
	'FOES_EXPLAIN'				=> 'Злоснікі - гэта карыстальнікі, якія будуць ігнаравацца па змаўчанні. Паведамленні гэтых карыстальнікаў будуць утоеныя. Аднак, асабістыя паведамленні ад злоснікаў дазволеныя. Улічыце, што вы не можаце ігнараваць мадэратараў або адміністратараў.',
	'FOES_UPDATED'				=> 'Спіс злоснікаў быў паспяхова абноўлены.',
	'FOLDER_ADDED'				=> 'Папка была паспяхова дададзеная.',
	'FOLDER_MESSAGE_STATUS'		=> '%1$d з %2$d паведамленняў',
	'FOLDER_NAME_EMPTY'			=> 'Неабходна ўвесці імя для гэтай папкі.',
	'FOLDER_NAME_EXIST'			=> 'Папка <strong>%s</strong> ужо існуе.',
	'FOLDER_OPTIONS'			=> 'Уласцівасці папкі',
	'FOLDER_RENAMED'			=> 'Папка была паспяхова пераназваная.',
	'FOLDER_REMOVED'			=> 'Папка была паспяхова выдаленая.',
	'FOLDER_STATUS_MSG'			=> 'Папка запоўненая на %1$d%% (%2$d з %3$d паведамленняў)',
	'FORWARD_PM'				=> 'Пераслаць АП',
	'FORCE_PASSWORD_EXPLAIN'	=> 'Для далейшага выкарыстання канферэнцыі вам неабходна змяніць свой пароль.',
	'FRIEND_MESSAGE'			=> 'Паведамленне ад сябра',
	'FRIENDS'					=> 'Сябры',
	'FRIENDS_EXPLAIN'			=> 'Спіс сяброў дазваляе вам атрымаць хуткі доступ да карыстальнікаў, з якімі вы часта маеце зносіны. Пры наяўнасці адпаведнай падтрымкі ў стылю форума, усё паведамленні вашых сяброў будуць вылучаныя пры праглядзе.',
	'FRIENDS_OFFLINE'			=> 'Не ў сеткі',
	'FRIENDS_ONLINE'			=> 'У сеткі',
	'FRIENDS_UPDATED'			=> 'Спіс сяброў быў паспяхова абноўлены.',
	'FULL_FOLDER_OPTION_CHANGED'=> 'Дзеянне, выконваемае ў выпадку перапаўнення папкі, зменена.',
	'FWD_ORIGINAL_MESSAGE'		=> '-------- Зыходнае паведамленне --------',
	'FWD_SUBJECT'				=> 'Тэма: %s',
	'FWD_DATE'					=> 'Дата: %s',
	'FWD_FROM'					=> 'Ад: %s',
	'FWD_TO'					=> 'Каму: %s',

	'GLOBAL_ANNOUNCEMENT'		=> 'Важная',

	'HIDE_ONLINE'				=> 'Хаваць маё знаходжанне на канферэнцыі',
	'HIDE_ONLINE_EXPLAIN'		=> 'Змена налады ўступіць у сілу толькі са наступнага наведвання канферэнцыі.',
	'HOLD_NEW_MESSAGES'			=> 'Не прымаць новыя паведамленні (новыя паведамленні будуць адкладзеныя да з\'яўлення дастатковай колькасці вольнага месца)',
	'HOLD_NEW_MESSAGES_SHORT'	=> 'Новыя паведамленні будуць адкладзеныя',

	'IF_FOLDER_FULL'			=> 'Калі папка запоўненая',
	'IMPORTANT_NEWS'			=> 'Важныя аб\'явы',
	'INVALID_USER_BIRTHDAY'			=> 'Няверная дата дня нараджэння.',
	'INVALID_CHARS_USERNAME'	=> 'Імя карыстальніка ўтрымоўвае забароненыя знакі.',
	'INVALID_CHARS_NEW_PASSWORD'=> 'Пароль не ўтрымоўвае патрабаваных знакаў.',
	'ITEMS_REQUIRED'			=> 'Палі вашага профіля адзначаныя * абавязковыя да запаўнення.',

	'JOIN_SELECTED'				=> 'Уступіць у вылучаную',

	'LANGUAGE'					=> 'Мова',
	'LINK_REMOTE_AVATAR'		=> 'Знешняя спасылка',
	'LINK_REMOTE_AVATAR_EXPLAIN'=> 'Увядзіце URL, па якім находзіцца файл з малюнкам, ён будзе скарыстаны ў якасці вашай аватары.',
	'LINK_REMOTE_SIZE'			=> 'Памеры аватары',
	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'Пакажыце вышыню і шырыню аватары або пакіньце палі пустымі для іх аўтаматычнай праверкі.',
	'LOGIN_EXPLAIN_UCP'			=> 'Калі ласка, аўтарызуйцеся для ўваходу ў ваш асабісты раздзел.',
	'LOGIN_REDIRECT'			=> 'Вы паспяхова ўвайшлі ў сістэму.',
	'LOGOUT_FAILED'				=> 'Вы не вышлі з канферэнцыі, бо запыт не адпавядаў параметрам вашай сесіі. Звяжыцеся з адміністратарам канферэнцыі, калі праблема паўторыцца.',
	'LOGOUT_REDIRECT'			=> 'Вы паспяхова вышлі з сістэмы.',

	'MARK_IMPORTANT'				=> 'Пазначыць / зняць пазнаку',
	'MARKED_MESSAGE'				=> 'Пазначанае паведамленне',
	'MAX_FOLDER_REACHED'			=> 'Дасягнута максімальная колькасць карыстальніцкіх папак.',
	'MESSAGE_BY_AUTHOR'				=> '',
	'MESSAGE_COLOURS'				=> 'Колеры паведамленняў',
	'MESSAGE_DELETED'				=> 'Паведамленне паспяхова выдаленае.',
	'MESSAGE_EDITED'				=> 'Паведамленне паспяхова адрэдагаванае.',
	'MESSAGE_HISTORY'				=> 'Гісторыя паведамленняў',
	'MESSAGE_REMOVED_FROM_OUTBOX'	=> 'Аўтар выдаліў гэтае паведамленне.',
	'MESSAGE_SENT_ON'				=> 'ад',
	'MESSAGE_STORED'				=> 'Ваша паведамленне паспяхова адпраўленае.',
	'MESSAGE_TO'					=> 'Каму',
	'MESSAGES_DELETED'				=> 'Паведамленні паспяхова выдаленыя',
	'MOVE_DELETED_MESSAGES_TO'		=> 'Перамясціць паведамленні з выдаляемай папкі ў папку',
	'MOVE_DOWN'						=> 'Ссунуць уніз',
	'MOVE_MARKED_TO_FOLDER'			=> 'Перамясціць адзначаныя ў папку %s',
	'MOVE_PM_ERROR'					=> 'Падчас перамяшчэння паведамленняў у новую папку адбылася памылка, перанесена паведамленняў: %1d з %2d.',
	'MOVE_TO_FOLDER'				=> 'Перамясціць у папку',
	'MOVE_UP'						=> 'Ссунуць уверх',

	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Вы не ўвялі пацверджанне адрасу email.',
	'NEW_EMAIL_ERROR'				=> 'Уведзеныя вамі адрасы email не супадаюць.',
	'NEW_FOLDER_NAME'				=> 'Новае імя папкі',
	'NEW_PASSWORD'					=> 'Новы пароль',
	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Вы не ўвялі пацверджанне пароля.',
	'NEW_PASSWORD_ERROR'			=> 'Уведзеныя вамі паролі не супадаюць.',
	'NOTIFY_METHOD'					=> 'Спосаб апавяшчэння',
	'NOTIFY_METHOD_BOTH'			=> 'Абодва спосабу',
	'NOTIFY_METHOD_EMAIL'			=> 'Толькі email',
	'NOTIFY_METHOD_EXPLAIN'			=> 'Сродак адпраўкі паведамленняў, пасыланых гэтымі форумамі.',
	'NOTIFY_METHOD_IM'				=> 'Толькі Jabber',
	'NOTIFY_ON_PM'					=> 'Апавяшчаць мяне аб новых асабістых паведамленнях',
	'NOT_ADDED_FRIENDS_ANONYMOUS'	=> 'Вы не можаце дадаць госця ў спіс сяброў.',
	'NOT_ADDED_FRIENDS_BOTS'		=> 'Вы не можаце дадаць бота ў спіс сяброў.',
	'NOT_ADDED_FRIENDS_FOES'		=> 'Вы не можаце дадаваць карыстальнікаў з спісу злоснікаў у спіс сяброў.',
	'NOT_ADDED_FRIENDS_SELF'		=> 'Вы не можаце дадаць самога сябе ў спіс сяброў.',
	'NOT_ADDED_FOES_MOD_ADMIN'		=> 'Вы не можаце дадаваць адміністратараў і мадэратараў у спіс злоснікаў.',
	'NOT_ADDED_FOES_ANONYMOUS'		=> 'Вы не можаце дадаць госця ў спіс злоснікаў.',
	'NOT_ADDED_FOES_BOTS'			=> 'Вы не можаце дадаць бота ў спіс злоснікаў.',
	'NOT_ADDED_FOES_FRIENDS'		=> 'Вы не можаце дадаваць карыстальнікаў з спісу сяброў у спіс злоснікаў.',
	'NOT_ADDED_FOES_SELF'			=> 'Вы не можаце дадаць самога сябе ў спіс злоснікаў.',
	'NOT_AGREE'						=> 'Я не згодзен з гэтымі ўмовамі',
	'NOT_ENOUGH_SPACE_FOLDER'		=> 'Папка-атрымальнік «%s» запоўненая. Запытанае дзеянне не было выканана.',
	'NOT_MOVED_MESSAGE'				=> 'Папка з вашымі асабістымі паведамленнямі запоўненая. Адкладзеных паведамленняў: 1.',
	'NOT_MOVED_MESSAGES'			=> 'Папка з вашымі асабістымі паведамленнямі запоўненая. Адкладзеных паведамленняў: %d.',
	'NO_ACTION_MODE'				=> 'Не вылучана дзеянне для паведамлення.',
	'NO_AUTHOR'						=> 'Не паказаны аўтар паведамлення',
	'NO_AVATAR_CATEGORY'			=> 'Не',

	'NO_AUTH_DELETE_MESSAGE'		=> 'У вас няма доступу да выдалення асабістых паведамленняў.',
	'NO_AUTH_EDIT_MESSAGE'			=> 'У вас няма доступу да рэдагавання асабістых паведамленняў.',
	'NO_AUTH_FORWARD_MESSAGE'		=> 'У вас няма доступу да перасылання асабістых паведамленняў.',
	'NO_AUTH_GROUP_MESSAGE'			=> 'У вас няма доступу да адпраўкі асабістых паведамленняў у групы.',
	'NO_AUTH_PASSWORD_REMINDER'		=> 'У вас няма доступу да атрымання новага пароля.',
	'NO_AUTH_READ_HOLD_MESSAGE'		=> 'У вас няма доступу да чытання адкладзеных асабістых паведамленняў.',
	'NO_AUTH_READ_MESSAGE'			=> 'У вас няма доступу да чытання асабістых паведамленняў.',
	'NO_AUTH_READ_REMOVED_MESSAGE'	=> 'Вы не можаце прачытаць гэтае паведамленне, таму што яно было выдаленае яго аўтарам.',
	'NO_AUTH_SEND_MESSAGE'			=> 'У вас няма доступу да адпраўкі асабістых паведамленняў.',
	'NO_AUTH_SIGNATURE'				=> 'У вас няма доступу да рэдагавання подпісу.',

	'NO_BCC_RECIPIENT'			=> 'Не',
	'NO_BOOKMARKS'				=> 'У вас няма закладак.',
	'NO_BOOKMARKS_SELECTED'		=> 'Вы не адзначылі закладкі.',
	'NO_EDIT_READ_MESSAGE'		=> 'Асабістае паведамленне не можа быць адрэдагавана, бо ўжо было прачытана.',
	'NO_EMAIL_USER'				=> 'Уведзеная інфармацыя аб email/імя карыстальніка не знойдзеная.',
	'NO_FOES'					=> 'Спіс злоснікаў пусты',
	'NO_FRIENDS'				=> 'Спіс сяброў пусты',
	'NO_FRIENDS_OFFLINE'		=> 'Няма сяброў па-за сеткай',
	'NO_FRIENDS_ONLINE'			=> 'Няма сяброў у сеткі',
	'NO_GROUP_SELECTED'			=> 'Група не вылучаная.',
	'NO_IMPORTANT_NEWS'			=> 'Няма важных аб\'яў.',
	'NO_MESSAGE'				=> 'Асабістае паведамленне не знойдзена.',
	'NO_NEW_FOLDER_NAME'		=> 'Вы павінны паказаць новае імя папкі.',
	'NO_NEWER_PM'				=> 'Няма новых паведамленняў.',
	'NO_OLDER_PM'				=> 'Няма старых паведамленняў.',
	'NO_PASSWORD_SUPPLIED'		=> 'Вы не можаце ўвайсці без пароля.',
	'NO_RECIPIENT'				=> 'Атрымальнік паведамлення не вылучаны.',
	'NO_RULES_DEFINED'			=> 'Правілаў не ўсталявана.',
	'NO_SAVED_DRAFTS'			=> 'Няма захаваных чарнавікоў.',
	'NO_TO_RECIPIENT'			=> 'Не',
	'NO_WATCHED_FORUMS'			=> 'Вы не падпісаныя на якія-небудзь форумы.',
	'NO_WATCHED_SELECTED'		=> 'Вы не вылучылі тэм або форумаў, на якія падпісаныя.',
	'NO_WATCHED_TOPICS'			=> 'Вы не падпісаныя на якія-небудзь тэмы.',

	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Пароль павінен быць даўжынёй ад %1$d да %2$d знакаў, утрымоўваць літары розных рэгістраў і лічбы.',
	'PASS_TYPE_ANY_EXPLAIN'		=> 'Павінен быць даўжынёй ад %1$d да %2$d знакаў.',
	'PASS_TYPE_CASE_EXPLAIN'	=> 'Пароль павінен быць даўжынёй ад %1$d да %2$d знакаў і ўтрымоўваць літары розных рэгістраў.',
	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Пароль павінен быць даўжынёй ад %1$d да %2$d знакаў і ўтрымоўваць літары розных рэгістраў, лічбы і знакі.',
	'PASSWORD'					=> 'Пароль',
	'PASSWORD_ACTIVATED'		=> 'Ваш новы пароль актываваны.',
	'PASSWORD_UPDATED'			=> 'Ваш новы пароль паспяхова адпраўлены на ваш адрас email.',
	'PERMISSIONS_RESTORED'		=> 'Вашы правы доступу адноўленыя.',
	'PERMISSIONS_TRANSFERRED'	=> 'Імітацыя мае рацыю доступу, усталяваных для <strong>%s</strong>, паспяхова праведзеная. Зараз вы  можаце праглядаць канферэнцыю з абмежаваннямі, усталяванымі для дадзенага карыстальніка.<br />Калі ласка, падушыце, што правы адміністратара адключаныя. Вы можаце перапыніць імітацыю ў любы час.',
	'PM_DISABLED'				=> 'Асабістыя паведамленні на гэтай канферэнцыі адключаныя.',
	'PM_FROM'					=> 'Ад',
	'PM_FROM_REMOVED_AUTHOR'	=> 'Гэтае паведамленне ад ужо незарэгістраванага карыстальніка.',
	'PM_ICON'					=> 'Значок АП',
	'PM_INBOX'					=> 'Уваходныя',
	'PM_NO_USERS'				=> 'Запытваемыя для дадання карыстальнікі не існуюць.',
	'PM_OUTBOX'					=> 'Выходныя',
	'PM_SENTBOX'				=> 'Адпраўленыя',
	'PM_SUBJECT'				=> 'Тэма паведамлення',
	'PM_TO'						=> 'Каму',
	'PM_USERS_REMOVED_NO_PM'	=> 'Некаторыя карыстальнікі не могуць быць дададзеныя, бо яны адключылі атрыманне асабістых паведамленняў.',
	'POPUP_ON_PM'				=> 'Усплывальнае акно пры атрыманні асабістага паведамлення',
	'POST_EDIT_PM'				=> 'Рэдагаваць',
	'POST_FORWARD_PM'			=> 'Пераслаць',
	'POST_NEW_PM'				=> 'Стварыць паведамленне',
	'POST_PM_LOCKED'			=> 'Асабістае паведамленне заблакаванае.',
	'POST_PM_POST'				=> 'Цытаваць',
	'POST_QUOTE_PM'				=> 'Цытаваць паведамленне',
	'POST_REPLY_PM'				=> 'Адказаць',
	'PRINT_PM'					=> 'Для друку',
	'PREFERENCES_UPDATED'		=> 'Вашы налады абноўленыя.',
	'PROFILE_INFO_NOTICE'		=> 'Калі ласка, падушыце, што гэтая інфармацыя можа быць даступная іншым карыстальнікам. Будзьце асцярожныя пры выбары паказваных персанальных дадзеных. Любыя палі, пазначаныя * павінны быць запоўненыя.',
	'PROFILE_UPDATED'			=> 'Ваш профіль абноўлены.',

	'RECIPIENT'							=> 'Атрымальнік',
	'RECIPIENTS'						=> 'Атрымальнікі',
	'REGISTRATION'						=> 'Рэгістрацыя',
	'RELEASE_MESSAGES'					=> '%sДобавить усе адкладзеныя паведамленні%s… якія будуць рассартыраваныя ў адпаведнай папцы пры наяўнасці вольнага месца',
	'REMOVE_ADDRESS'					=> 'Выдаліць адрас',
	'REMOVE_SELECTED_BOOKMARKS'			=> 'Выдаліць вылучаныя закладкі',
	'REMOVE_SELECTED_BOOKMARKS_CONFIRM'	=> 'Вы ўпэўненыя, што жадаеце выдаліць усе вылучаныя закладкі?',
	'REMOVE_BOOKMARK_MARKED'			=> 'Выдаліць адзначаныя закладкі',
	'REMOVE_FOLDER'						=> 'Выдаліць папку',
	'REMOVE_FOLDER_CONFIRM'				=> 'Вы ўпэўненыя, што жадаеце выдаліць гэтую папку?',
	'RENAME'							=> 'Пераназваць',
	'RENAME_FOLDER'						=> 'Пераназваць папку',
	'REPLIED_MESSAGE'					=> 'Адказаныя паведамленні',
	'REPLY_TO_ALL'						=> 'Адказ адпраўшчыку і ўсім атрымальнікам.',
	'REPORT_PM'							=> 'Паскардзіцца на асабістае паведамленне',
	'RESIGN_SELECTED'					=> 'Пакінуць вылучаную',
	'RETURN_FOLDER'						=> '%1$sВернуться ў папярэднюю папку%2$s',
	'RETURN_UCP'						=> '%sВернуться ў асабісты раздзел%s',
	'RULE_ADDED'						=> 'Правіла паспяхова дададзена.',
	'RULE_ALREADY_DEFINED'				=> 'Такое правіла ўжо было дададзена раней.',
	'RULE_DELETED'						=> 'Правіла паспяхова выдаленае.',
	'RULE_LIMIT_REACHED'				=> 'Немагчыма дадаць правіла, паколькі дасягнута максімальна магчымае колькасць правілаў.',
	'RULE_NOT_DEFINED'					=> 'Правіла паказана некарэктна.',
	'RULE_REMOVED_MESSAGE'				=> 'Фільтрамі АП было выдаленае асабістых паведамленняў: 1',
	'RULE_REMOVED_MESSAGES'				=> 'Фільтрамі АП было выдаленае асабістых паведамленняў: %d',

	'SAME_PASSWORD_ERROR'		=> 'Уведзены вамі новы пароль супадае з вашым дзеючым.',
	'SEARCH_YOUR_POSTS'			=> 'Паказаць вашы паведамленні',
	'SEND_PASSWORD'				=> 'Адправіць пароль',
	'SENT_AT'					=> 'Адпраўленае',
	'SHOW_EMAIL'				=> 'Паказваць мой адрас email',
	'SIGNATURE_EXPLAIN'			=> 'Гэта тэкст, які можа аўтаматычна дадавацца да вашых паведамленняў. Максімальная даўжыня ў знаках: %d.',
	'SIGNATURE_PREVIEW'			=> 'Ваш подпіс у паведамленнях будзе выглядаць так',
	'SIGNATURE_TOO_LONG'		=> 'Вы ўвялі занадта доўгі подпіс.',
	'SORT'						=> 'Сартаваць',
	'SORT_COMMENT'				=> 'Каментары',
	'SORT_DOWNLOADS'			=> 'Запампоўкі',
	'SORT_EXTENSION'			=> 'Пашырэнне',
	'SORT_FILENAME'				=> 'Імя файла',
	'SORT_POST_TIME'			=> 'Час',
	'SORT_SIZE'					=> 'Памер',

	'TIMEZONE'					=> 'Гадзінны пояс',
	'TO'						=> 'Каму',
	'TOO_MANY_RECIPIENTS'		=> 'Вы паспрабавалі адправіць асабістае паведамленне занадта вялікай колькасці атрымальнікаў.',
	'TOO_MANY_REGISTERS'		=> 'Вы вычарпалі лімітавую колькасць спроб рэгістрацыі для дадзенай сесіі. Паўторыце спробу пазней.',

	'UCP'						=> 'Асабісты раздзел',
	'UCP_ACTIVATE'				=> 'Актываваць уліковы запіс',
	'UCP_ADMIN_ACTIVATE'		=> 'Звернеце ўвагу на тое, што вы павінны ўвесці правільны адрас электроннай пошты перад актывацыяй. Адміністратар праверыць ваш уліковы запіс і адправіць на паказаны адрас ліст, якb змяшчае спасылку для актывацыі ўліковага запісу.',
	'UCP_AIM'					=> 'AIM',
	'UCP_ATTACHMENTS'			=> 'Укладанні',
	'UCP_COPPA_BEFORE'			=> 'Да %s',
	'UCP_COPPA_ON_AFTER'		=> '%s і пасля',
	'UCP_EMAIL_ACTIVATE'		=> 'Звернеце ўвагу на тое, што вы павінны ўвесці правільны адрас электроннай пошты перад актывацыяй. На паказаны вамі адрас прыйдзе ліст, які змяшчае спасылку для актывацыі ўліковага запісу.',
	'UCP_ICQ'					=> 'ICQ',
	'UCP_JABBER'				=> 'Jabber',

	'UCP_MAIN'					=> 'Агляд',
	'UCP_MAIN_ATTACHMENTS'		=> 'Укладанні',
	'UCP_MAIN_BOOKMARKS'		=> 'Закладкі',
	'UCP_MAIN_DRAFTS'			=> 'Чарнавікі',
	'UCP_MAIN_FRONT'			=> 'Пачатак',
	'UCP_MAIN_SUBSCRIBED'		=> 'Падпіскі',

	'UCP_MSNM'					=> 'WL/MSN Messenger',
	'UCP_NO_ATTACHMENTS'		=> 'Вы не стварылі не аднаго ўкладанні.',

	'UCP_PREFS'					=> 'Асабістыя налады',
	'UCP_PREFS_PERSONAL'		=> 'Агульныя налады',
	'UCP_PREFS_POST'			=> 'Адпраўка паведамленняў',
	'UCP_PREFS_VIEW'			=> 'Налады адлюстравання',

	'UCP_PM'					=> 'Асабістыя паведамленні',
	'UCP_PM_COMPOSE'			=> 'Новае паведамленне',
	'UCP_PM_DRAFTS'				=> 'Кіраванне чарнавікамі',
	'UCP_PM_OPTIONS'			=> 'Правілы, папкі і налады',
	'UCP_PM_POPUP'				=> 'Асабістыя паведамленні',
	'UCP_PM_POPUP_TITLE'		=> 'Усплывальнае акно аб новым асабістым паведамленні',
	'UCP_PM_UNREAD'				=> 'Непрачытаныя паведамленні',
	'UCP_PM_VIEW'				=> 'Прагляд паведамленняў',

	'UCP_PROFILE'				=> 'Профіль',
	'UCP_PROFILE_AVATAR'		=> 'Аватара',
	'UCP_PROFILE_PROFILE_INFO'	=> 'Асабістыя дадзеныя',
	'UCP_PROFILE_REG_DETAILS'	=> 'Рэгістрацыйныя дадзеныя',
	'UCP_PROFILE_SIGNATURE'		=> 'Подпіс',

	'UCP_USERGROUPS'			=> 'Групы',
	'UCP_USERGROUPS_MEMBER'		=> 'Удзел у групах',
	'UCP_USERGROUPS_MANAGE'		=> 'Кіраванне групамі',

	'UCP_REGISTER_DISABLE'			=> 'Стварэнне новага ўліковага запісу на дзеючы момант немагчыма.',
	'UCP_REMIND'					=> 'Адправіць пароль',
	'UCP_RESEND'					=> 'Паслаць ліст для актывацыі ўліковага запісу',
	'UCP_WELCOME'					=> 'Сардэчна запрашаем у ваш асабісты раздзел. Адгэтуль вы можаце праглядаць і змяняць налады, інфармацыю аб сабе і падпіску на форумы і тэмы. Таксама, калі вам гэта дазволена, вы можаце пасылаць асабістыя паведамленні (АП) іншым карыстальнікам. Перад тым як працягнуць, упэўніцеся, што вы прачыталі ўсе аб\'явы адміністрацыі.',
	'UCP_YIM'						=> 'Yahoo Messenger',
	'UCP_ZEBRA'						=> 'Сябры і злоснікі',
	'UCP_ZEBRA_FOES'				=> 'Спіс злоснікаў',
	'UCP_ZEBRA_FRIENDS'				=> 'Спіс сяброў',
 	'UNDISCLOSED_RECIPIENT'			=> 'Невядомы атрымальнік',
	'UNKNOWN_FOLDER'				=> 'Невядомая папка',
	'UNWATCH_MARKED'				=> 'Адпісацца ад вылучанага',
	'UPLOAD_AVATAR_FILE'			=> 'Загрузіць з вашага кампутара',
	'UPLOAD_AVATAR_URL'				=> 'Загрузіць з URL',
	'UPLOAD_AVATAR_URL_EXPLAIN'		=> 'Увядзіце URL па якім находзіцца файл з малюнкам. Яно будзе скапіявана на гэтую бачыну.',
	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Імя карыстальніка павінна быць ад %1$d да %2$d знакаў і павінна ўтрымоўваць толькі літары.',
	'USERNAME_ALPHA_SPACERS_EXPLAIN'=> 'Імя карыстальніка павінна быць ад %1$d да %2$d знакаў і павінна ўтрымоўваць толькі літары, прабел або знакі -+_[]',
	'USERNAME_ASCII_EXPLAIN'		=> 'Імя карыстальніка павінна быць ад %1$d да %2$d знакаў і павінна ўтрымоўваць толькі знакі ASCII, без адмысловых знакаў.',
	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'Імя карыстальніка павінна быць ад %1$d да %2$d знакаў і павінна ўтрымоўваць толькі літары або лічбы.',
	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'=> 'Імя карыстальніка павінна быць ад %1$d да %2$d знакаў і павінна ўтрымоўваць толькі літары, лічбы, прабел або знакі -+_[]',
	'USERNAME_CHARS_ANY_EXPLAIN'	=> 'Імя карыстальніка павінна быць ад %1$d і да %2$d знакаў.',
	'USERNAME_TAKEN_USERNAME'		=> 'Выбачайце, карыстальнік з такім імем ужо існуе',
	'USERNAME_DISALLOWED_USERNAME'	=> 'Уведзенае вамі імя карыстальніка было забароненае або ўтрымоўвае забароненае слова. Вылучыце іншае імя.',
	'USER_NOT_FOUND_OR_INACTIVE'	=> 'Уведзенае вамі імя карыстальніка не знойдзена, альбо дадзены карыстальнік яшчэ не прайшоў працэдуру актывацыі.',

	'VIEW_AVATARS'				=> 'Паказваць аватары',
	'VIEW_EDIT'					=> 'Праглядзець/змяніць',
	'VIEW_FLASH'				=> 'Паказваць Flash-анімацыю',
	'VIEW_IMAGES'				=> 'Паказваць малюнкі ў паведамленнях',
	'VIEW_NEXT_HISTORY'			=> 'Наступнае АП у архіве',
	'VIEW_NEXT_PM'				=> 'Наступнае АП',
	'VIEW_PM'					=> 'Паглядзець паведамленне',
	'VIEW_PM_INFO'				=> 'Інфармацыя',
	'VIEW_PM_MESSAGE'			=> 'Паведамленняў: 1',
	'VIEW_PM_MESSAGES'			=> 'Паведамленняў: %d',
	'VIEW_PREVIOUS_HISTORY'		=> 'Папярэдняе АП у архіве',
	'VIEW_PREVIOUS_PM'			=> 'Папярэдняе АП',
	'VIEW_SIGS'					=> 'Паказваць подпісы',
	'VIEW_SMILIES'				=> 'Замяняць смайлікі малюнкамі',
	'VIEW_TOPICS_DAYS'			=> 'Паказваць тэмы за',
	'VIEW_TOPICS_DIR'			=> 'Парадак сартавання тэм',
	'VIEW_TOPICS_KEY'			=> 'Поле сартавання тэм',
	'VIEW_POSTS_DAYS'			=> 'Паказваць паведамленні за',
	'VIEW_POSTS_DIR'			=> 'Парадак сартавання паведамленняў',
	'VIEW_POSTS_KEY'			=> 'Поле сартавання паведамленняў',

	'WATCHED_EXPLAIN'			=> 'Ніжэй размешчаны спіс форумаў і тым, на якія вы падпісаныя. Вы будзеце абвешчаныя аб з\'яўленні ў іх новых паведамленняў. Каб адпісацца ад іх, вылучыце форум або тэму і націсніце кнопку <em>Адпісацца ад вылучанага</em>',
	'WATCHED_FORUMS'			=> 'Вашы падпіскі на форумы',
	'WATCHED_TOPICS'			=> 'Вашы падпіскі на тэмы',
	'WRONG_ACTIVATION'			=> 'Ключ актывацыі, паказаны вамі, адсутнічае ў базе дадзеных.',

	'YOUR_DETAILS'				=> 'Ваша актыўнасць на форумах',
	'YOUR_FOES'					=> 'Вашы злоснікі',
	'YOUR_FOES_EXPLAIN'			=> 'Каб прыбраць карыстальнікаў з спісу, вылучыце іх і націсніце «Адправіць».',
	'YOUR_FRIENDS'				=> 'Вашы сябры',
	'YOUR_FRIENDS_EXPLAIN'		=> 'Каб прыбраць карыстальнікаў з спісу, вылучыце іх і націсніце «Адправіць».',
	'YOUR_WARNINGS'				=> 'Атрымана папярэджанняў',

	'PM_ACTION' => array(
		'PLACE_INTO_FOLDER'	=> 'Змясціць у папку',
		'MARK_AS_READ'		=> 'Пазначыць як прачытанае',
		'MARK_AS_IMPORTANT'	=> 'Пазначыць як важнае',
		'DELETE_MESSAGE'	=> 'Выдаліць паведамленне'
	),
	'PM_CHECK' => array(
		'SUBJECT'	=> 'Тэма',
		'SENDER'	=> 'Адпраўнік',
		'MESSAGE'	=> 'Паведамленне',
		'STATUS'	=> 'Статут паведамлення',
		'TO'		=> 'Атрымальнік'
	),
	'PM_RULE' => array(
		'IS_LIKE'		=> 'утрымоўвае',
		'IS_NOT_LIKE'	=> 'не ўтрымоўвае',
		'IS'			=> 'адпавядае',
		'IS_NOT'		=> 'не адпавядае',
		'BEGINS_WITH'	=> 'пачынаецца з',
		'ENDS_WITH'		=> 'сканчаецца на',
		'IS_FRIEND'		=> 'сябар',
		'IS_FOE'		=> 'злоснік',
		'IS_USER'		=> 'карыстальнік',
		'IS_GROUP'		=> 'уваходзіць у групу',
		'ANSWERED'		=> 'адказанае',
		'FORWARDED'		=> 'адпраўленае',
		'TO_GROUP'		=> 'у маю групу па змаўчанні',
		'TO_ME'			=> 'мне'
	),


	'GROUPS_EXPLAIN'	=> 'Групы даюць адміністратару канферэнцыі больш магчымасцяў па кіраванні карыстальнікамі. Па змаўчанні вы змешчаныя ў вызначаную групу. Аб таго, у які з груп вы складаецеся па змаўчанні, залежыць ваша адлюстраванне ў канферэнцыі: колер вашага імя, аватара, званне і т.п. У залежнасці ад таго, ці дазволена гэта адміністратарам, вы можаце змяніць зададзеную па змаўчанні групу. Вы можаце быць змешчаныя або вам можа быць дазволена ўступіць у іншую групу. Удзел у некаторых групах можа даваць дадатковыя правы доступу да раздзелаў форума або іншыя магчымасці.',
	'GROUP_LEADER'		=> 'Лідэр групы',
	'GROUP_MEMBER'		=> 'Удзельнік групы',
	'GROUP_PENDING'		=> 'Кандыдат на ўступ у групы',
	'GROUP_NONMEMBER'	=> 'Не складаецца ў групах',
	'GROUP_DETAILS'		=> 'Інфармацыя аб групах',

	'NO_LEADER'		=> 'Няма лідэраў групы',
	'NO_MEMBER'		=> 'Няма чальцоў групы',
	'NO_PENDING'	=> 'Няма кандыдатаў у чэлесы групы',
	'NO_NONMEMBER'	=> 'Няма пустых груп',
));

?>
