<?php
/**
*
* acp_permissions [Belarusian]
*
* @package language
* @version $Id: permissions.php,v 1.38 2007/10/08 14:38:26 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_PERMISSIONS_EXPLAIN'	=> '
		<p>Правы доступу надзвычай дэталізаваныя і згрупаваныя ў чатыры асноўныя раздзелы:</p>

		<h2>Глабальныя правы доступу</h2>
		<p>Гэтыя правы выкарыстоўваюцца для кіравання доступам на глабальным узроўні і ўжываюцца да ўсёй канферэнцыі ў цэлым. Далей яны падзеленыя на правы карыстальнікаў, груп, адміністратараў і супермадэратараў.</p>

		<h2>Лакальныя правы доступу</h2>
		<p>Гэтыя правы выкарыстоўваюцца для кіравання доступам на ўзроўні форумаў. Далей яны падзеленыя на Доступ да форумаў, Мадэратары форумаў, Форумныя правы карыстальнікаў, Форумныя правы груп.</p>

		<h2>Ролі</h2>
		<p>Яны выкарыстоўваюцца для стварэння розных тыпавых набораў праў доступу, каб у далейшым можна было прызначаць правы, заснаваныя на ролевым доступе. Набор роляў па змаўчанні павінен цалкам задавальняць патрэбнасці адміністравання вялікіх і малых канферэнцый, тым не менш, у кожным з чатырох раздзелаў вы можаце дадаваць, змяняць і выдаляць ролі так, як лічыце мэтазгодным.</p>

		<h2>Маскі праў доступу</h2>
		<p>Маскі праў доступу выкарыстоўваюцца для прагляду дзеючых праў доступу, прызначаных на карыстальнікаў, мадэратараў (лакальных і супермадэратараў), адміністратараў і на форумы.</p>

		<br />

		<p>Для атрымання больш падрабязнай інфармацыі па наладзе і кіраванню правамі доступу на вашай канферэнцыі phpBB3 глядзіце <a href="http://www.phpbb.com/support/documentation/3.0/quickstart/quick_permissions.html">Падзел 1.5 нашага кіраўніцтва</a>.</p>
	',

	'ACL_NEVER'				=> 'Ніколі',
	'ACL_SET'				=> 'Налада праў доступу',
	'ACL_SET_EXPLAIN'		=> 'Правы доступу заснаваныя на прастой сістэме <samp>ТАК</samp>/<samp>НЕ</samp>. Усталяванне значэння <samp>НІКОЛІ</samp> для карыстальніка або групы азначае ігнараванне любых іншых значэнняў, усталяваных па дадзенай опцыі. Калі вы не жадаеце прызначаць права па опцыі для дадзенага карыстальніка або групы вылучыце <samp>НЕ</samp>. Калі значэнні па гэтай опцыі ўсталяваныя дзе-небудзь яшчэ, яны будуць мець больш высокі прыярытэт, калі не ўсталявана <samp>НІКОЛІ</samp>. Усе адзначаныя аб\'екты (з усталяваным сцяжком) адлюстроўваюць усталяваныя значэнні праў доступу.',
	'ACL_SETTING'			=> 'Налады',

	'ACL_TYPE_A_'			=> 'Правы адміністратара',
	'ACL_TYPE_F_'			=> 'Доступ да форумаў',
	'ACL_TYPE_M_'			=> 'Правы мадэратара',
	'ACL_TYPE_U_'			=> 'Правы карыстальніка',

	'ACL_TYPE_GLOBAL_A_'	=> 'Правы адміністратара',
	'ACL_TYPE_GLOBAL_U_'	=> 'Правы карыстальніка',
	'ACL_TYPE_GLOBAL_M_'	=> 'Правы супермадэратара',
	'ACL_TYPE_LOCAL_M_'		=> 'правы мадэратара форума',
	'ACL_TYPE_LOCAL_F_'		=> 'доступ да форумаў',

	'ACL_NO'				=> 'Не',
	'ACL_VIEW'				=> 'Прагляд праў доступу',
	'ACL_VIEW_EXPLAIN'		=> 'Тут вы можаце бачыць дзеючыя правы карыстальніка або групы. Чырвоны колер паказвае на адсутнасць права ў карыстальніка або ў групы, а зялёны — на наяўнасць права ў карыстальніка або ў групы.',
	'ACL_YES'				=> 'Так',

	'ACP_ADMINISTRATORS_EXPLAIN'				=> 'Тут вы можаце прызначаць адміністратарскія правы карыстальнікам ці групам. Усе карыстальнікі з адміністратарскімі правамі могуць уваходзіць у панэль адміністравання',
	'ACP_FORUM_MODERATORS_EXPLAIN'				=> 'Тут вы можаце прызначаць карыстальнікаў і групы карыстальнікаў мадэратарамі форумаў. Для прызначэння карыстальнікам праў доступу да форумаў, а таксама для азначэння праў супермадэратара і адміністратара, выкарыстайце адпаведную старонку.',
	'ACP_FORUM_PERMISSIONS_EXPLAIN'				=> 'Тут вы можаце змяняць для кожнага карыстальніка і групы доступ да кожнага форуму. Для прызначэння мадэратараў або вызначэння правоў адміністратара выкарыстайце адпаведную старонку.',
	'ACP_FORUM_PERMISSIONS_COPY_EXPLAIN'		=> 'Тут вы можаце капіяваць форумныя правы доступу з аднаго форуму ў іншы форум або адразу ў некалькі іншых форумаў.',
	'ACP_GLOBAL_MODERATORS_EXPLAIN'				=> 'Тут вы можаце прызначаць правы супермадэратара карыстальнікам ці групам. Супермадэратары падобныя звычайным мадэратарам, за выключэннем таго, што яны маюць доступ да кіравання ўсімі форумамі канферэнцыі.',
	'ACP_GROUPS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Тут вы можаце прызначаць форумныя правы груп.',
	'ACP_GROUPS_PERMISSIONS_EXPLAIN'			=> 'Тут вы можаце прызначаць глабальныя правы доступу для груп — правы карыстальнікаў, правы супермадэратараў і правы адміністратараў. Правы карыстальнікаў уключаюць такія магчымасці, як выкарыстанне аватары, адпраўка асабістых паведамленняў і гэтак далей; правы супермадэратара такія, як ухвала паведамленняў, кіраванне тэмамі, кіраванне блакоўкай і гэтак далей, і, нарэшце, правы адміністратара такія, як змена праў доступу, азначэнне новых BBCodes, кіраванне форумамі і гэтак далей. Індывідуальна правы доступу карыстальнікаў варта змяняць у крайніх выпадках. Пераважны метад складаецца ў памяшканні карыстальнікаў у групы і ў прызначэнні праў групам.',
	'ACP_ADMIN_ROLES_EXPLAIN'					=> 'Тут вы можаце кіраваць адміністратарскімі ролямі. Ролі ўтрымоўваюць дзеючыя правы доступу, калі вы зменіце змест ролі, то зменяцца правы доступу ўсіх для карыстальнікаў і груп, якім прызначаная дадзеная роля.',
	'ACP_FORUM_ROLES_EXPLAIN'					=> 'Тут вы можаце кіраваць форумнымі ролямі. Ролі ўтрымоўваюць дзеючыя правы доступу, калі вы зменіце змест ролі, то зменяцца правы доступу ўсіх для карыстальнікаў і груп, якім прызначаная дадзеная роля.',
	'ACP_MOD_ROLES_EXPLAIN'						=> 'Тут вы можаце кіраваць мадэратарскімі ролямі. Ролі ўтрымоўваюць дзеючыя правы доступу, калі вы зменіце змест ролі, то зменяцца правы доступу ўсіх для карыстальнікаў і груп, якім прызначаная дадзеная роля.',
	'ACP_USER_ROLES_EXPLAIN'					=> 'Тут вы можаце кіраваць карыстальніцкімі ролямі. Ролі ўтрымоўваюць дзеючыя правы доступу, калі вы зменіце змест ролі, то зменяцца правы доступу ўсіх для карыстальнікаў і груп, якім прызначаная дадзеная роля.',
	'ACP_USERS_FORUM_PERMISSIONS_EXPLAIN'		=> 'Тут вы можаце прызначаць карыстальнікам права доступу да форумаў.',
	'ACP_USERS_PERMISSIONS_EXPLAIN'				=> 'Тут вы можаце прызначаць глабальныя правы доступу для карыстальнікаў — правы карыстальнікаў, правы супермадэратараў і правы адміністратараў. Правы карыстальнікаў уключаюць такія магчымасці, як выкарыстанне аватары, адпраўка асабістых паведамленняў і гэтак далей; правы супермадэратара такія, як ухвала паведамленняў, кіраванне тэмамі, кіраванне блакоўкай і гэтак далей, і, нарэшце, правы адміністратара такія, як змена праў доступу, азначэнне новых BBCodes, кіраванне форумамі і гэтак далей. Індывідуальна правы доступу карыстальнікаў варта змяняць у крайніх выпадках. Пераважны метад складаецца ў памяшканні карыстальнікаў у групы і ў прызначэнні праў групам.',
	'ACP_VIEW_ADMIN_PERMISSIONS_EXPLAIN'		=> 'Тут вы можаце праглядзець дзеючыя адміністратарскія правы доступу для вылучаных карыстальнікаў і груп.',
	'ACP_VIEW_GLOBAL_MOD_PERMISSIONS_EXPLAIN'	=> 'Тут вы можаце праглядзець дзеючыя супермадэратарскія правы доступу для вылучаных карыстальнікаў і груп.',
	'ACP_VIEW_FORUM_PERMISSIONS_EXPLAIN'		=> 'Тут вы можаце праглядзець дзеючыя лакальныя правы доступу для вылучаных форумаў, карыстальнікаў і груп.',
	'ACP_VIEW_FORUM_MOD_PERMISSIONS_EXPLAIN'	=> 'Тут вы можаце праглядзець дзеючыя мадэратарскія правы доступу для вылучаных форумаў, карыстальнікаў і груп.',
	'ACP_VIEW_USER_PERMISSIONS_EXPLAIN'			=> 'Тут вы можаце праглядзець дзеючыя карыстальніцкія правы доступу для вылучаных карыстальнікаў і груп.',

	'ADD_GROUPS'				=> 'Дадаць групы',
	'ADD_PERMISSIONS'			=> 'Дадаць правы',
	'ADD_USERS'					=> 'Дадаць карыстальнікаў',
	'ADVANCED_PERMISSIONS'		=> 'Пашыраныя правы',
	'ALL_GROUPS'				=> 'Вылучыць усе групы',
	'ALL_NEVER'					=> 'Усё <samp>НІКОЛІ</samp>',
	'ALL_NO'					=> 'Усё <samp>НЕ</samp>',
	'ALL_USERS'					=> 'Вылучыць усіх карыстальнікаў',
	'ALL_YES'					=> 'Усё <samp>ТАК</samp>',
	'APPLY_ALL_PERMISSIONS'		=> 'Ужыць усе правы',
	'APPLY_PERMISSIONS'			=> 'Ужыць правы',
	'APPLY_PERMISSIONS_EXPLAIN'	=> 'Правы і роля, паказаныя для гэтага элемента, будуць ужытыя да гэтага элемента і да адзначаных элементаў.',
	'AUTH_UPDATED'				=> 'Правы доступу абноўленыя.',

	'COPY_PERMISSIONS_CONFIRM'				=> 'Вы сапраўды жадаеце выканаць гэта дзеянне? Памятайце, што гэта дзеянне перазапіша ўсе наяўныя права выбраных форумаў.',
	'COPY_PERMISSIONS_FORUM_FROM_EXPLAIN'	=> 'Зыходны форум, з якога вы жадаеце скапіяваць правы доступу.',
	'COPY_PERMISSIONS_FORUM_TO_EXPLAIN'		=> 'Канцавыя форумы, да якіх вы жадаеце ўжыць скапіяваны правы доступу.',
	'COPY_PERMISSIONS_FROM'					=> 'Капіраваць права з форуму',
	'COPY_PERMISSIONS_TO'					=> 'Ужыць права на форумах',

	'CREATE_ROLE'				=> 'Стварыць ролю',
	'CREATE_ROLE_FROM'			=> 'Выкарыстаць налады ролі…',
	'CUSTOM'					=> 'Іншае…',

	'DEFAULT'					=> 'Па змаўчанні',
	'DELETE_ROLE'				=> 'Выдаленне ролі',
	'DELETE_ROLE_CONFIRM'		=> 'Вы сапраўды жадаеце выдаліць гэтую ролю? Аб\'екты з дадзенай роляй <strong>не</strong> страцяць вызначаныя ёю налады праў доступу.',
	'DISPLAY_ROLE_ITEMS'		=> 'Праглядзець аб\'екты з дадзенай роляй',

	'EDIT_PERMISSIONS'			=> 'Рэдагаваць правы',
	'EDIT_ROLE'					=> 'Рэдагаваць ролю',

	'GROUPS_NOT_ASSIGNED'		=> 'Няма груп з дадзенай роляй',

	'LOOK_UP_GROUP'				=> 'Выбар групы',
	'LOOK_UP_USER'				=> 'Выбар карыстальніка',

	'MANAGE_GROUPS'		=> 'Кіраванне групамі',
	'MANAGE_USERS'		=> 'Кіраванне карыстальнікамі',

	'NO_AUTH_SETTING_FOUND'		=> 'Налады праў доступу не вызначаныя.',
	'NO_ROLE_ASSIGNED'			=> 'Роля не прызначаная…',
	'NO_ROLE_ASSIGNED_EXPLAIN'	=> 'Гэты выбар не змяняе прызначаных праў доступу (справа). Калі вы жадаеце скінуць або выдаліць усе правы доступу, то неабходна выкарыстаць спасылку «Усё <samp>НЕ</samp>».',
	'NO_ROLE_AVAILABLE'			=> 'Ролі недаступныя',
	'NO_ROLE_NAME_SPECIFIED'	=> 'Увядзіце імя ролі.',
	'NO_ROLE_SELECTED'			=> 'Роля не знойдзеная.',
	'NO_USER_GROUP_SELECTED'	=> 'Вы не вылучылі карыстальніка або групу.',

	'ONLY_FORUM_DEFINED'	=> 'Вы вызначылі толькі форумы. Вылучыце, прынамсі, аднаго карыстальніка або групу.',

	'PERMISSION_APPLIED_TO_ALL'		=> 'Правы доступу і роля будуць ужытыя для ўсіх адзначаных аб\'ектаў',
	'PLUS_SUBFORUMS'				=> '+падфорумы',

	'REMOVE_PERMISSIONS'			=> 'Выдаліць правы',
	'REMOVE_ROLE'					=> 'Выдаліць ролю',
	'RESULTING_PERMISSION'			=> 'Выніковыя правы',
	'ROLE'							=> 'Роля',
	'ROLE_ADD_SUCCESS'				=> 'Роля паспяхова дададзеная.',
	'ROLE_ASSIGNED_TO'				=> 'Каму прызначаная роля «%s»',
	'ROLE_DELETED'					=> 'Роля паспяхова выдаленая.',
	'ROLE_DESCRIPTION'				=> 'Апісанне ролі',

	'ROLE_ADMIN_FORUM'			=> 'Адміністратар форума',
	'ROLE_ADMIN_FULL'			=> 'Адміністратар канферэнцыі',
	'ROLE_ADMIN_STANDARD'		=> 'Стандартны адміністратар',
	'ROLE_ADMIN_USERGROUP'		=> 'Адміністратар карыстальнікаў і груп',
	'ROLE_FORUM_BOT'			=> 'Доступ для бота',
	'ROLE_FORUM_FULL'			=> 'Поўны доступ',
	'ROLE_FORUM_LIMITED'		=> 'Абмежаваны доступ',
	'ROLE_FORUM_LIMITED_POLLS'	=> 'Абмежаваны доступ з апытаннямі',
	'ROLE_FORUM_NOACCESS'		=> 'Няма доступу',
	'ROLE_FORUM_ONQUEUE'		=> 'З папярэдняй ухвалой',
	'ROLE_FORUM_POLLS'			=> 'Стандартны доступ з апытаннямі',
	'ROLE_FORUM_READONLY'		=> 'Доступ толькі для чытання',
	'ROLE_FORUM_STANDARD'		=> 'Стандартны доступ',
	'ROLE_FORUM_NEW_MEMBER'		=> 'Доступ Новых карыстальнікаў',
	'ROLE_MOD_FULL'				=> 'Супермадэратар',
	'ROLE_MOD_QUEUE'			=> 'Прэмадэратар',
	'ROLE_MOD_SIMPLE'			=> 'Прастой мадэратар',
	'ROLE_MOD_STANDARD'			=> 'Стандартны мадэратар',
	'ROLE_USER_FULL'			=> 'Усе магчымасці',
	'ROLE_USER_LIMITED'			=> 'Абмежаваныя магчымасці',
	'ROLE_USER_NOAVATAR'		=> 'Без аватараў',
	'ROLE_USER_NOPM'			=> 'Без асабістых паведамленняў',
	'ROLE_USER_STANDARD'		=> 'Стандартныя магчымасці',
	'ROLE_USER_NEW_MEMBER'		=> 'Магчымасці Новых карыстальнікаў',


	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'Мае доступ да кіравання форумам і да налад праў доступу да форума.',
	'ROLE_DESCRIPTION_ADMIN_FULL'			=> 'Мае доступ да ўсіх адміністратарскіх магчымасцяў канферэнцыі.<br />Не рэкамендуецца.',
	'ROLE_DESCRIPTION_ADMIN_STANDARD'		=> 'Мае доступ да большасці адміністратарскіх магчымасцяў, але не можа выкарыстаць сістэмныя і серверныя налады.',
	'ROLE_DESCRIPTION_ADMIN_USERGROUP'		=> 'Можа кіраваць карыстальнікамі і групамі: змяняць правы доступу, налады, кіраваць блакоўкай і званнямі.',
	'ROLE_DESCRIPTION_FORUM_BOT'			=> 'Гэтая роля рэкамендаваная для ботаў і пошукавых машын.',
	'ROLE_DESCRIPTION_FORUM_FULL'			=> 'Доступ да выкарыстання ўсіх магчымасцяў на форуме, уключаючы стварэнне аб\'яў і прымацаваных тэм. Таксама даступная магчымасць ігнаравання флуд-інтэрвалу.<br />Не рэкамендуецца для звычайных карыстальнікаў.',
	'ROLE_DESCRIPTION_FORUM_LIMITED'		=> 'Доступ да звычайных магчымасцяў на форуме, за выключэннем прымацавання ўкладанняў або выкарыстанні значкоў паведамленняў.',
	'ROLE_DESCRIPTION_FORUM_LIMITED_POLLS'	=> 'Аналагічна абмежаванаму доступу, але з магчымасцю стварэння апытанняў.',
	'ROLE_DESCRIPTION_FORUM_NOACCESS'		=> 'Поўная адсутнасць доступу, у тым ліку магчымасці бачыць форум.',
	'ROLE_DESCRIPTION_FORUM_ONQUEUE'		=> 'Доступ да большасці магчымасцяў на форуме, уключаючы прымацаванне ўкладанняў, але якія размяшчаюцца паведамленні і тэмы патрабуюць папярэдняй ухвалы мадэратарам.',
	'ROLE_DESCRIPTION_FORUM_POLLS'			=> 'Аналагічна стандартнаму доступу, але з магчымасцю стварэння апытанняў.',
	'ROLE_DESCRIPTION_FORUM_READONLY'		=> 'Маецца доступ да чытання форума, але без магчымасці ствараць новыя тэмы або адказваць на паведамленні.',
	'ROLE_DESCRIPTION_FORUM_STANDARD'		=> 'Доступ да большасці магчымасцяў на форуме, уключаючы прымацаванне ўкладанняў і выдаленне сваіх тэм, але без права зачыненні сваіх тэм і стварэнні апытанняў.',
	'ROLE_DESCRIPTION_FORUM_NEW_MEMBER'		=> 'Роля для членаў спецыяльнай групы "Новыя карыстальнікі», якая абмяжоўвае магчымасці зноў зарэгістраваных карыстальнікаў.',
	'ROLE_DESCRIPTION_MOD_FULL'				=> 'Можа выкарыстаць усе мадэратарскія магчымасці, уключаючы блакоўку карыстальнікаў.',
	'ROLE_DESCRIPTION_MOD_QUEUE'			=> 'Можа здзяйсняць толькі папярэдняя ўхвала і праўку паведамленняў.',
	'ROLE_DESCRIPTION_MOD_SIMPLE'			=> 'Можа выконваць толькі асноўныя дзеянні ў тэмах. Не можа выносіць папярэджанні або выкарыстаць адкладзеную мадэрацыю.',
	'ROLE_DESCRIPTION_MOD_STANDARD'			=> 'Можа выкарыстаць большасць мадэратарскіх магчымасцяў, але не мае доступу да блакоўкі карыстальнікаў або змене аўтара паведамленняў.',
	'ROLE_DESCRIPTION_USER_FULL'			=> 'Можа выкарыстаць усё даступныя на форуме магчымасці для карыстальніка, уключаючы змену імя або ігнараванне флуд-інтэрвалу.<br />Не рэкамендуецца.',
	'ROLE_DESCRIPTION_USER_LIMITED'			=> 'Мае доступ да звычайных магчымасцяў карыстальніка. Прымацаванне ўкладанняў, а таксама адпраўка электронных і імгненных паведамленняў недаступныя.',
	'ROLE_DESCRIPTION_USER_NOAVATAR'		=> 'Мае набор абмежаваных магчымасцяў, і, акрамя гэтага, не можа выкарыстаць аватару.',
	'ROLE_DESCRIPTION_USER_NOPM'			=> 'Мае набор абмежаваных магчымасцяў, і, акрамя гэтага, не мае доступу да асабістых паведамленняў.',
	'ROLE_DESCRIPTION_USER_STANDARD'		=> 'Мае доступ да большасці, але не да ўсіх магчымасцяў карыстальніка. Напрыклад, не можа змяняць сваё імя або ігнараваць флуд-інтэрвал.',
	'ROLE_DESCRIPTION_USER_NEW_MEMBER'		=> 'Роля для членаў спецыяльнай групы «Новыя карыстальнікі», якая абмяжоўвае магчымасці зноў зарэгістраваных карыстальнікаў.',

	'ROLE_DESCRIPTION_EXPLAIN'		=> 'Вы можаце ўвесці кароткае апісанне ролі. Уведзены тэкст будзе адлюстраваны ў выглядзе апісання ў пераліку роляў.',
	'ROLE_DESCRIPTION_LONG'			=> 'Апісанне ролі занадта доўгае. Абмяжуйце апісанне да 4000 знакаў.',
	'ROLE_DETAILS'					=> 'Звесткі аб ролі',
	'ROLE_EDIT_SUCCESS'				=> 'Роля паспяхова змененая.',
	'ROLE_NAME'						=> 'Назва ролі',
	'ROLE_NAME_ALREADY_EXIST'		=> 'Назва ролі <strong>%s</strong> ужо існуе для дадзенага набору праў доступу.',
	'ROLE_NOT_ASSIGNED'				=> 'Роля не прызначаная.',

	'SELECTED_FORUM_NOT_EXIST'		=> 'Вылучаных форумаў не існуе.',
	'SELECTED_GROUP_NOT_EXIST'		=> 'Вылучаных груп не існуе.',
	'SELECTED_USER_NOT_EXIST'		=> 'Вылучаных карыстальнікаў не існуе.',
	'SELECT_FORUM_SUBFORUM_EXPLAIN'	=> 'Вылучаны тут форум будзе ўключаць усе падфорумы.',
	'SELECT_ROLE'					=> 'Выбар ролі…',
	'SELECT_TYPE'					=> 'Вылучыце тып',
	'SET_PERMISSIONS'				=> 'Усталяваць правы',
	'SET_ROLE_PERMISSIONS'			=> 'Усталяваць правы для ролі',
	'SET_USERS_PERMISSIONS'			=> 'Усталяваць правы карыстальніка',
	'SET_USERS_FORUM_PERMISSIONS'	=> 'Усталяваць форумныя правы карыстальніка',

	'TRACE_DEFAULT'					=> 'Па змаўчанні значэнне кожнага права доступу <samp>НЕ</samp> (скінута). Такім чынам, правы доступу могуць быць перавызначаныя іншымі параметрамі налад.',
	'TRACE_FOR'						=> 'Вынік для',
	'TRACE_GLOBAL_SETTING'			=> '%s (глабальна)',
	'TRACE_GROUP_NEVER_TOTAL_NEVER'	=> 'Значэнне права для гэтай групы <samp>НІКОЛІ</samp> адпавядае выніковаму, таму захавана раней зададзенае значэнне.',
	'TRACE_GROUP_NEVER_TOTAL_NEVER_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>НІКОЛІ</samp> адпавядае выніковаму, таму захавана раней зададзенае значэнне.',
	'TRACE_GROUP_NEVER_TOTAL_NO'	=> 'Значэнне права для гэтай групы <samp>НІКОЛІ</samp> становіцца новым выніковым, бо раней не было зададзена (было зададзена <samp>НЕ</samp>).',
	'TRACE_GROUP_NEVER_TOTAL_NO_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>НІКОЛІ</samp> становіцца новым выніковым, бо раней не было зададзена (было зададзена <samp>НЕ</samp>).',
	'TRACE_GROUP_NEVER_TOTAL_YES'	=> 'Значэнне права для гэтай групы <samp>НІКОЛІ</samp> замяняе выніковае <samp>ТАК</samp> на <samp>НІКОЛІ</samp> для дадзенага карыстальніка.',
	'TRACE_GROUP_NEVER_TOTAL_YES_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>НІКОЛІ</samp> замяняе выніковае <samp>ТАК</samp> на <samp>НІКОЛІ</samp> для гэтага карыстальніка.',
	'TRACE_GROUP_NO'				=> 'Значэнне права для гэтай групы <samp>НЕ</samp>, таму захавана раней зададзенае выніковае права.',
	'TRACE_GROUP_NO_LOCAL'			=> 'Значэнне права для гэтай групы ў гэтым форуме <samp>НЕ</samp>, таму захавана раней зададзенае значэнне.',
	'TRACE_GROUP_YES_TOTAL_NEVER'	=> 'Значэнне права для гэтай групы <samp>ТАК</samp>, але выніковае права <samp>НІКОЛІ</samp> не можа быць заменена.',
	'TRACE_GROUP_YES_TOTAL_NEVER_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>ТАК</samp>, але выніковае права <samp>НІКОЛІ</samp> не можа быць заменена.',
	'TRACE_GROUP_YES_TOTAL_NO'		=> 'Значэнне права для гэтай групы <samp>ТАК</samp> становіцца новым выніковым, бо раней не было зададзена (было зададзена <samp>НЕ</samp>).',
	'TRACE_GROUP_YES_TOTAL_NO_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>ТАК</samp> становіцца новым выніковым, бо раней не было зададзена (было зададзена <samp>НЕ</samp>).',
	'TRACE_GROUP_YES_TOTAL_YES'		=> 'Значэнне права для гэтай групы <samp>ТАК</samp>, выніковым правам таксама з\'яўляецца <samp>ТАК</samp>, таму захавана раней зададзенае значэнне.',
	'TRACE_GROUP_YES_TOTAL_YES_LOCAL'	=> 'Значэнне права групы для гэтага форума <samp>ТАК</samp>, выніковым правам таксама з\'яўляецца <samp>ТАК</samp>, таму захавана раней зададзенае значэнне.',
	'TRACE_PERMISSION'				=> 'Адсачыць права доступу — %s',
	'TRACE_RESULT'					=> 'Адсачыць вынік',
	'TRACE_SETTING'					=> 'Адсачыць налады',

	'TRACE_USER_GLOBAL_YES_TOTAL_YES'		=> 'Незалежна ад форума значэнне права гэтага карыстальніка <samp>ТАК</samp>, выніковае права таксама роўна <samp>ТАК</samp>, такім чынам, захавана выніковае значэнне. %sОтследить глабальнае права%s',
	'TRACE_USER_GLOBAL_YES_TOTAL_NEVER'		=> 'Незалежна ад форума значэнне права для гэтага карыстальніка <samp>ТАК</samp>, якое замяняе дзеючае лакальнае значэнне <samp>НІКОЛІ</samp>. %sОтследить глабальнае права%s',
	'TRACE_USER_GLOBAL_NEVER_TOTAL_KEPT'	=> 'Незалежна ад форума значэнне права гэтага карыстальніка <samp>НІКОЛІ</samp>, якое не ўплывае на лакальнае значэнне. %sАдсачыць глабальнае права%s',

	'TRACE_USER_FOUNDER'					=> 'Карыстальнік з\'яўляецца заснавальнікам канферэнцыі, таму значэння адміністратарскіх правоў заўсёды ўстаноўлены ў значэнне <samp>ТАК</samp>.',
	'TRACE_USER_KEPT'						=> 'Значэнне права для гэтага карыстальніка <samp>НЕ</samp>, такім чынам, захавана раней зададзенае выніковае значэнне.',
	'TRACE_USER_KEPT_LOCAL'					=> 'Значэнне права для гэтага карыстальніка на дадзеным форуме <samp>НЕ</samp>, такім чынам, захавана раней зададзенае выніковае значэнне.',
	'TRACE_USER_NEVER_TOTAL_NEVER'			=> 'Значэнне права для гэтага карыстальніка <samp>НІКОЛІ</samp>, выніковым правам таксама з\'яўляецца <samp>НІКОЛІ</samp>, таму змены не вырабляюцца.',
	'TRACE_USER_NEVER_TOTAL_NEVER_LOCAL'	=> 'Значэнне права для гэтага карыстальніка на дадзеным форуме <samp>НІКОЛІ</samp>, выніковым правам таксама з\'яўляецца <samp>НІКОЛІ</samp>, таму змены не вырабляюцца.',
	'TRACE_USER_NEVER_TOTAL_NO'				=> 'Значэнне права для гэтага карыстальніка <samp>НІКОЛІ</samp> становіцца новым выніковым правам, бо раней было зададзена <samp>НЕ</samp>.',
	'TRACE_USER_NEVER_TOTAL_NO_LOCAL'		=> 'Значэнне права для гэтага карыстальніка на дадзеным форуме <samp>НІКОЛІ</samp> становіцца новым выніковым правам, бо раней было зададзена <samp>НЕ</samp>.',
	'TRACE_USER_NEVER_TOTAL_YES'			=> 'Значэнне права для гэтага карыстальніка <samp>НІКОЛІ</samp> замяняе раней зададзенае значэнне <samp>ТАК</samp>.',
	'TRACE_USER_NEVER_TOTAL_YES_LOCAL'		=> 'Значэнне права для гэтага карыстальніка на дадзеным форуме <samp>НІКОЛІ</samp> замяняе раней зададзенае значэнне <samp>ТАК</samp>.',
	'TRACE_USER_NO_TOTAL_NO'				=> 'Значэнне права для гэтага карыстальніка <samp>НЕ</samp>, выніковым правам таксама з\'яўляецца <samp>НЕ</samp>, таму ўсталявана значэнне па змаўчанні <samp>НІКОЛІ</samp>.',
	'TRACE_USER_NO_TOTAL_NO_LOCAL'			=> 'Значэнне права для гэтага карыстальніка ў дадзеным форуме <samp>НЕ</samp>, выніковым правам таксама з\'яўляецца <samp>НЕ</samp>, таму ўсталявана значэнне па змаўчанні <samp>НІКОЛІ</samp>.',
	'TRACE_USER_YES_TOTAL_NEVER'			=> 'Значэнне права для гэтага карыстальніка <samp>ТАК</samp>, але выніковае права <samp>НІКОЛІ</samp> не можа быць заменена.',
	'TRACE_USER_YES_TOTAL_NEVER_LOCAL'		=> 'Значэнне права для гэтага карыстальніка ў дадзеным форуме <samp>ТАК</samp>, але выніковае права <samp>НІКОЛІ</samp> не можа быць заменена.',
	'TRACE_USER_YES_TOTAL_NO'				=> 'Значэнне права для гэтага карыстальніка <samp>ТАК</samp> становіцца новым выніковым правам, бо раней было зададзена <samp>НЕ</samp>.',
	'TRACE_USER_YES_TOTAL_NO_LOCAL'			=> 'Значэнне права для гэтага карыстальніка ў дадзеным форуме <samp>ТАК</samp> становіцца новым выніковым правам, бо раней было зададзена <samp>НЕ</samp>.',
	'TRACE_USER_YES_TOTAL_YES'				=> 'Значэнне права для гэтага карыстальніка <samp>ТАК</samp>, выніковым правам таксама з\'яўляецца <samp>ТАК</samp>, таму змены не вырабляюцца.',
	'TRACE_USER_YES_TOTAL_YES_LOCAL'		=> 'Значэнне права для гэтага карыстальніка ў дадзеным форуме <samp>ТАК</samp>, выніковым правам таксама з\'яўляецца <samp>ТАК</samp>, таму змены не вырабляюцца.',
	'TRACE_WHO'								=> 'У якасці',
	'TRACE_TOTAL'							=> 'Падрахунак',

	'USERS_NOT_ASSIGNED'			=> 'Няма карыстальнікаў з гэтай роляй',
	'USER_IS_MEMBER_OF_DEFAULT'		=> 'складаецца ў наступных прадусталяваных групах',
	'USER_IS_MEMBER_OF_CUSTOM'		=> 'складаецца ў наступных створаных групах',

	'VIEW_ASSIGNED_ITEMS'	=> 'Прагляд прызначаных элементаў',
	'VIEW_LOCAL_PERMS'		=> 'Паглядзець лакальныя правы',
	'VIEW_GLOBAL_PERMS'		=> 'Паглядзець глабальныя правы',
	'VIEW_PERMISSIONS'		=> 'Паглядзець правы',

	'WRONG_PERMISSION_TYPE'				=> 'Вылучаны няправільны тып правоў.',
	'WRONG_PERMISSION_SETTING_FORMAT'	=> 'Правы ўсталяваныя ў няслушным фармаце, іх апрацоўка немагчымая.',
));

?>