<?php
/**
*
* search_ignore_words [Belarusian]
*
* @package language
* @version $Id: search_ignore_words.php,v 1.3 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

if (!defined('IN_PHPBB'))
{
	exit;
}

$words = array(
	'href',
	'lol',
	'www',
	'а',
	'без',
	'дзякую',
	'дзякуючы',
	'блізка',
	'больш',
	'больш-меней',
	'вялікая',
	'больш',
	'вялікія',
	'вялікае',
	'вялікі',
	'будзе',
	'будуць',
	'быўшы',
	'быў',
	'была',
	'былі',
	'было',
	'быць',
	'у',
	'вас',
	'вам',
	'вамі',
	'ваш',
	'ваша',
	'ваша',
	'вашага',
	'вашай',
	'вашым',
	'вашаму',
	'вашы',
	'вашым',
	'вашымі',
	'вашых',
	'вашу',
	'зблізку',
	'ж',
	'усюды',
	'пышна',
	'па-за',
	'усярэдзіне',
	'ва',
	'поруч',
	'вось',
	'порамі',
	'часам',
	'часу',
	'час',
	'усё',
	'усёткі',
	'усё',
	'усёткі',
	'заўсёды',
	'усяго',
	'усімі',
	'усіх',
	'усякая',
	'усякія',
	'усякі',
	'усякім',
	'усякімі',
	'усякіх',
	'усякага',
	'усякае',
	'усякай',
	'усякім',
	'усякаму',
	'усякую',
	'выглядае',
	'выглядаюць',
	'дзе',
	'так',
	'далёка',
	'сапраўды',
	'дзень',
	'для',
	'дні',
	'дзён',
	'днём',
	'днём',
	'дні',
	'дню',
	'дня',
	'дням',
	'днямі',
	'днях',
	'да',
	'хата',
	'хаты',
	'хаце',
	'хатай',
	'хаце',
	'яго',
	'яе',
	'яе',
	'калі',
	'ёсць',
	'яшчэ',
	'жа',
	'за',
	'навошта',
	'наштосьці',
	'затым',
	'затым-то',
	'захацеў',
	'захацела',
	'захацелі',
	'захачу',
	'ведае',
	'ведаў',
	'ведала',
	'ведалі',
	'ведала',
	'ведаю',
	'і',
	'і г.д',
	'і т.п',
	'бо',
	'з',
	'з-пад',
	'або',
	'інакш',
	'часам',
	'шукаў',
	'шукала',
	'шукалі',
	'шукала',
	'шукаць',
	'ім',
	'имхо',
	'такім чынам',
	'іх',
	'да',
	'кожны',
	'як',
	'якая',
	'якія',
	'якім',
	'якіх',
	'якога',
	'якое',
	'які',
	'якім',
	'якому',
	'якую',
	'кім',
	'калі',
	'калі-небудзь',
	'каго',
	'кім',
	'каму',
	'якая',
	'якога',
	'якое',
	'якой',
	'якім',
	'якому',
	'якую',
	'якія',
	'які',
	'якім',
	'якіх',
	'хто',
	'хтосьці',
	'дарэчы',
	'куды',
	'ці',
	'альбо',
	'лол',
	'лепшая',
	'лепшае',
	'лепшыя',
	'лепшы',
	'любая',
	'любога',
	'любое',
	'любы',
	'любому',
	'любую',
	'любыя',
	'любым',
	'любымі',
	'любых',
	'маленькая',
	'маленькі',
	'маленькім',
	'маленькага',
	'маленькае',
	'маленькай',
	'маленькім',
	'маленькаму',
	'маленькую',
	'паміж',
	'меней',
	'менш',
	'мяне',
	'свет',
	'мне',
	'шмат',
	'мной',
	'мог',
	'магла',
	'маглі',
	'магло',
	'магу',
	'маё',
	'маё',
	'можам',
	'можа',
	'мае',
	'мой',
	'мая',
	'мы',
	'на',
	'над',
	'назад',
	'найболей',
	'найменш',
	'напіша',
	'напішу',
	'напішуць',
	'напрыклад',
	'нас',
	'нам',
	'намі',
	'наш',
	'наша',
	'наша',
	'нашага',
	'нашай',
	'нашым',
	'нашаму',
	'нашы',
	'нашым',
	'нашымі',
	'нашых',
	'нашу',
	'не',
	'яго',
	'нядаўна',
	'няўжо',
	'яе',
	'яе',
	'трохі',
	'не',
	'не',
	'ніколі',
	'ніхто',
	'нішто',
	'ім',
	'нічога',
	'але',
	'новая',
	'новага',
	'новае',
	'новай',
	'новым',
	'новаму',
	'навін',
	'навіны',
	'навіна',
	'навінамі',
	'новую',
	'новы',
	'новы',
	'новым',
	'новых',
	'новых',
	'ну',
	'патрэбен',
	'патрэбна',
	'трэба',
	'патрэбныя',
	'аб',
	'аб',
	'аднак',
	'каля',
	'ён',
	'яна',
	'яны',
	'яно',
	'ад',
	'адказ',
	'адказаў',
	'адказала',
	'адказалі',
	'адказала',
	'окуда',
	'зусім',
	'перад',
	'пісаў',
	'пісала',
	'пісалі',
	'пісала',
	'піша',
	'пішу',
	'пішуць',
	'дрэнна',
	'па',
	'паблізу',
	'пад',
	'калі ласка',
	'атрымоўвала',
	'атрымоўвалі',
	'атрымоўвала',
	'атрымоўваць',
	'атрымаў',
	'атрымала',
	'атрымалі',
	'атрымала',
	'атрымаць',
	'пор',
	'пара',
	'порам',
	'порамі',
	'пары',
	'парой',
	'пару',
	'поры',
	'пасля',
	'таму',
	'чаму',
	'амаль',
	'пайшлі',
	'праўда',
	'перш',
	'прыкладна',
	'пра',
	'проста',
	'прайшоў',
	'прайшоў',
	'прайшла',
	'прайшлі',
	'прайшло',
	'няхай',
	'хай',
	'раз',
	'разу',
	'хіба',
	'радзей',
	'з',
	'сам',
	'сама',
	'самі',
	'самім',
	'самімі',
	'саміх',
	'само',
	'самога',
	'самае',
	'самой',
	'самім',
	'самому',
	'самоя',
	'саму',
	'самую',
	'самыя',
	'самы',
	'самым',
	'самымі',
	'самых',
	'зрабіў',
	'зрабіла',
	'зрабілі',
	'зрабіла',
	'зараз',
	'скрозь',
	'хутчэй',
	'хутка',
	'выпадку',
	'выпадкам',
	'выпадак',
	'выпадку',
	'выпадку',
	'гледзячы',
	'са',
	'зусім',
	'дзякуй',
	'старая',
	'старога',
	'старое',
	'старой',
	'старым',
	'старому',
	'старую',
	'стары',
	'старым',
	'старых',
	'так',
	'таксама',
	'тваё',
	'твайго',
	'тваё',
	'твае',
	'твой',
	'тваю',
	'твая',
	'тыя',
	'цябе',
	'тым',
	'тымі',
	'зараз',
	'тых',
	'табой',
	'тады',
	'таго',
	'таксама',
	'той',
	'толькі',
	'туды',
	'у',
	'жудасна',
	'ужо',
	'пазнае',
	'пазнаюць',
	'сыйшоў',
	'сыйшоў',
	'сыйшла',
	'сыйшлі',
	'сыйшло',
	'хадзіў',
	'хадзіла',
	'хадзілі',
	'хадзіла',
	'ходзіць',
	'хадзіць',
	'ходзяць',
	'добра',
	'жадаў',
	'жадала',
	'жадалі',
	'жадала',
	'хоць',
	'жадаю',
	'гушчару',
	'чаго',
	'чым',
	'чым',
	'чымсьці',
	'чымсьці',
	'чаму',
	'праз',
	'што',
	'каб',
	'каб',
	'чыё',
	'чыё',
	'чыёй',
	'чыйму',
	'чые',
	'чыім',
	'чыімі',
	'чыіх',
	'чыя',
	'ішоў',
	'ішоў',
	'ішла',
	'ішлі',
	'ішло',
	'гэтая',
	'гэтыя',
	'гэтым',
	'гэтых',
	'гэта',
	'гэтай',
	'гэтаму',
	'гэты',
	'гэтую',
	'я',
	'з\'яўляецца',
	'з\'яўляюцца',
);

?>