<?php
/**
*
* posting [Belarusian]
*
* @package language
* @version $Id: posting.php,v 1.50 2007/11/28 20:09:01 kellanved Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// BBCodes
// Note to translators: you can translate everything but what's between { and }
$lang = array_merge($lang, array(
	'ACP_BBCODES_EXPLAIN'		=> 'BBCode - гэта адмысловая рэалізацыя мовы HTML, якая прадстаўляе больш зручныя магчымасці па фарматаваньню паведамленняў. З дапамогай гэтай старонкі вы можаце дадаваць, выдаляць і змяняць BBCodes.',
	'ADD_BBCODE'				=> 'Дадаць BBCode',

	'BBCODE_DANGER' 		=> 'Гэты BBCode выкарыстоўвае лексему {TEXT} ў тегах HTML. Гэта можа стварыць праблемы з бяспекай, звязаныя з XSS (межсайтавым скрыптынгам). Паспрабуйце ўжыць лексемы {SIMPLETEXT} або {INTTEXT}, якія выкарыстоўваюць больш строгія праверкі. Ігнаруйце дадзенае папярэджанне толькі ў выпадку, калі цалкам усведамляеце магчымыя рызыкі, і выкарыстанне лексемы {TEXT} абсалютна неабходна.', 
	'BBCODE_DANGER_PROCEED' 	=> 'Працягнуць', //'Я ўсьведамляю рызыку',

	'BBCODE_ADDED'				=> 'BBCode паспяхова дададзены.',
	'BBCODE_EDITED'				=> 'BBCode паспяхова зменены.',
	'BBCODE_NOT_EXIST'			=> 'Вылучаны BBCode не існуе.',
	'BBCODE_HELPLINE'			=> 'Падказка',
	'BBCODE_HELPLINE_EXPLAIN'	=> 'Дадзенае поле ўтрымоўвае тэкст, які з\'явіцца пры навядзенні паказальніка мышы на кнопку з BBCode.',
	'BBCODE_HELPLINE_TEXT'		=> 'Тэкст падказкі',
	'BBCODE_HELPLINE_TOO_LONG'	=> 'Уведзены тэкст падказкі занадта доўгі.',

	'BBCODE_INVALID_TAG_NAME'	=> 'Вылучанае імя тэга BBCode ужо існуе.',
	'BBCODE_INVALID'			=> 'BBCode створаны ў недапушчальнай форме.',
	'BBCODE_OPEN_ENDED_TAG'		=> 'Наладжвальны BBCode павінен утрымоўваць які адчыняе і што зачыняе тэгі.',
	'BBCODE_TAG'				=> 'Тэг',
	'BBCODE_TAG_TOO_LONG'		=> 'Уведзенае імя тэга занадта доўгае.',
	'BBCODE_TAG_DEF_TOO_LONG'	=> 'Уведзенае азначэнне тэга занадта доўгае. Увядзіце карацейшае азначэнне.',
	'BBCODE_USAGE'				=> 'Выкарыстанне BBCode',
	'BBCODE_USAGE_EXAMPLE'		=> '[hilight={COLOR}]{TEXT}[/hilight]<br /><br />[font={SIMPLETEXT1}]{SIMPLETEXT2}[/font]',
	'BBCODE_USAGE_EXPLAIN'		=> 'Тут вызначаецца выкарыстанне BBCode. Любая ўводзеная пераменная можа быць замененая на адпаведную лексему (%sпрыклады ніжэй%s).',

	'EXAMPLE'						=> 'Прыклад:',
	'EXAMPLES'						=> 'Прыклады:',

	'HTML_REPLACEMENT'				=> 'Замена HTML',
	'HTML_REPLACEMENT_EXAMPLE'		=> '&lt;span style="background-color: {COLOR};"&gt;{TEXT}&lt;/span&gt;<br /><br />&lt;span style="font-family: {SIMPLETEXT1};"&gt;{SIMPLETEXT2}&lt;/span&gt;',
	'HTML_REPLACEMENT_EXPLAIN'		=> 'Тут вызначаюцца замены HTML. Не забывайце дадаць лексемы, скарыстаныя вышэй!',

	'TOKEN'					=> 'Лексема',
	'TOKENS'				=> 'Лексемы',
	'TOKENS_EXPLAIN'		=> 'Лексемы з\'яўляюцца пазнакамі-запаўняльнікамі для ўводзімага карыстальнікам змесціва. Правільнасць уведзенага змесціва будзе пацверджаная толькі ў выпадку, калі яно адказвае адпаведнаму азначэнню. Калі неабходна, вы можаце нумараваць іх шляхам дадання нумара ў канцы лексемы ўсярэдзіне фігурных дужак, напрыклад, {TEXT1}, {TEXT2}.<br /><br />У якасці пазанак-запаўняльнікаў вы таксама можаце выкарыстаць любую з моўных пераменных, якія прысутнічаюць у вашай моўнай папцы (language/), напрыклад: {L_<em>&lt;STRINGNAME&gt;</em>}, дзе <em>&lt;STRINGNAME&gt;</em> — гэтае імя перакладзенага радка, якую вы жадаеце дадаць. Напрыклад, {L_WROTE} будзе адлюстравана як «wrote» або яго пераклад у адпаведнасці з мовай карыстальніка.<br /><br /><strong>Улічыце, што толькі лексемы, пералічаныя ніжэй, могуць быць скарыстаныя ў карыстальніцкіх BBCodes.</strong>',
	'TOKEN_DEFINITION'		=> 'Апісанне',
	'TOO_MANY_BBCODES'		=> 'Вы больш не можаце стварыць BBCodes. Выдаліце або перамесціце некаторыя BBCodes і паспрабуйце зноўку.',

	'tokens'	=>	array(
		'TEXT'			=> 'Любы тэкст, уключаючы знакі любой мовы, лікі і т.п. Не варта ўжываць гэтую лексему ў тэгах HTML. Замест гэтага выкарыстайце лексемы IDENTIFIER або SIMPLETEXT.',
		'SIMPLETEXT'		=> 'Літары лацінскага алфавіту (A-Z), лічбы, прабелы, коскі, кропкі, мінус, плюс, злучок і падкрэсленне',
		'INTTEXT' 		=> 'Сімвалы Unicode, лічбы, прабелы, коскі, кропкі, мінус, плюс, злучок, падкрэсленне',
		'IDENTIFIER'		=> 'Літары лацінскага алфавіту (A-Z), лічбы, злучок і падкрэсленне',
		'NUMBER'		=> 'Любая паслядоўнасць лічб',
		'EMAIL'			=> 'Правільны адрас электроннай пошты',
		'URL'			=> 'Правільны адрас URL з выкарыстаннем любога пратаколу (http, ftp і г.д. не могуць выкарыстоўвацца для дэструктыўных дзеянняў JavaScript). Калі нічога не зададзена, то да радка будзе аўтаматычна дададзены прэфікс «http://».',
		'LOCAL_URL'		=> 'Лакальны адрас URL. URL павінен быць адносным да старонкі тэмы і не павінен утрымоўваць пратаколу або імя сервера, таму як спасылкі маюць прэфікс “%s”',
		'RELATIVE_URL'	=> 'Адносны адрас URL. Можна выкарыстоўваць для падстаноўкі асобных частак адрасы URL, але з асцярожнасцю: поўны адрас URL з\'яўляецца правільным адносным адрасам URL. Калі патрабуецца выкарыстоўваць адносныя адрасы URL канферэнцыі, ужывайце лексему LOCAL_URL.',
		'COLOR'			=> 'Колер HTML. Колер можа быць зададзены ў лікавым фармаце <samp>#FF1234</samp> або <a href="http://www.w3.org/TR/CSS21/syndata.html#value-def-color">ключавым словам колеру CSS</a>. Напрыклад, <samp>fuchsia</samp> або <samp>InactiveBorder</samp>'
	)
));

// Smilies and topic icons
$lang = array_merge($lang, array(
	'ACP_ICONS_EXPLAIN'		=> 'З дапамогай гэтай старонкі вы можаце дадаваць, выдаляць і змяняць значкі, якія могуць дадавацца карыстальнікамі да тэм або да паведамленняў. Гэтыя значкі звычайна адлюстроўваюцца побач з назовамі тэм на старонках прагляду форумаў, або побач з загалоўкамі паведамленняў на старонках прагляду тэм. Таксама вы можаце ўсталёўваць і ствараць новыя пакеты значкоў.',
	'ACP_SMILIES_EXPLAIN'	=> 'Смайлікі — гэта невялікія, часам аніміраваныя, малюнкі, выкарыстоўваныя для перадачы пачуццяў і настрояў. З дапамогай гэтай старонкі вы можаце дадаваць, выдаляць і змяняць смайлікі, якія могуць дадавацца карыстальнікамі да сваіх паведамленняў. Таксама вы можаце ўсталёўваць і ствараць новыя пакеты смайлікаў.',
	'ADD_SMILIES'			=> 'Дадаць некалькі смайлікаў',
	'ADD_SMILEY_CODE'		=> 'Дадаць дадатковы код смайліка',
	'ADD_ICONS'				=> 'Дадаць некалькі значкоў',
	'AFTER_ICONS'			=> 'Пасля %s',
	'AFTER_SMILIES'			=> 'Пасля %s',

	'CODE'						=> 'Код',
	'CURRENT_ICONS'				=> 'Усталяваныя значкі',
	'CURRENT_ICONS_EXPLAIN'		=> 'Вылучыце дзеянне, якое трэба дастасаваць да ўжо ўсталяваным значкам.',
	'CURRENT_SMILIES'			=> 'Усталяваныя смайлікі',
	'CURRENT_SMILIES_EXPLAIN'	=> 'Вылучыце дзеянне, якое трэба дастасаваць да ўсталяваным смайлікам.',

	'DISPLAY_ON_POSTING'		=> 'Паказваць на старонцы адказу',
	'DISPLAY_POSTING'			=> 'На старонцы адказу',
	'DISPLAY_POSTING_NO'		=> 'Няма на старонцы адказу',



	'EDIT_ICONS'				=> 'Змяніць значкі',
	'EDIT_SMILIES'				=> 'Змяніць смайлікі',
	'EMOTION'					=> 'Эмоцыя',
	'EXPORT_ICONS'				=> 'Экспартаваць і загрузіць файл icons.pak',
	'EXPORT_ICONS_EXPLAIN'		=> '%sАпасля пстрычкі па гэтай спасылцы канфігурацыя ўсталяваных значкоў будзе спакаваная ў файл <samp>icons.pak</samp>, які пасля загрузкі можна выкарыстаць для стварэння архіваў <samp>.zip</samp> або <samp>.tgz</samp>, якія змяшчаюць усе вашы значкі разам з канфігурацыйным файлам <samp>icons.pak</samp>%s.',
	'EXPORT_SMILIES'			=> 'Экспартаваць і загрузіць файл smilies.pak',
	'EXPORT_SMILIES_EXPLAIN'	=> '%sАпасля пстрычкі па гэтай спасылцы канфігурацыя ўсталяваных смайлікаў будзе спакаваная ў файл <samp>smilies.pak</samp>, які пасля загрузкі можна выкарыстаць для стварэння архіваў <samp>.zip</samp> або <samp>.tgz</samp>, якія змяшчаюць усе вашы смайлікі разам з канфігурацыйным файлам <samp>smilies.pak</samp>%s.',

	'FIRST'			=> 'Першы',

	'ICONS_ADD'				=> 'Дадаць значок',
	'ICONS_NONE_ADDED'		=> 'Значкі не былі дададзеныя.',
	'ICONS_ONE_ADDED'		=> 'Паказаны значок паспяхова дададзены.',
	'ICONS_ADDED'			=> 'Паказаныя значкі паспяхова дададзеныя.',
	'ICONS_CONFIG'			=> 'Налады значкоў',
	'ICONS_DELETED'			=> 'Значок паспяхова выдалены.',
	'ICONS_EDIT'			=> 'Змяніць значок',
	'ICONS_ONE_EDITED'		=> 'Паказаны значок паспяхова абноўлены.',
	'ICONS_NONE_EDITED'		=> 'Значкі не былі абноўленыя.',
	'ICONS_EDITED'			=> 'Паказаныя значкі паспяхова абноўленыя.',
	'ICONS_HEIGHT'			=> 'Вышыня значка',
	'ICONS_IMAGE'			=> 'Малюнак значка',
	'ICONS_IMPORTED'		=> 'Пакет значкоў паспяхова ўсталяваны.',
	'ICONS_IMPORT_SUCCESS'	=> 'Пакет значкоў паспяхова імпартаваны.',
	'ICONS_LOCATION'		=> 'Шлях да значка',
	'ICONS_NOT_DISPLAYED'	=> 'Наступныя значкі не будуць адлюстроўвацца на старонцы размяшчэння паведамлення',
	'ICONS_ORDER'			=> 'Парадак значка',
	'ICONS_URL'				=> 'Файл значка',
	'ICONS_WIDTH'			=> 'Шырыня значка',
	'IMPORT_ICONS'			=> 'Усталяваць пакет значкоў',
	'IMPORT_SMILIES'		=> 'Усталяваць пакет смайлікаў',

	'KEEP_ALL'			=> 'Захаваць усё',

	'MASS_ADD_SMILIES'	=> 'Дадаць некалькі смайлікаў',

	'NO_ICONS_ADD'		=> 'Няма значкоў, даступных для дадання.',
	'NO_ICONS_EDIT'		=> 'Няма значкоў, даступных для змены.',
	'NO_ICONS_EXPORT'	=> 'Няма значкоў, даступных для стварэння пакета.',
	'NO_ICONS_PAK'		=> 'Пакеты значкоў не знойдзеныя.',
	'NO_SMILIES_ADD'	=> 'Няма смайлікаў, даступных для дадання.',
	'NO_SMILIES_EDIT'	=> 'Няма смайлікаў, даступных для змены.',
	'NO_SMILIES_EXPORT'	=> 'Няма смайлікаў, даступных для стварэння пакета.',
	'NO_SMILIES_PAK'	=> 'Пакеты смайлікаў не знойдзеныя.',

	'PAK_FILE_NOT_READABLE'		=> 'Памылка чытання файла <samp>.pak</samp>',

	'REPLACE_MATCHES'	=> 'Замяніць парныя',

	'SELECT_PACKAGE'			=> 'Вылучыце файл пакета',
	'SMILIES_ADD'				=> 'Дадаць смайлік',
	'SMILIES_NONE_ADDED'		=> 'Смайлікі не былі дададзеныя.',
	'SMILIES_ONE_ADDED'			=> 'Паказаны смайлік паспяхова дададзены.',
	'SMILIES_ADDED'				=> 'Паказаныя смайлікі паспяхова дададзеныя.',
	'SMILIES_CODE'				=> 'Код смайліка',
	'SMILIES_CONFIG'			=> 'Налады смайлікаў',
	'SMILIES_DELETED'			=> 'Смайлік паспяхова выдалены.',
	'SMILIES_EDIT'				=> 'Змяніць смайлік',
	'SMILIE_NO_CODE'			=> 'Смайлік «%s» не быў дададзены, так як для яго не зададзены код.',
	'SMILIE_NO_EMOTION'			=> 'Смайлік «%s» не быў дададзены, так як для яго не зададзена эмоцыя.',
	'SMILIE_NO_FILE'			=> 'Смайлік «%s» не быў дададзены, так як для яго адсутнічае файл.',
	'SMILIES_NONE_EDITED'		=> 'Смайлікі не былі абноўленыя.',
	'SMILIES_ONE_EDITED'		=> 'Паказаны смайлік паспяхова абноўлены.',
	'SMILIES_EDITED'			=> 'Паказаныя смайлікі паспяхова абноўленыя.',
	'SMILIES_EMOTION'			=> 'Эмоцыя',
	'SMILIES_HEIGHT'			=> 'Вышыня смайліка',
	'SMILIES_IMAGE'				=> 'Малюнак смайліка',
	'SMILIES_IMPORTED'			=> 'Пакет смайлікаў паспяхова ўсталяваны.',
	'SMILIES_IMPORT_SUCCESS'	=> 'Пакет смайлікаў паспяхова імпартаваны.',
	'SMILIES_LOCATION'			=> 'Шлях да смайліка',
	'SMILIES_NOT_DISPLAYED'		=> 'Наступныя смайлікі не будуць адлюстроўвацца на старонцы размяшчэння паведамлення',
	'SMILIES_ORDER'				=> 'Парадак смайліка',
	'SMILIES_URL'				=> 'Файл смайліка',
	'SMILIES_WIDTH'				=> 'Шырыня смайліка',

	'TOO_MANY_SMILIES'			=> 'Дасягнутая мяжа ў колькасці %d смайлікаў.',

	'WRONG_PAK_TYPE'	=> 'Паказаны пакет не ўтрымоўвае прыдатных дадзеных.',
));

// Word censors
$lang = array_merge($lang, array(
	'ACP_WORDS_EXPLAIN'		=> 'З дапамогай гэтай панэлі вы можаце дадаваць, выдаляць і змяняць словы, якія будуць аўтаматычна падвяргацца цэнзуры на вашых форумах. Акрамя гэтага, карыстальнікі не змогуць зарэгістравацца з імёнамі, якія змяшчаюць гэтыя словы. У словах могуць утрымоўвацца падстаноўныя знакі (*). Напрыклад, *тэст* будзе адпавядаць слову «пратэставаць», тэст* — «тэставанне», *тэст — «пратэст».',
	'ADD_WORD'				=> 'Дадаць слова',

	'EDIT_WORD'		=> 'Змена слова',
	'ENTER_WORD'	=> 'Неабходна ўвесці слова і яго замену.',

	'NO_WORD'	=> 'Не вылучана слова для рэдагавання.',

	'REPLACEMENT'	=> 'Замена',

	'UPDATE_WORD'	=> 'Абнаўленне слова',

	'WORD'				=> 'Слова',
	'WORD_ADDED'		=> 'Слова паспяхова дададзена.',
	'WORD_REMOVED'		=> 'Вылучанае слова паспяхова выдаленае.',
	'WORD_UPDATED'		=> 'Вылучанае слова паспяхова абноўленае.',
));

// Ranks
$lang = array_merge($lang, array(
	'ACP_RANKS_EXPLAIN'		=> 'З дапамогай гэтай панэлі вы можаце дадаваць, выдаляць і змяняць званні. Таксама вы можаце ствараць адмысловыя званні, якія могуць быць прысвоеныя карыстальнікам на старонцы кіравання карыстальнікамі.',
	'ADD_RANK'				=> 'Дадаць званне',

	'MUST_SELECT_RANK'		=> 'Неабходна вылучыць званне.',

	'NO_ASSIGNED_RANK'		=> 'Адмысловага звання не прысвоена.',
	'NO_RANK_TITLE'			=> 'Не паказаны загаловак звання.',
	'NO_UPDATE_RANKS'		=> 'Званне паспяхова выдаленае. Аднак, уліковыя запісы карыстальнікаў, якім яно было прысвоена, не былі абноўленыя. Вам неабходна ўручную аднавіць званні ў гэтых уліковых запісах.',

	'RANK_ADDED'			=> 'Званне паспяхова дададзена.',
	'RANK_IMAGE'			=> 'Малюначак да звання',
	'RANK_IMAGE_EXPLAIN'	=> 'Тут можна прысвоіць невялікі малюнак, звязаны з дадзеным званнем. Шлях да малюнка задаецца адносна каранёвай папкі phpBB.',
	'RANK_IMAGE_IN_USE'		=> '(выкарыстоўваецца)',
	'RANK_MINIMUM'			=> 'Мінімум паведамленняў',
	'RANK_REMOVED'			=> 'Званне паспяхова выдаленае.',
	'RANK_SPECIAL'			=> 'Адмысловае званне',
	'RANK_TITLE'			=> 'Загаловак звання',
	'RANK_UPDATED'			=> 'Званне паспяхова абноўленае.',
));

// Disallow Usernames
$lang = array_merge($lang, array(
	'ACP_DISALLOW_EXPLAIN'	=> 'Тут вы можаце кіраваць імёнамі карыстальнікаў, забароненымі для выкарыстання. Забароненыя імёны могуць утрымоўваць падстаноўныя знакі (*).',
	'ADD_DISALLOW_EXPLAIN'	=> 'Тут вы можаце забараніць імя карыстальніка. Выкарыстайце зорачку (*) у якасці падстаноўнага знака для любых знакаў.',
	'ADD_DISALLOW_TITLE'	=> 'Дадаць забароненае імя',

	'DELETE_DISALLOW_EXPLAIN'	=> 'Вы можаце выдаліць імя з спісу забароненых, вылучыўшы яго і націснуўшы кнопку «Адправіць».',
	'DELETE_DISALLOW_TITLE'		=> 'Выдаліць імя з спісу забароненых',
	'DISALLOWED_ALREADY'		=> 'Уведзенае імя ўжо забароненае.',
	'DISALLOWED_DELETED'		=> 'Забароненае імя паспяхова выдаленае.',
	'DISALLOW_SUCCESSFUL'		=> 'Забароненае імя паспяхова дададзена.',

	'NO_DISALLOWED'				=> 'Няма забароненых імёнаў',
	'NO_USERNAME_SPECIFIED'		=> 'Не вылучана або не зададзена імя.',
));

// Reasons
$lang = array_merge($lang, array(
	'ACP_REASONS_EXPLAIN'	=> 'Тут вы можаце кіраваць чыннікамі, выкарыстоўванымі ў скаргах і апавяшчэннях аб адхіленні паведамленняў карыстальнікаў. Чыннік, пазначаная зорачкай, не можа быць выдаленая. Звычайна гэты чыннік выкарыстоўваецца ў выпадку, калі іншыя наяўныя чыннікі не падыходзяць пад скаргу карыстальніка.',
	'ADD_NEW_REASON'		=> 'Дадаць чыннік',
	'AVAILABLE_TITLES'		=> 'Даступныя чыннікі на іншых мовах',

	'IS_NOT_TRANSLATED'			=> 'Чыннік <strong>не</strong> лакалізаваная.',
	'IS_NOT_TRANSLATED_EXPLAIN'	=> 'Чыннік <strong>не</strong> лакалізаваная. Калі вы жадаеце падаць лакалізаваную форму, то пакажыце правільны ключ з моўных файлаў раздзелу чыннікаў і скарг.',
	'IS_TRANSLATED'				=> 'Чыннік лакалізаваная',
	'IS_TRANSLATED_EXPLAIN'		=> 'Чыннік лакалізаваная. Калі ўведзены загаловак паказаны ў моўных файлах у раздзеле чыннікаў і скарг, то будзе выкарыстоўвацца лакалізаваная форма загалоўка і апісанні чынніку.',

	'NO_REASON'					=> 'Чыннік не знойдзеная.',
	'NO_REASON_INFO'			=> 'Неабходна ўвесці загаловак і апісанне гэтага чынніку.',
	'NO_REMOVE_DEFAULT_REASON'	=> 'Нельга выдаліць чыннік «Іншае».',

	'REASON_ADD'				=> 'Даданне чынніку скаргі або адмовы',
	'REASON_ADDED'				=> 'Чыннік скаргі або адмовы паспяхова дададзеная.',
	'REASON_ALREADY_EXIST'		=> 'Чыннік з такім загалоўкам ужо існуе. Увядзіце іншы загаловак.',
	'REASON_DESCRIPTION'		=> 'Апісанне чынніку',
	'REASON_DESC_TRANSLATED'	=> 'Якое адлюстроўваецца апісанне чынніку',
	'REASON_EDIT'				=> 'Змена чынніку або адмовы',
	'REASON_EDIT_EXPLAIN'		=> 'Тут вы можаце дадаць або змяніць чыннік. Калі чыннік перакладзеная, то выкарыстоўваецца лакалізаваная версія, замест уведзенага тут апісання.',
	'REASON_REMOVED'			=> 'Чыннік скаргі або адмовы паспяхова выдаленая.',
	'REASON_TITLE'				=> 'Загаловак чынніку',
	'REASON_TITLE_TRANSLATED'	=> 'Які адлюстроўваецца загаловак чынніку',
	'REASON_UPDATED'			=> 'Чыннік скаргі або адмовы паспяхова абноўленая.',

	'USED_IN_REPORTS'		=> 'Выкарыстоўваецца ў скаргах',
));

?>
