<?php
/**
*
* help_faq [Belarusian]
*
* @package language
* @version $Id: help_faq.php,v 1.42 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
*/
if (!defined('IN_PHPBB'))
{
   exit;
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$help = array(
	array(
		0 => '--',
		1 => 'Уваход на канферэнцыю і рэгістрацыя'
	),
	array(
		0 => 'Чаму я не магу ўвайсці?',
		1 => 'Існуе некалькі магчымых прычын. Першым чынам упэўніцеся, што вы правільна ўводзіце імя карыстальніка і пароль. Калі дадзеныя ўведзеныя правільна, звяжыцеся з адміністратарам, каб праверыць, не ці быў вам зачынены доступ да канферэнцыі. Таксама магчыма, што адміністратар няправільна наладзіў канфігурацыю канферэнцыі, звяжыцеся з ім для выпраўлення налад.'
	),
	array(
		0 => 'Навошта мне наогул трэба рэгістравацца?',
		1 => 'Вы можаце гэтага і не рабіць. Усё залежыць ад таго, як адміністратар наладзіў канферэнцыю: ці павінны вы зарэгістравацца, каб размяшчаць паведамленні або няма. Тым не менш, рэгістрацыя дае вам дадатковыя магчымасці, якія недаступныя ананімным карыстальнікам: аватары, асабістыя паведамленні, адпраўка email-паведамленняў, удзел у групах і г.д. Рэгістрацыя зойме ў вас усяго пару хвілін, таму мы рэкамендуем гэта зрабіць.'
	),
	array(
		0 => 'Чаму мне перыядычна прыходзіцца паўтараць увод імя і пароля?',
		1 => 'Калі вы не адзначылі сцяжком пункт <em>Аўтаматычна ўваходзіць пры кожным наведванні</em>, вы зможаце заставацца пад сваім імем на канферэнцыі толькі некаторы абмежаваны час. Гэта зроблена для таго, каб ніхто іншы не змог скарыстацца вашым уліковым запісам. Для таго каб вам не прыходзілася ўводзіць імя карыстальніка і пароль штораз, вы можаце вылучыць паказаны пункт пры ўваходзе на канферэнцыю. Не рэкамендуецца рабіць гэта на агульнадаступным кампутары, напрыклад у бібліятэцы, інтэрнэт-кафэ, універсітэце і г.д. Калі пункт <em>Аўтаматычна ўваходзіць пры кожным наведванні</em> адсутнічае, значыць адміністратар адключыў гэтую функцыю.'
	),
	array(
		0 => 'Як зрабіць, каб я не з\'яўляўся ў спісе актыўных карыстальнікаў?',
		1 => 'У наладах асабістага раздзелу вы знойдзеце опцыю <em>Хаваць маё знаходжанне на канферэнцыі</em>. Вылучыце <em>Так</em>, і вы будзеце бачныя толькі адміністратарам, мадэратарам і самому сабе. Для ўсіх астатніх вы будзеце ўтоеным карыстальнікам.'
	),
	array(
		0 => 'Я забыў пароль!',
		1 => 'Не панікуйце! Хоць пароль нельга аднавіць, можна лёгка атрымаць новы. Перайдзіце на старонку ўваходу на канферэнцыю і пстрыкніце на спасылку <em>Забылі пароль?</em>. Прытрымлівайцеся інструкцыям, і хутка вы зноўку зможаце ўвайсці на канферэнцыю.'
	),
	array(
		0 => 'Я толькі што зарэгістраваўся, але не магу ўвайсці!',
		1 => 'Спачатку праверце свае імя карыстальніка і пароль. Калі яны дакладныя, то магчымыя два варыянту. Калі ўключаная падтрымка COPPA і пры рэгістрацыі вы паказалі, што вам меней 13 гадоў, прытрымлівайцеся атрыманым інструкцыям. На некаторых канферэнцыях патрабуецца, каб усе новыя ўліковыя запісы былі актываваныя карыстальнікамі або адміністратарам да ўваходу ў сістэму. Гэтая інфармацыя адлюстроўваецца ў працэсе рэгістрацыі. Калі вам быў даслана email-паведамленне, прытрымлівайцеся атрыманым інструкцыям. Калі email-паведамленне не атрымана, то магчыма, што вы паказалі няправільны адрас email, альбо ён заблакаваны спам-фільтрам. Калі вы ўпэўненыя, што ўвялі правільны адрас email, паспрабуйце звязацца з адміністратарам.'
	),
	array(
		0 => 'Я даўно зарэгістраваны, але больш не магу ўвайсці!',
		1 => 'Магчыма, адміністратар па нейкай прычыне дэактываваў або выдаліў ваш уліковы запіс. Акрамя таго, шматлікія канферэнцыі перыядычна выдаляюць карыстальнікаў, якія працяглы час не пакідаюць паведамленні, каб паменшыць памер базы дадзеных. Калі гэта адбылося, паспрабуйце зарэгістравацца зноўку і актыўней удзельнічаць у дыскусіях.'
	),
	array(
		0 => 'Што такое COPPA?',
		1 => 'COPPA (Child Online Privacy and Protection Act), або Акт аб абароне дзеляў мае рацыю дзіцяці ў інтэрнэце ад 1998 г. — гэта закон Злучаных Штатаў, які патрабуе ад бачын, якія могуць збіраць інфармацыю ад непаўналетніх узросту малодшай 13-і гадоў, мець на гэтую пісьмовую згоду бацькоў. Дапушчальна наяўнасць іншага выгляду пацверджання таго, што апякуны дазваляюць збор асабістай інфармацыі ад непаўналетніх узросту малодшай 13-і гадоў. Калі вы не ўпэўненыя, ці дастасавальна гэта да вас, як да які рэгіструецца на канферэнцыі, або да самой канферэнцыі, звернецеся за дапамогай да юрыстконсульту. Звернеце ўвагу, што phpBB Group не можа даваць рэкамендацый па прававых пытаннях і не з\'яўляецца аб\'ектам юрыдычных адносін, акрамя паказаных ніжэй.<br /><strong>Нататка перакладніка: у Расіі дадзены акт не мае юрыдычнай сілы.</strong>',
	),
	array(
		0 => 'Чаму я не магу зарэгістравацца?',
		1 => 'Магчыма, адміністратар канферэнцыі заблакаваў ваш IP-адрас або забараніў імя, пад якім вы спрабуеце зарэгістравацца. Ён таксама мог адключыць рэгістрацыю новых карыстальнікаў. Звернецеся за дапамогай да адміністратара канферэнцыі.',
	),
	array(
		0 => 'Што робіць функцыя «Выдаліць cookies канферэнцыі»?',
		1 => 'Яна выдаляе ўсё створаныя cookies, якія дазваляюць вам заставацца аўтарызаванымі на гэтай канферэнцыі, а таксама выконвае іншыя функцыі, такія, як адсочванне прачытаных паведамленняў, калі гэтая магчымасць уключаная адміністратарам. Калі вы выпрабоўваеце цяжкасці з уваходам або выхадам з канферэнцыі, магчыма, выдаленне cookies дапаможа.',
	),
	array(
		0 => '--',
		1 => 'Параметры і налады карыстальніка'
	),
	array(
		0 => 'Як мне змяніць мае налады?',
		1 => 'Калі вы з\'яўляецеся зарэгістраваным карыстальнікам, усе вашы налады захоўваюцца ў базе дадзеных канферэнцыі. Каб змяніць іх, перайдзіце ў <em>Асабісты раздзел</em>; спасылка на яго звычайна находзіцца ўгары старонкі. Там вы можаце змяніць усе свае налады.'
	),
	array(
		0 => 'На канферэнцыі няправільны час!',
		1 => 'Магчыма, адлюстроўваецца час, якое адносіцца да іншага гадзіннага пояса, а не да таго, у якім находзіцеся вы. У гэтым выпадку зменіце ў асабістых наладах гадзінны пояс на той, у якім вы находзіцеся: Масква, Кіеў і г.д. Улічыце, што змяняць гадзінны пояс, як і большасць налад, могуць толькі зарэгістраваныя карыстальнікі. Калі вы не зарэгістраваныя, то зараз удалы момант зрабіць гэта. '
	),
	array(
		0 => 'Я змяніў гадзінны пояс, але час усё роўна няправільнае!',
		1 => 'Калі вы ўпэўненыя, што правільна паказалі гадзінны пояс і наладу летняга часу, але час адлюстроўваецца па-ранейшаму няслушнае, значыць, няправільна ўсталявана час на серверы. Апавесціце адміністратара для ўхілення праблемы.'
	),
	array(
		0 => 'Маёй мовы няма ў спісе!',
		1 => 'Адміністратар не ўсталяваў падтрымку вашай мовы на канферэнцыі, або жа проста ніхто не перавёў phpBB на вашу мову. Паспрабуйце пазнаць у адміністратара канферэнцыі, ці можа ён усталяваць патрэбны вам моўны пакет. Калі такога моўнага пакета не існуе, то вы самі можаце перавесці phpBB на сваю мову. Дадатковую інфармацыю вы можаце атрымаць на бачыне phpBB (спасылка находзіцца ўнізе старонак канферэнцыі)'
	),
	array(
		0 => 'Як я магу змясціць малюнак пад сваім імем?',
		1 => 'Пад імем карыстальніка могуць быць два малюнка. У залежнасці ад выкарыстоўванага стылю, першае можа ставіцца да вашага звання, звычайна гэта зорачкі, квадрацікі або кропкі, якія паказваюць на то, колькі паведамленняў вы пакінулі або на ваш статут на канферэнцыі. Другое, звычайна буйнейшы малюнак, вядома як «аватара» і звычайна ўнікальная для кожнага карыстальніка. Ад адміністратара залежыць, ці ўключаная падтрымка аватар, і ад яго жа залежыць, якія аватары могуць быць скарыстаныя. Калі вы не можаце выкарыстаць аватары, звяжыцеся з адміністратарам канферэнцыі для высвятлення чыннікаў.'
	),
	array(
		0 => 'Што такое званне і як я магу змяніць яго?',
		1 => 'Званні, якія адлюстроўваюцца пад вашым імем, адлюстроўваюць колькасць створаных вамі паведамленняў, або ідэнтыфікуюць вызначаных карыстальнікаў: напрыклад, мадэратараў і адміністратараў. Звычайна вы не можаце напроста змяняць найменні званняў на канферэнцыі, бо яны ўсталяваныя яе адміністратарам. Калі ласка, не засмечвайце канферэнцыю непатрэбнымі паведамленнямі толькі для таго, каб падвысіць сваё званне. На большасці канферэнцый гэта забароненае, і мадэратар або адміністратар панізяць значэнне вашага лічыльніка паведамленняў.'
	),
	array(
		0 => 'Калі я пстрыкаю па спасылцы «email» ад мяне патрабуюць увайсці на канферэнцыю?',
		1 => 'Толькі зарэгістраваныя карыстальнікі могуць адпраўляць email-паведамленні іншым карыстальнікам праз убудаваную ў канферэнцыю форму, і толькі калі адміністратар уключыў такую магчымасць. Гэта зроблена для таго, каб прадухіліць злоўжыванні паштовай сістэмай ананімнымі карыстальнікамі.'
	),
	array(
		0 => '--',
		1 => 'Стварэнне паведамленняў'
	),
	array(
		0 => 'Як мне стварыць тэму ў форуме?',
		1 => 'Для стварэння новай тэмы ў форуме пстрыкніце па адпаведнай кнопцы ў акне форума або тэмы. Магчыма, вам прыйдзецца зарэгістравацца, перш чым адправіць паведамленне. Пералік вашых мае рацыю доступу находзіцца ўнізе старонак форума або тэмы. Напрыклад: «Вы можаце пачынаць тэмы», «Вы можаце галасаваць у апытаннях» і т.п.'
	),
	array(
		0 => 'Як мне адрэдагаваць або выдаліць паведамленне?',
		1 => 'Калі вы не з\'яўляецеся адміністратарам або мадэратарам канферэнцыі, вы можаце рэдагаваць і выдаляць толькі свае ўласныя паведамленні. Вы можаце перайсці да рэдагавання, пстрыкнуўшы па кнопцы <em>праўка</em> у адпаведным паведамленні, часам толькі на працягу абмежаванага часу пасля яго стварэння. Калі хтосьці ўжо адказаў на паведамленне, то пад ім з\'явіцца невялікі надпіс, якая паказвае колькасць правак а таксама дату і час апошняй з іх. Гэты надпіс не з\'яўляецца, калі паведамленне рэдагаваў адміністратар або мадэратар, хоць яны могуць самі напісаць аб зробленых зменах па сваім меркаванні. Улічыце, што звычайныя карыстальнікі не могуць выдаліць паведамленне, калі на яго ўжо хтосьці адказаў.'
	),
	array(
		0 => 'Як мне дадаць подпіс да свайго паведамлення?',
		1 => 'Каб дадаць подпіс да паведамлення, вы павінны спачатку стварыць яе ў асабістым раздзеле. Пасля гэтага вы можаце адзначыць сцяжком пункт <em>Далучыць подпіс</em> у форме адпраўкі паведамлення, каб подпіс дадалася. Вы таксама можаце наладзіць даданне подпісу па змаўчанні да ўсіх вашых паведамленняў, зрабіўшы адпаведны выбар у параграфе «Адпраўка паведамленняў» пункта «Асабістыя налады» у асабістым раздзеле. Нягледзячы на гэта, вы зможаце адмяніць даданне подпісу ў асобных паведамленнях, прыбраўшы сцяжок <em>Далучыць подпіс</em> у форме адпраўкі паведамлення.'
	),
	array(
		0 => 'Як мне стварыць апытанне?',
		1 => 'Пры стварэнні тэмы або рэдагаванні першага паведамлення тэмы, пстрыкніце на закладцы або перайдзіце ў форму <em>Стварыць апытанне</em> пад асноўнай формай для стварэння паведамлення, у залежнасці ад выкарыстоўванага стылю; калі вы не бачыце такі закладкі або формы, то вы не маеце мае рацыю на стварэнне апытанняў. Задайце тэму і як мінімум два варыянту адказу ў адпаведных палях, упэўніўшыся, што кожны варыянт находзіцца на асобным радку тэкставага поля. Вы таксама можаце задаць колькасць варыянтаў, якія могуць вылучыць карыстальнікі пры галасаванні, з дапамогай опцыі «Варыянтаў адказу», перыяд правядзення апытання ў днях (0 азначае, што апытанне будзе сталым) і магчымасць карыстальнікаў змяняць варыянт, за які яны прагаласавалі.'
	),
	array(
		0 => 'Чаму я не магу дадаць больш варыянтаў адказу?',
		1 => 'Абмежаванне колькасці варыянтаў адказу ўсталёўваецца адміністратарам канферэнцыі. Калі вам трэба дадаць колькасць варыянтаў, якое перавышае гэтае абмежаванне, звяжыцеся з адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Як мне адрэдагаваць або выдаліць апытанне?',
		1 => 'Гэтак жа, як і паведамленні, апытанні могуць рэдагавацца толькі іх стваральнікамі, мадэратарамі або адміністратарамі. Для рэдагавання апытання перайдзіце да рэдагавання першага паведамлення ў тэме; апытанне заўсёды звязаны менавіта з ім. Калі ніхто не паспеў прагаласаваць, то вы можаце выдаліць апытанне або адрэдагаваць любы з варыянтаў адказу. Аднак, калі хтосьці ўжо прагаласаваў, то толькі мадэратары або адміністратары могуць адрэдагаваць або выдаліць апытанне. Гэта зроблена для таго, каб нельга было мяняць варыянты адказаў падчас галасавання.'
	),
	array(
		0 => 'Чаму мне недаступныя некаторыя форумы?',
		1 => 'Некаторыя форумы даступныя толькі вызначаным карыстальнікам або групам карыстальнікаў. Каб іх праглядаць, ствараць паведамленні і здзяйсняць іншыя дзеянні, вам можа запатрабавацца адмысловы дазвол. Звяжыцеся з мадэратарам або адміністратарам канферэнцыі для атрымання такога дазволу.'
	),
	array(
		0 => 'Чаму я не магу дадаваць укладанні?',
		1 => 'Права даданні ўкладанняў можа быць прадстаўлена на ўзроўні форума, групы або карыстальніка. Адміністратар канферэнцыі можа не дазволіць даданне ўкладанняў у вызначаных форумах. Таксама магчыма, што дадаваць укладанні дазволена толькі чальцам вызначаных груп. Калі вы не ведаеце, чаму не можаце дадаваць укладанні, звяжыцеся з адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Чаму я атрымаў папярэджанне?',
		1 => 'На кожнай канферэнцыі адміністратары ўсталёўваюць свой уласны збор правілаў. Калі вы парушылі правіла, вы можаце атрымаць папярэджанне. Улічыце, што гэтае рашэнне адміністратара канферэнцыі, і phpBB Group не мае ніякага дачынення да папярэджанняў, вынесеным на дадзенай бачыне. Калі вы не ведаеце, завошта атрымалі папярэджанне, звяжыцеся з адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Як мне паскардзіцца на паведамленні мадэратару?',
		1 => 'Побач з кожным паведамленнем вы ўбачыце кнопку, прызначаную для адпраўкі скаргі на яго, калі гэта дазволена адміністратарам канферэнцыі. Пстрыкнуўшы па гэтай кнопцы, вы пройдзеце праз шэраг крокаў, неабходных для апраўкі скаргі на паведамленне.'
	),
	array(
		0 => 'Што азначае кнопка «Захаваць» пры стварэнні паведамлення?',
		1 => 'Гэтая кнопка дазваляе вам захоўваць паведамленні для таго, каб скончыць і адправіць іх пазней. Для загрузкі захаванага паведамлення перайдзіце ў параграф «Чарнавікі» асабістага раздзелу.'
	),
	array(
		0 => 'Чаму маё паведамленне патрабуе ўхвалы?',
		1 => 'Адміністратар канферэнцыі можа рашыць, што паведамленні патрабуюць папярэдняга прагляду перад адпраўкай на форум. Магчыма таксама, што адміністратар уключыў вас у групу карыстальнікаў, паведамленні якіх, па яго або яе меркаванню, павінны быць папярэдне прагледжаныя перад адпраўкай. Калі ласка, звяжыцеся з адміністратарам канферэнцыі для атрымання дадатковай інфармацыі.'
	),
	array(
		0 => 'Як мне ізноў падняць маю тэму?',
		1 => 'Пстрыкнуўшы па спасылцы «Падняць тэму» пры праглядзе тэмы, вы можаце «падняць» яе ў верхнюю частку першай старонкі форума. Калі гэтага не адбываецца, то гэта азначае, што магчымасць узняцця тэм магла быць адключаная, або час, якое павінна прайсці да паўторнага ўзняцця тэмы, яшчэ не прайшло. Таксама можна падняць тэму, проста адказаўшы на яе, аднак пераканайцеся, што тым самым вы не парушаеце правілы канферэнцыі, на якой находзіцеся.'
	),
	array(
		0 => '--',
		1 => 'Фарматаванне паведамленняў і тыпы ствараемых тэм'
	),
	array(
		0 => 'Што такое BBCode?',
		1 => 'BBCode — гэта адмысловая рэалізацыя HTML, якая прапануе вялікія магчымасці па фарматаванні асобных частак паведамлення. Магчымасць выкарыстання BBCode вызначаецца адміністратарам, аднак BBCode таксама можа быць адключаны на ўзроўні паведамлення ў форме для яго адпраўкі. BBCode вельмі падобны на HTML, але тэгі ў ім складаюцца ў квадратныя дужкі [ і ], а не ў &lt; and &gt;. За дадатковай інфармацыяй аб BBCode звернецеся да кіраўніцтва па BBCode, спасылка на якое даступная з формы адпраўкі паведамленняў.'
	),
	array(
		0 => 'Ці магу я выкарыстаць HTML?',
		1 => 'Не. На гэтай канферэнцыі немагчымыя адпраўка і апрацоўка HTML кода ў паведамленнях. Вялікая частка магчымасцяў HTML па фарматаванні паведамленняў можа быць рэалізаваная з выкарыстаннем BBCode.'
	),
	array(
		0 => 'Што такое смайлікі?',
		1 => 'Смайлікі, або эматыконы — гэта маленькія малюначкі, якія могуць быць скарыстаныя для выраза пачуццяў, напрыклад :) азначае радасць, а :( азначае журботнасць. Поўны спіс смайлікаў можна ўбачыць у форме стварэння паведамленняў. Толькі не перастарайцеся, выкарыстаючы іх: яны лёгка могуць зрабіць паведамленне нечытэльным, і мадэратар можа адрэдагаваць ваша паведамленне, або наогул выдаліць яго. Адміністратар канферэнцыі таксама можа абмежаваць колькасць смайлікаў, якое можна выкарыстаць у паведамленні.'
	),
	array(
		0 => 'Ці магу я дадаваць малюнкі да паведамленняў?',
		1 => 'Так, вы можаце размяшчаць малюнкі ў вашых паведамленнях. Калі адміністратар дазволіў дадаваць укладанні, вы можаце загрузіць малюнак на канферэнцыю. Калі няма, вы павінны паказаць спасылку на малюнак, захаванае на агульнадаступным вэб-серверы. Прыклад спасылкі: http://www.example.com/my-picture.gif. Вы не можаце паказваць спасылку не на малюнкі, якія захоўваюцца на вашым кампутары (калі ён не з\'яўляецца агульнадаступным серверам), не на малюнкі, для доступу да якіх неабходная аўтэнтыфікацыя, як, напрыклад, на паштовыя скрыні hotmail або yahoo, абароненыя паролямі бачыны і т.п. Для ўказання спасылак на малюнкі выкарыстайце ў паведамленнях тэг BBCode [img].'
	),
	array(
		0 => 'Што такое важныя аб\'явы?',
		1 => 'Гэтыя аб\'явы ўтрымоўваюць важную інфармацыю, і вы павінны прачытаць іх па магчымасці. Яны з\'яўляюцца ўгары кожнага з форумаў і ў вашым асабістым раздзеле. Правы на стварэнне важных аб\'яў падаюцца адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Што такое аб\'явы?',
		1 => 'Аб\'явы часцей за ўсё ўтрымоўваюць важную інфармацыю для форума, на якім вы находзіцеся ў сапраўдны момант, і вы павінны прачытаць іх па магчымасці. Аб\'явы з\'яўляюцца ўгары кожнай старонкі форума, у якім яны створаныя. Гэтак жа, як і з важнымі аб\'явамі, правы на стварэнне аб\'яў падаюцца адміністратарам.'
	),
	array(
		0 => 'Што такое прылепленыя тэмы?',
		1 => 'Прылепленыя тэмы ў форуме находзяцца ніжэй усіх аб\'яў і толькі на яго першай старонцы. Яны часцей за ўсё ўтрымоўваюць досыць важную інфармацыю, таму вы павінны прачытаць іх па магчымасці. Гэтак жа, як і з аб\'явамі, правы на стварэнне прылепленых тэм падаюцца адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Што такое зачыненыя тэмы?',
		1 => 'Гэта такія тэмы, у якіх карыстальнікі больш не могуць пакідаць паведамленні, і ўсё змешчаныя ў іх апытанні аўтаматычна завяршаюцца. Тэмы могуць быць зачыненыя па шматлікіх чынніках мадэратарам форума або адміністратарам канферэнцыі. Вы таксама можаце мець магчымасць зачыняць створаныя вамі тэмы, у залежнасці ад мае рацыю, прадстаўленых вам адміністратарам канферэнцыі.'
	),
	array(
		0 => 'Што такое значкі тэм?',
		1 => 'Значкі тэм — гэта вылучаныя аўтарамі малюнка, звязаныя з паведамленнямі і якія адлюстроўваюць іх змест. Магчымасць выкарыстання значкоў тэм залежыць ад дазволаў, усталяваных адміністратарам канферэнцыі.'
	),
	// This block will switch the FAQ-Questions to the second template column
	array(
		0 => '--',
		1 => '--'
	),
	array(
		0 => '--',
		1 => 'Узроўні карыстальнікаў і групы'
	),
	array(
		0 => 'Хто такія адміністратары?',
		1 => 'Адміністратары — гэта карыстальнікі, нададзеныя вышэйшым узроўнем кантролю над канферэнцыяй. Яны могуць кіраваць усімі аспектамі працы канферэнцыі, уключаючы размежаванне мае рацыю доступу, адключэнне карыстальнікаў, стварэнне груп карыстальнікаў, прызначэнне мадэратараў і т.п., у залежнасці ад мае рацыю, прадстаўленых ім стваральнікам канферэнцыі. Яны таксама могуць валодаць усімі магчымасцямі мадэратараў ва ўсіх форумах, у залежнасці ад налад, вырабленых стваральнікам канферэнцыі.'
	),
	array(
		0 => 'Хто такія мадэратары?',
		1 => 'Мадэратары — гэта карыстальнікі (або групы карыстальнікаў), якія штодня сочаць за форумамі. Яны маюць права рэдагаваць або выдаляць паведамленні, зачыняць, адчыняць, перамяшчаць, выдаляць і аб\'ядноўваць тэмы на форуме, за які яны адказваюць. Асноўныя задачы мадэратараў — не дапушчаць неадпаведнасці зместа паведамленняў якія абмяркоўваюцца тэмам (афтопік), абраз.'
	),
	array(
		0 => 'Што такое групы карыстальнікаў?',
		1 => 'Групы карыстальнікаў разбіваюць супольнасць на структурныя часткі, кіраваныя адміністратарам канферэнцыі. Кожны карыстальнік можа складацца ў некалькіх групах, і кожнай групе могуць быць прызначаныя індывідуальныя правы доступу. Гэта палягчае адміністратарам прызначэнне мае рацыю доступу адначасова вялікай колькасці карыстальнікаў, напрыклад, змена мадэратарскіх мае рацыю або падаванне карыстальнікам доступу да прыватных форумаў.'
	),
	array(
		0 => 'Дзе находзяцца групы і як мне ўступіць у іх?',
		1 => 'Вы можаце атрымаць інфармацыю аб усіх наяўных групах па спасылцы «Групы» у вашым асабістым раздзеле. Калі вы жадаеце ўступіць у адну з іх, націсніце адпаведную кнопку. Аднак, не ўсе групы агульнадаступныя. Некаторыя могуць патрабаваць ухвалы для ўступа ў іх, могуць быць зачыненымі або нават утоенымі. Калі група агульнадаступная, то вы можаце запытаць чалецтва ў ёй, пстрыкнуўшы па адпаведнай кнопцы. Калі патрабуецца ўхвала на ўдзел у групе, вы можаце адправіць запыт на ўступ, пстрыкнуўшы па адпаведнай кнопцы. Лідэр групы павінен будзе ўхваліць ваш удзел у групе і можа спытаць, навошта вы жадаеце далучыцца. Калі ласка, не турбуйце лідэра групы, калі ён адхіліў ваш запыт; у яго могуць быць для гэтага свае чыннікі.'
	),
	array(
		0 => 'Як мне стаць лідэрам групы?',
		1 => 'Лідэры груп звычайна прызначаюцца пры іх стварэнні адміністратарамі канферэнцыі. Калі вы зацікаўленыя ў стварэнні групы, спачатку звяжыцеся з адміністратарам; паспрабуйце адправіць яму асабістае паведамленне.'
	),
	array(
		0 => 'Чаму назовы некаторых груп маюць розныя колеры?',
		1 => 'Адміністратар канферэнцыі можа прысвойваць колеры ўдзельнікам груп для таго, каб іх было прасцей адрозніваць сябар ад сябра.'
	),
	array(
		0 => 'Што такое група па змаўчанні?',
		1 => 'Калі вы складаецеся больш за ў адной групе, ваша група па змаўчанні выкарыстоўваецца для таго, каб вызначыць, якія групавыя колер і званне павінны быць вам прысвоеныя. Адміністратар канферэнцыі можа падаць вам дазвол самому змяняць вашу групу па змаўчанні ў асабістым раздзеле.'
	),
	array(
		0 => 'Што азначае спасылка «Наша каманда»?',
		1 => 'На гэтай старонцы вы знойдзеце спіс адміністратараў і мадэратараў канферэнцыі і іншую інфармацыю, такую, як звесткі аб форумах, якія яны мадэруюць.'
	),
	array(
		0 => '--',
		1 => 'Асабістыя паведамленні'
	),
	array(
		0 => 'Я не магу адправіць асабістыя паведамленні!',
		1 => 'Гэта можа быць выклікана трыма чыннікамі; вы не зарэгістраваныя і/або не ўвайшлі на канферэнцыю, адміністратар забараніў адпраўку асабістых паведамленняў на ўсёй канферэнцыі, або жа адміністратар забараніў гэта вам асабіста. Звяжыцеся з адміністратарам канферэнцыі для атрымання дадатковай інфармацыі.'
	),
	array(
		0 => 'Я стала атрымоўваю непажаданыя асабістыя паведамленні!',
		1 => 'Вы можаце забараніць карыстальніку адпраўляць вам асабістыя паведамленні, выкарыстаючы правілы для паведамленняў у вашым асабістым раздзеле. Калі вы атрымоўваеце абразлівыя асабістыя паведамленні ад пэўнага карыстальніка, паінфармуйце аб гэтым адміністратара канферэнцыі; ён мае магчымасць забараніць карыстальніку адпраўку асабістых паведамленняў.'
	),
	array(
		0 => 'Я атрымаў спам або абразлівы email ад кагосьці з гэтай канферэнцыі!',
		1 => 'Мы шкадуем аб гэтым. Форма адпраўкі email на дадзенай канферэнцыі ўключае меры засцярогі і магчымасць адсочвання карыстальнікаў, якія адпраўляюць падобныя паведамленні. Адпраўце email-паведамленне адміністратару канферэнцыі з поўнай копіяй атрыманага ліста. Вельмі важна ўключыць усе загалоўкі, у якіх утрымоўваецца дэталёвая інфармацыя аб адпраўніку. Адміністратар канферэнцыі зможа ў гэтым выпадку прыняць меры.'
	),
	array(
		0 => '--',
		1 => 'Сябры і злоснікі'
	),
	array(
		0 => 'Што азначаюць спісы сяброў і злоснікаў?',
		1 => 'Вы можаце ўключаць у гэтыя спісы іншых карыстальнікаў канферэнцыі. Карыстальнікі, дададзеныя ў спіс сяброў, будуць паказаныя ў вашым асабістым раздзеле для атрымання хуткага доступу да інфармацыі аб тым, ці находзяцца яны зараз у сеткі, і для адпраўкі ім асабістых паведамленняў. Паведамленні ад гэтых карыстальнікаў таксама могуць вылучацца, калі гэта падтрымліваецца стылем канферэнцыі. Калі вы дадалі карыстальнікаў у спіс злоснікаў, то любыя адпраўленыя імі паведамлення будуць утоеныя па змаўчанні.'
	),
	array(
		0 => 'Як мне дадаваць / выдаляць карыстальнікаў у спісах маіх сяброў і злоснікаў?',
		1 => 'Вы можаце дадаваць карыстальнікаў у свой спіс двума спосабамі. У профілі кожнага карыстальніка ёсць спасылка для яго дадання ў спіс сяброў або злоснікаў. Акрамя таго, вы можаце зрабіць гэта прама з вашага асабістага раздзелу, непасрэдным уводам імя карыстальніка. Вы можаце таксама выдаляць карыстальнікаў з адпаведных спісаў на той жа старонцы.'
	),
	array(
		0 => '--',
		1 => 'Пошук па форумах'
	),
	array(
		0 => 'Як мне выканаць пошук па форуме або форумам?',
		1 => 'Задайце ўмову пошуку ў адпаведным полі, размешчаным на галоўнай старонцы канферэнцыі, старонках прагляду форума або тэмы. Вы можаце ажыццявіць пашыраны пошук, пстрыкнуўшы па спасылцы «Пашыраны пошук», даступнай на ўсіх старонках канферэнцыі. Спосаб доступу да пошуку можа залежаць ад выкарыстоўванага стылю.'
	),
	array(
		0 => 'Чаму мой пошук не дае вынікаў?',
		1 => 'Ваш пошукавы запыт, магчыма, быў занадта нявызначаным, і ўключаў шмат агульных умоў, пошук па якіх у phpBB3 не здзяйсняецца. Для больш дбайнага пошуку выкарыстайце магчымасці пашыранага пошуку.'
	),
	array(
		0 => 'У выніку майго пошуку я атрымаў пустую старонку!',
		1 => 'Ваш пошук даў занадта вялікая колькасць вынікаў, якія вэб-сервер не змог апрацаваць. Выкарыстайце «Пашыраны пошук», больш сапраўды задавайце ўмовы пошуку і форумы, на якіх ён павінен быць ажыццёўлены.'
	),
	array(
		0 => 'Як мне знайсці карыстальніка канферэнцыі?',
		1 => 'Перайдзіце на старонку «Карыстальнікі» і пстрыкніце па спасылцы «Знайсці карыстальніка».'
	),
	array(
		0 => 'Як мне знайсці свае паведамленні і створаныя мной тэмы?',
		1 => 'Вы можаце знайсці свае паведамленні, пстрыкнуўшы альбо па спасылцы «Вашы паведамленні» на галоўнай старонцы, альбо па спасылцы «Знайсці паведамленні карыстальніка» у вашым асабістым раздзеле. Каб знайсці створаныя вам тэмы, выкарыстайце старонку пашыранага пошуку, запоўніўшы адпаведныя крытэры для яго ажыццяўлення.'
	),
	array(
		0 => '--',
		1 => 'Закладкі і падпіска на тэмы'
	),
	array(
		0 => 'Чым адрозніваюцца закладкі ад падпіскі?',
		1 => 'Закладкі ў phpBB3 больш падобныя на закладкі ў вашым вэб-браўзэры. Вы не будзеце папярэджаныя аб якія адбыліся зменах, але зможаце вярнуцца ў тэму пазней. Аднак, аформіўшы падпіску, вы будзеце атрымоўваць апавяшчэнні аб зменах у тэме або форуме на канферэнцыі пераважным вам спосабам або спосабамі.'
	),
	array(
		0 => 'Як мне падпісацца на вызначаную тэму або форум?',
		1 => 'Каб падпісацца на вызначаны форум, зайдзіце на яго і пстрыкніце па спасылцы «Падпісацца на форум». Каб падпісацца на тэму, пастаўце адпаведную галачку пры адпраўцы адказу, альбо пстрыкніце па спасылцы «Падпісацца на тэму» на старонцы прагляду тэмы.'
	),
	array(
		0 => 'Як мне адмовіцца ад падпіскі?',
		1 => 'Для адмовы ад падпіскі перайдзіце ў ваш асабісты раздзел і пстрыкніце па спасылцы «Падпіскі».'
	),
	array(
		0 => '--',
		1 => 'Укладанні'
	),
	array(
		0 => 'Якія ўкладанні дазволеныя на гэтай канферэнцыі?',
		1 => 'Адміністратар кожнай канферэнцыі можа дазволіць або забараніць вызначаныя тыпы ўкладанняў. Калі вы не ведаеце, якія ўкладанні дазволеныя, звяжыцеся з адміністратарам канферэнцыі для атрымання дапамогі.'
	),
	array(
		0 => 'Як мне знайсці мае ўкладанні?',
		1 => 'Каб знайсці спіс дададзеных вамі ўкладанняў, перайдзіце ў ваш асабісты раздзел, і пстрыкніце па спасылцы «Укладанні».'
	),
	array(
		0 => '--',
		1 => 'Інфармацыя аб phpBB 3'
	),
	array(
		0 => 'Хто напісаў гэтую канферэнцыю?',
		1 => 'Гэтае праграмнае забеспячэнне (у яго зыходнай форме) створана і распаўсюджваецца <a href="httpы://www.phpbb.com/">phpBB Group</a>. Яно даступна на ўмовах GNU General Public Licence і можа вольна распаўсюджвацца. Для атрымання больш падрабязных звестак перайдзіце па прыведзенай спасылцы.'
	),
	array(
		0 => 'Чаму тут няма такой-то функцыі?',
		1 => 'Гэтае праграмнае забеспячэнне было створана і ліцэнзавана phpBB Group. Калі вы лічыце, што нейкая функцыя павінна быць дададзеная, ці хочаце паведаміць пра памылку, наведайце сайт phpBB <a href="https://www.phpbb.com/ideas/">phpBB Ideas Centre</a> і даведайцеся, як гэта зрабіць.'
	),
	array(
		0 => 'З кім можна звязацца па пытанні некарэктнага выкарыстання і/або юрыдычных пытанняў, звязаных з гэтай канферэнцыяй?',
		1 => 'Вы можаце звязацца з любым з адміністратараў, пералічаных у спісе на старонцы «Наша каманда». Калі вы не атрымалі адказу, звяжыцеся з уладальнікам дамена (зрабіце <a href="http://www.google.com/search?q=whois">whois lookup</a>) або, калі канферэнцыя находзіцца на бясплатным дамене (напрыклад na.by, Yahoo!, free.fr, f2s.com і т.п.), з кіраўніцтвам або тэхпадтрымкай дадзенага дамена. Улічыце, што phpBB Group <strong>не мае ніякага кантролю над дадзенай канферэнцыяй</strong>, і не можа несці ніякай адказнасці за то, кім і як дадзеная канферэнцыя выкарыстоўваецца. Не звяртайцеся да phpBB Group па юрыдычных пытаннях (аб прыпыненні працы канферэнцыі, адказнасці за яе і г.д.), якія <strong>не ставяцца напроста</strong> да бачыны phpBB.com, або якія часткова ставяцца да праграмнага забеспячэння phpBB Group. Калі жа вы ўсёткі пашлеце email у адрас phpBB Group аб выкарыстанні дадзенай канферэнцыі <strong>трэцім бокам</strong>, то не чакайце падрабязнага ліста, або вы можаце наогул не атрымаць адказу.'
	)
);

?>
