<?php
/**
*
* acp_forums [Belarusian]
*
* @package language
* @version $Id: forums.php,v 1.32 2007/10/05 13:14:58 kellanved Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Forum Admin
$lang = array_merge($lang, array(
	'AUTO_PRUNE_DAYS'			=> 'Аўтаачыстка па даце апошняга паведамлення',
	'AUTO_PRUNE_DAYS_EXPLAIN'	=> 'Колькасць дзён з апошняга паведамлення, па сканчэнні якіх тэма будзе выдаленая.',
	'AUTO_PRUNE_FREQ'			=> 'Частата аўтаматычнай ачысткі',
	'AUTO_PRUNE_FREQ_EXPLAIN'	=> 'Час у днях паміж выкананнем аўтаачысткі.',
	'AUTO_PRUNE_VIEWED'			=> 'Аўтаачыстка па часе прагляду',
	'AUTO_PRUNE_VIEWED_EXPLAIN'	=> 'Колькасць дзён з апошняга прагляду, па сканчэнні якіх тэма будзе выдаленая.',

	'CONTINUE'						=> 'Працягнуць',
	'COPY_PERMISSIONS'				=> 'Капіяваць правы доступу з',
	'COPY_PERMISSIONS_EXPLAIN'		=> 'У мэтах спрашчэння наладкі правоў доступу для новага форуму вы можаце скапіяваць у яго права з іншага існуючага форуму.',
	'COPY_PERMISSIONS_ADD_EXPLAIN'	=> 'Ізноў створанаму форуму будуць прысвоеныя тыя жа правы доступу, што і ў вылучанага з спісу. Калі нічога не вылучана, створаны форум не будзе адлюстроўвацца на канферэнцыі да ўсталёўкі праў доступу.',
	'COPY_PERMISSIONS_EDIT_EXPLAIN'	=> 'Калі вы вылучылі капіяванне праў доступу, форуму будуць прысвоеныя тыя жа правы доступу, што і вылучанаму тут. Усе раней усталяваныя правы доступу да гэтага форума будуць пры гэтым замененыя. Калі форум не вылучаны, будуць захаваныя дзеючыя правы доступу.',
	'COPY_TO_ACL'					=> 'Акрамя таго, вы таксама можаце %sнастроить новыя правы%s для гэтага форуму.',
	'CREATE_FORUM'					=> 'Стварыць форум',

	'DECIDE_MOVE_DELETE_CONTENT'		=> 'Выдаліць змесціва або перамясціць у форум',
	'DECIDE_MOVE_DELETE_SUBFORUMS'		=> 'Выдаліць падфорумы або перамясціць у форум',
	'DEFAULT_STYLE'						=> 'Стыль па змаўчанні',
	'DELETE_ALL_POSTS'					=> 'Выдаліць паведамленні',
	'DELETE_SUBFORUMS'					=> 'Выдаліць падфорумы і паведамленні',
	'DISPLAY_ACTIVE_TOPICS'				=> 'Уключыць актыўныя тэмы',
	'DISPLAY_ACTIVE_TOPICS_EXPLAIN'		=> 'Калі ўключана, у дадзенай катэгорыі будуць адлюстроўвацца актыўныя тэмы з вылучаных падфорумаў.',

	'EDIT_FORUM'					=> 'Рэдагаванне форума',
	'ENABLE_INDEXING'				=> 'Уключыць пошукавае індэксаванне',
	'ENABLE_INDEXING_EXPLAIN'		=> 'Калі ўключана, то паведамленні гэтага форума будуць індэксавацца для пошуку.',
	'ENABLE_POST_REVIEW'			=> 'Уключыць прагляд паведамленняў',
	'ENABLE_POST_REVIEW_EXPLAIN'	=> 'Калі ўключана, карыстальнікі змогуць перагледзець сваё паведамленне, калі падчас яго стварэння ў тэме з\'явіліся новыя паведамленні. Гэтую опцыю пажадана адключаць на чат-форумах.',
	'ENABLE_QUICK_REPLY'			=> 'Ўключыць хуткі адказ',
	'ENABLE_QUICK_REPLY_EXPLAIN'	=> 'Ўключае форму хуткага адказу для гэтага форуму. Настройка не дзейнічае, калі функцыя хуткага адказу на канферэнцыі не ўключаная. Хуткі адказ будзе паказвацца толькі для карыстальнікаў, якія маюць права размяшчаць паведамленні ў дадзеным форуме.',
	'ENABLE_RECENT'					=> 'Паказваць актыўныя тэмы',
	'ENABLE_RECENT_EXPLAIN'			=> 'Калі ўключана, то тэмы гэтага форума будуць адлюстроўвацца ў спісе актыўных тэм.',
	'ENABLE_TOPIC_ICONS'			=> 'Уключыць значкі тэм',

	'FORUM_ADMIN'						=> 'Кіраванне форумамі',
	'FORUM_ADMIN_EXPLAIN'				=> 'phpBB3 заснаваны на форумах. Катэгорыя з\'яўляецца асаблівым тыпам форуму. Кожны форум можа мець неабмежаваную колькасць падфорумаў, і вы можаце вызначаць, дазволена ў ім ствараць тэмы або няма (у апошнім выпадку форум будзе дзейнічаць як катэгорыя ў phpBB2). Тут вы можаце дадаваць, рэдагаваць, зачыняць, адчыняць кожны з форумаў, усталёўваць некаторыя дадатковыя налады. Калі вашы паведамленні і тэмы рассінхранізаваныя, вы можаце таксама сінхранізаваць форум. <strong>Вы павінны скапіяваць або ўсталяваць патрэбныя правы для таго, каб ізноў створаны форум адлюстроўваўся ў спісе форумаў.</strong>',
	'FORUM_AUTO_PRUNE'					=> 'Уключыць аўтаачыстку',
	'FORUM_AUTO_PRUNE_EXPLAIN'			=> 'Чысціць форум ад тэм, усталюеце параметры перыядычнасці/часу ніжэй.',
	'FORUM_CREATED'						=> 'Форум паспяхова створаны.',
	'FORUM_DATA_NEGATIVE'				=> 'Параметры ачысткі не могуць быць адмоўнымі.',
	'FORUM_DESC_TOO_LONG'				=> 'Апісанне форума занадта доўгае. Апісанне не павінна перавышаць 4000 знакаў.',
	'FORUM_DELETE'						=> 'Выдаленне форума',
	'FORUM_DELETE_EXPLAIN'				=> 'Форма ніжэй дазваляе вам выдаліць форум. Калі ў форуме дазволена ствараць паведамленні, вы можаце рашыць, куды перамясціць усё наяўныя ў ім тэмы (форумы).',
	'FORUM_DELETED'						=> 'Форум паспяхова выдалены.',
	'FORUM_DESC'						=> 'Апісанне',
	'FORUM_DESC_EXPLAIN'				=> 'Любая зададзеная тут разметка будзе адлюстраваная ў гэтым жа выглядзе.',
	'FORUM_EDIT_EXPLAIN'				=> 'Форма ніжэй дазваляе вам наладжваць гэты форум. Улічыце, што налады мадэравання і колькасці паведамленняў вырабляюцца ў правах доступу да форумаў для кожнага асобнага карыстальніка або групы.',
	'FORUM_IMAGE'						=> 'Значок форума',
	'FORUM_IMAGE_EXPLAIN'				=> 'Шлях адносна каранёвай папкі phpBB да дадатковага малюнка, асацыяванаму з гэтым форумам.',
	'FORUM_IMAGE_NO_EXIST'				=> 'Паказаны значок форума не існуе',
	'FORUM_LINK_EXPLAIN'				=> 'Поўная спасылка (URL, уключаючы пратакол, напрыклад <samp>http://</samp>), на якую будзе перанакіраваны карыстальнік пры пстрычцы па дадзеным форуме.',
	'FORUM_LINK_TRACK'					=> 'Адсочваць пераходы',
	'FORUM_LINK_TRACK_EXPLAIN'			=> 'Запісвае колькасць пстрычак па спасылцы на форум.',
	'FORUM_NAME'						=> 'Імя форума',
	'FORUM_NAME_EMPTY'					=> 'Неабходна ўвесці імя гэтага форума.',
	'FORUM_PARENT'						=> 'Бацькоўскі форум',
	'FORUM_PASSWORD'					=> 'Пароль да форума',
	'FORUM_PASSWORD_CONFIRM'			=> 'Пацверджанне пароля да форума',
	'FORUM_PASSWORD_CONFIRM_EXPLAIN'	=> 'Неабходна толькі ў выпадку, калі зададзены пароль да форума.',
	'FORUM_PASSWORD_EXPLAIN'			=> 'Усталёўвае пароль для гэтага форума, пераважна выкарыстанне сістэмы праў доступу.',
	'FORUM_PASSWORD_UNSET'				=> 'Выдаліць пароль форума',
	'FORUM_PASSWORD_UNSET_EXPLAIN'		=> 'Адзначце, калі жадаеце выдаліць пароль форума.',
	'FORUM_PASSWORD_OLD'				=> 'Дадзены пароль форума выкарыстае састарэлае шыфраванне і павінен быць зменены.',
	'FORUM_PASSWORD_MISMATCH'			=> 'Уведзеныя паролі не супадаюць.',
	'FORUM_PRUNE_SETTINGS'				=> 'Параметры ачысткі форума',
	'FORUM_RESYNCED'					=> 'Форум «%s» паспяхова сінхранізаваны',
	'FORUM_RULES_EXPLAIN'				=> 'Правілы форума адлюстроўваюцца на кожнай старонцы ў межах дадзенага форума.',
	'FORUM_RULES_LINK'					=> 'Спасылка на правілы форума',
	'FORUM_RULES_LINK_EXPLAIN'			=> 'Тут вы можаце задаць спасылку (URL) на старонку/паведамленне з правіламі форума. Пры гэтым тэкст правілаў форума будзе заменены.',
	'FORUM_RULES_PREVIEW'				=> 'Прагляд правілаў форума',
	'FORUM_RULES_TOO_LONG'				=> 'Правілы форума не павінны перавышаць 4000 знакаў.',
	'FORUM_SETTINGS'					=> 'Налады форума',
	'FORUM_STATUS'						=> 'Статут форума',
	'FORUM_STYLE'						=> 'Стыль форума',
	'FORUM_TOPICS_PAGE'					=> 'Тэм на старонцы',
	'FORUM_TOPICS_PAGE_EXPLAIN'			=> 'Калі выдатна ад нуля, гэтае значэнне заменіць наладу колькасці тэм на старонку па змаўчанні.',
	'FORUM_TYPE'						=> 'Тып форума',
	'FORUM_UPDATED'						=> 'Звесткі аб форуме паспяхова абноўленыя.',

	'FORUM_WITH_SUBFORUMS_NOT_TO_LINK'		=> 'Вы жадаеце змяніць форум з паведамленнямі і падфорумамі на спасылку. Перамесціце ўсе падфорумы ў іншы форум перад выкананнем гэтай працэдуры, інакш вы больш не ўбачыце падфорумы, звязаныя з гэтым форумам.',

	'GENERAL_FORUM_SETTINGS'	=> 'Агульныя налады форума',

	'LINK'					=> 'Спасылка',
	'LIST_INDEX'			=> 'Паказваць падфорум ў легендзе бацькоўскага форума',
	'LIST_INDEX_EXPLAIN'	=> 'Адлюстроўвае спасылку на дадзены форум у спісе падфорумаў бацькоўскага форума, калі такі існуе.',
	'LIST_SUBFORUMS'			=> 'Паказваць падфорумы ў легендзе',
	'LIST_SUBFORUMS_EXPLAIN'	=> 'Паказваць падфорумы форума на галоўнай старонцы і ўсюды як спасылку ў легендзе, калі іх опцыя “Паказваць падфорум ў легендзе бацькоўскага форума” уключаная.',
	'LOCKED'				=> 'Зачынены',

	'MOVE_POSTS_NO_POSTABLE_FORUM'	=> 'The forum you selected for moving the posts to is not postable. Please select a postable forum.',
	'MOVE_POSTS_TO'					=> 'Перамясціць паведамленні ў',
	'MOVE_SUBFORUMS_TO'				=> 'Перамясціць падфорумы ў',

	'NO_DESTINATION_FORUM'			=> 'Не паказаны форум для перамяшчэння змесціва.',
	'NO_FORUM_ACTION'				=> 'Не зададзена дзеянне для змесціва форума.',
	'NO_PARENT'						=> 'Не',
	'NO_PERMISSIONS'				=> 'Не капіяваць правы доступу',
	'NO_PERMISSION_FORUM_ADD'		=> 'У вас няма неабходных праў для дадання форумаў.',
	'NO_PERMISSION_FORUM_DELETE'	=> 'У вас няма неабходных праў для выдалення форумаў.',

	'PARENT_IS_LINK_FORUM'		=> 'Паказаны бацькоўскі форум з\'яўляецца спасылкай. Спасылкі не могуць утрымоўваць форумаў. Пакажыце катэгорыю, або форум у якасці бацькоўскага форума.',
	'PARENT_NOT_EXIST'			=> 'Бацькоўскі форум не існуе.',
	'PRUNE_ANNOUNCEMENTS'		=> 'Ачысціць аб\'явы',
	'PRUNE_STICKY'				=> 'Ачысціць прылепленыя тэмы',
	'PRUNE_OLD_POLLS'			=> 'Ачысціць старыя апытанні',
	'PRUNE_OLD_POLLS_EXPLAIN'	=> 'Выдаляць тэмы, у апытаннях якіх не было галасоў за паказанае вышэй колькасць дзён з апошняга паведамлення.',

	'REDIRECT_ACL'	=> 'Зараз вы можаце %sусталяваць правы доступу%s для гэтага форума.',

	'SYNC_IN_PROGRESS'			=> 'Сінхранізацыя форума',
	'SYNC_IN_PROGRESS_EXPLAIN'	=> 'Ідзе сінхранізацыя тэм %1$d/%2$d.',

	'TYPE_CAT'			=> 'Катэгорыя',
	'TYPE_FORUM'		=> 'Форум',
	'TYPE_LINK'			=> 'Спасылка',

	'UNLOCKED'			=> 'Адчынены',
));

?>
