<?php
/**
*
* acp_groups [Belarusian]
*
* @package language
* @version $Id: groups.php,v 1.29 2007/10/04 15:07:24 acydburn Exp $
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'ACP_GROUPS_MANAGE_EXPLAIN'		=> 'C дапамогай гэтай панэлі вы можаце кіраваць усімі групамі карыстальнікаў. Вы можаце выдаляць іх, ствараць новыя і рэдагаваць наяўныя. Акрамя гэтага, вы можаце прызначаць лідэраў, змяняць адчынены/утоены/зачынены статут груп, а таксама задаваць назовы і апісанні груп.',
	'ADD_USERS'						=> 'Даданне карыстальнікаў',
	'ADD_USERS_EXPLAIN'				=> 'Тут вы можаце дадаваць новых карыстальнікаў у групу. Вы можаце вылучыць, ці стане гэтая група групай па змаўчанні для вылучаных карыстальнікаў. Таксама тутака ж можна прызначаць лідэраў групы. Уводзіце імя кожнага карыстальніка на новым радку.',

	'COPY_PERMISSIONS'				=> 'Капіяваць правы доступу з групы',
	'COPY_PERMISSIONS_EXPLAIN'		=> 'Пасля стварэння група будзе мець тыя жа правы доступу, што і вылучаная тут.',
	'CREATE_GROUP'					=> 'Стварыць групу',

	'GROUPS_NO_MEMBERS'				=> 'У гэтай групе няма карыстальнікаў',
	'GROUPS_NO_MODS'				=> 'Лідэры групы не прызначаныя',

	'GROUP_APPROVE'					=> 'Прыняць кандыдата ў групу',
	'GROUP_APPROVED'				=> 'Удзельнікі групы',
	'GROUP_AVATAR'					=> 'Аватара групы',
	'GROUP_AVATAR_EXPLAIN'			=> 'Гэты малюнак будзе адлюстроўвацца ў панэлі кіравання групай.',
	'GROUP_CLOSED'					=> 'Зачыненая',
	'GROUP_COLOR'					=> 'Колер групы',
	'GROUP_COLOR_EXPLAIN'			=> 'Колер імёнаў карыстальнікаў — удзельнікаў групы. Пакіньце поле пустым для выкарыстання колеру па змаўчанні.',
	'GROUP_CONFIRM_ADD_USER'		=> 'Вы сапраўды жадаеце дадаць карыстальніка %1$s у групу?',
	'GROUP_CONFIRM_ADD_USERS'		=> 'Вы сапраўды жадаеце дадаць карыстальнікаў %1$s у групу?',
	'GROUP_CREATED'					=> 'Група паспяхова створаная.',
	'GROUP_DEFAULT'					=> 'Зрабіць групай па змаўчанні',
	'GROUP_DEFS_UPDATED'			=> 'Для ўсіх вылучаных карыстальнікаў усталяваная група па змаўчанні.',
	'GROUP_DELETE'					=> 'Выдаліць карыстальніка з групы',
	'GROUP_DELETED'					=> 'Група выдаленая і для яе ўдзельнікаў паспяхова ўсталяваныя новыя групы па змаўчанні.',
	'GROUP_DEMOTE'					=> 'Зняць лідэра групы',
	'GROUP_DESC'					=> 'Апісанне групы',
	'GROUP_DETAILS'					=> 'Звесткі аб групе',
	'GROUP_EDIT_EXPLAIN'			=> 'Тут можна змяніць налады наяўнай групы. Вы можаце змяніць назву, апісанне і тып групы (адчыненая, зачыненая і т.п.). Таксама можна ўсталяваць некаторыя дадатковыя параметры, такія, як колер, званне і т.п. Дзеючыя налады карыстальнікаў будуць замененыя ў адпаведнасці з вырабленымі тут зменамі. Звернеце ўвагу: удзельнікі груп могуць змяняць аватары груп на свае, толькі калі вы падалі ім для гэтага адпаведныя правы.',
	'GROUP_ERR_USERS_EXIST'			=> 'Паказаныя карыстальнікі ўжо з\'яўляюцца ўдзельнікамі гэтай групы.',
	'GROUP_FOUNDER_MANAGE'			=> 'Кіруецца толькі фундатарам',
	'GROUP_FOUNDER_MANAGE_EXPLAIN'	=> 'Абмежаваць кіраванне гэтай групай толькі фундатарамі. Карыстальнікі, якія маюць групавыя правы доступу, змогуць бачыць дадзеную групу і яе ўдзельнікаў.',
	'GROUP_HIDDEN'					=> 'Утоеная',
	'GROUP_LANG'					=> 'Мова групы',
	'GROUP_LEAD'					=> 'Лідэры групы',
	'GROUP_LEADERS_ADDED'			=> 'Новыя лідэры паспяхова дададзеныя ў групу.',
	'GROUP_LEGEND'					=> 'Адлюстроўваць групу ў легендзе',
	'GROUP_LIST'					=> 'Дзеючыя ўдзельнікі групы',
	'GROUP_LIST_EXPLAIN'			=> 'Гэта поўны спіс карыстальнікаў, якія з\'яўляюцца ў цяперашні час удзельнікамі гэтай групы. Вы можаце выдаляць удзельнікаў (за выключэннем некаторых адмысловых груп) або дадаваць новых.',
	'GROUP_MEMBERS'					=> 'Удзельнікі групы',
	'GROUP_MEMBERS_EXPLAIN'			=> 'Гэта поўны спіс удзельнікаў групы. Ён складаецца з асобных раздзелаў для лідэраў, кандыдатаў, якія чакаюць уступа ў групу, і дзеючых удзельнікаў. Адгэтуль вы можаце кіраваць усімі аспектамі чалецтва і размеркаванні роляў у групе. Каб выдаліць лідэра, але пакінуць яго ў групе, выкарыстайце опцыю «Зняць лідэра групы» замест «Выдаліць карыстальніка з групы». А каб зрабіць звычайнага ўдзельніка кіраўніком групы, вылучыце опцыю «Прызначыць лідэрам групы».',
	'GROUP_MESSAGE_LIMIT'			=> 'Ліміт асабістых паведамленняў у кожнай папцы',
	'GROUP_MESSAGE_LIMIT_EXPLAIN'	=> 'Гэтая налада адменіць агульны для карыстальнікаў ліміт паведамленняў. Значэнне 0 азначае, што будзе выкарыстоўвацца карыстальніцкі ліміт па змаўчанні.',
	'GROUP_MODS_ADDED'				=> 'Новыя лідэры групы паспяхова дададзеныя.',
	'GROUP_MODS_DEMOTED'			=> 'Вылучаныя лідэры групы паспяхова знятыя.',
	'GROUP_MODS_PROMOTED'			=> 'Вылучаныя ўдзельнікі групы паспяхова прызначаныя лідэрамі.',
	'GROUP_NAME'					=> 'Назва групы',
	'GROUP_NAME_TAKEN'				=> 'Уведзеная назва групы ўжо існуе. Увядзіце іншую назву.',
	'GROUP_OPEN'					=> 'Адчыненая',
	'GROUP_PENDING'					=> 'Кандыдаты на ўступ у групу',
	'GROUP_MAX_RECIPIENTS'			=> 'Максімальная дазволеная колькасць атрымальнікаў АП',
	'GROUP_MAX_RECIPIENTS_EXPLAIN'	=> 'Максімальная дазволеная колькасць атрымальнікаў асабістага паведамлення. Калі зададзена 0, будзе скарыстана адпаведнае значэнне, паказанае ў наладах канферэнцыі.',
	'GROUP_OPTIONS_SAVE'			=> 'Агульныя параметры групы',
	'GROUP_PROMOTE'					=> 'Прызначыць лідэрам групы',
	'GROUP_RANK'					=> 'Званне групы',
	'GROUP_RECEIVE_PM'				=> 'Група можа атрымоўваць асабістыя паведамленні',
	'GROUP_RECEIVE_PM_EXPLAIN'		=> 'Нататка: утоеныя групы не могуць атрымоўваць асабістыя паведамленні, незалежна ад гэтай опцыі.',
	'GROUP_REQUEST'					=> 'Па запыце',
	'GROUP_SETTINGS_SAVE'			=> 'Налады групы',
	'GROUP_SKIP_AUTH'				=> 'Выключыць лідэра групы з правоў',
	'GROUP_SKIP_AUTH_EXPLAIN'		=> 'Пры ўключэнні опцыі лідэр групы не будзе ўспадкаваць правы гэтай групы.',
	'GROUP_TYPE'					=> 'Тып групы',
	'GROUP_TYPE_EXPLAIN'			=> 'Гэтая група налад вызначае, хто можа ўступаць або праглядаць гэтую групу.',
	'GROUP_UPDATED'					=> 'Налады групы паспяхова абноўленыя.',

	'GROUP_USERS_ADDED'				=> 'Новыя карыстальнікі паспяхова дададзеныя ў групу.',
	'GROUP_USERS_EXIST'				=> 'Вылучаныя карыстальнікі ўжо з\'яўляюцца ўдзельнікамі групы.',
	'GROUP_USERS_REMOVE'			=> 'Карыстальнікі выдаленыя з групы і для іх паспяхова ўсталяваныя новыя групы па змаўчанні.',

	'MAKE_DEFAULT_FOR_ALL'	=> 'Зрабіць групай па змаўчанні для кожнага яе ўдзельніка',
	'MEMBERS'				=> 'Удзельнікі',

	'NO_GROUP'					=> 'Група не вызначаная.',
	'NO_GROUPS_CREATED'			=> 'Групы яшчэ не створаныя.',
	'NO_PERMISSIONS'			=> 'Не капіяваць правы доступу',
	'NO_USERS'					=> 'Вы не задалі не аднаго карыстальніка.',
	'NO_USERS_ADDED'			=> 'Карыстальнікі не былі дададзеныя ў групу.',
	'NO_VALID_USERS'			=> 'Вы не задалі аніводнага карыстальніка, падыходзячага да гэтай аперацыі.',

	'SPECIAL_GROUPS'			=> 'Прадусталяваныя групы',
	'SPECIAL_GROUPS_EXPLAIN'	=> 'Прадусталяваныя групы — гэта адмысловыя групы, якія не могуць быць выдаленыя або змененыя напроста. Тым не менш, вы можаце дадаваць карыстальнікаў у гэтыя групы і змяняць асноўныя налады гэтых груп.',

	'TOTAL_MEMBERS'				=> 'Удзельнікі',

	'USERS_APPROVED'				=> 'Карыстальнікі паспяхова ўхваленыя.',
	'USER_DEFAULT'					=> 'Па змаўчанні для карыстальніка',
	'USER_DEF_GROUPS'				=> 'Карыстальніцкія групы',
	'USER_DEF_GROUPS_EXPLAIN'		=> 'Гэтыя групы створаныя вамі або іншым адміністратарам. Вы можаце кіраваць удзельнікамі груп, змяняць налады груп і выдаляць непатрэбныя групы.',
	'USER_GROUP_DEFAULT'			=> 'Прызначыць групай па змаўчанні',
	'USER_GROUP_DEFAULT_EXPLAIN'	=> 'Усталёўка гэтай групы ў якасці групы па змаўчанні для дадаваных у групу карыстальнікаў.',
	'USER_GROUP_LEADER'				=> 'Прызначыць лідэрам групы',
));

?>