<?php
/**
*
* acp_board [Belarusian]
*
* @package language
* @version $Id$
* @copyright (c) 2005 phpBB Group
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Board Settings
$lang = array_merge($lang, array(
	'ACP_BOARD_SETTINGS_EXPLAIN'	=> 'Тут вы можаце ўсталяваць агульныя параметры канферэнцыі, даць ёй імя і апісанне, а таксама паказаць гадзінны пояс і мова, якія будуць выкарыстоўвацца па змаўчанні.',
	'CUSTOM_DATEFORMAT'				=> 'Іншы…',
	'DEFAULT_DATE_FORMAT'			=> 'Фармат даты',
	'DEFAULT_DATE_FORMAT_EXPLAIN'	=> 'Сінтаксіс ідэнтычны функцыі <code>date</code> мовы PHP.',
	'DEFAULT_LANGUAGE'				=> 'Мова канферэнцыі па змаўчанні',
	'DEFAULT_STYLE'					=> 'Стыль канферэнцыі па змаўчанні',
	'DISABLE_BOARD'					=> 'Адключыць канферэнцыю',
	'DISABLE_BOARD_EXPLAIN'			=> 'Канферэнцыя стане недаступнай для карыстальнікаў. Таксама вы можаце ўвесці кароткае паведамленне (да 255 знакаў) для наведвальнікаў.',
	'OVERRIDE_STYLE'				=> 'Замяняць стыль карыстальніка',
	'OVERRIDE_STYLE_EXPLAIN'		=> 'Стыль, вылучаны карыстальнікам, будзе заменены стылем па змаўчанні.',
	'SITE_DESC'						=> 'Апісанне канферэнцыі',
	'SITE_NAME'						=> 'Імя канферэнцыі',
	'SYSTEM_DST'					=> 'Зараз дзейнічае летні час (<abbr title="Летні час">DST</abbr>)',
	'SYSTEM_TIMEZONE'				=> 'Гадзінны пояс па змаўчанні',
	'SYSTEM_TIMEZONE_EXPLAIN'		=> 'Гадзінны пояс для карыстальнікаў, якія не аўтарызаваныя (боты, госьці). Аўтарызаваныя карыстальнікі сайта ўсталёўваюць гадзінны пояс падчас рэгістрацыі і могуць змяніць яго ў панэлі кіравання карыстальніка.',
	'WARNINGS_EXPIRE'				=> 'Працягласць папярэджання',
	'WARNINGS_EXPIRE_EXPLAIN'		=> 'Колькасць дзён, якое павінна прайсці да таго, як папярэджанне будзе аўтаматычна знята з карыстальніка. Усталюйце 0, каб зрабіць папярэджанні бестэрміновымі.',
));

// Board Features
$lang = array_merge($lang, array(
	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'Тут вы можаце ўключаць і адключаць некаторыя функцыі канферэнцыі',

	'ALLOW_ATTACHMENTS'			=> 'Дазволіць укладанні',
	'ALLOW_BIRTHDAYS'			=> 'Дазволіць дні нараджэння',
	'ALLOW_BIRTHDAYS_EXPLAIN'	=> 'Дазволіць паказваць дні нараджэння і адлюстраванні ўзросту ў профілі. Улічыце, што спіс дзён нараджэння на старонцы спісу форумаў уключаецца асобна ў наладах нагрузкі на сервер.',
	'ALLOW_BOOKMARKS'			=> 'Дазволіць закладкі на тэмы',
	'ALLOW_BOOKMARKS_EXPLAIN'	=> 'Карыстальнік зможа захоўваць персанальныя закладкі на любімыя тэмы',
	'ALLOW_BBCODE'				=> 'Дазволіць BBCode',
	'ALLOW_FORUM_NOTIFY'		=> 'Дазволіць падпіску на форумы',
	'ALLOW_NAME_CHANGE'			=> 'Дазволіць змену імя карыстальніка',
	'ALLOW_NO_CENSORS'			=> 'Дазволіць адключэнне аўтацэнзара',
	'ALLOW_NO_CENSORS_EXPLAIN'	=> 'Карыстальнікі змогуць па выбары адключаць аўтацэнзар у звычайных і асабістых паведамленнях.',
	'ALLOW_PM_ATTACHMENTS'		=> 'Дазволіць укладанні ў асабістых паведамленнях',
	'ALLOW_PM_REPORT'			=> 'Дазволіць скаргі на асабістыя паведамленні',
	'ALLOW_PM_REPORT_EXPLAIN'	=> 'Пры ўключэнні гэтай опцыі у карыстальнікаў з\'явіцца магчымасць скардзіцца мадэратарам на атрыманыя імі асабістыя паведамленні ад іншых карыстальнікаў. Абскарджаныя асабістыя паведамленні будуць бачныя ў панэлі мадэратара.',
	'ALLOW_QUICK_REPLY'			=> 'Дазволіць хуткі адказ',
	'ALLOW_QUICK_REPLY_EXPLAIN'	=> 'Пры ўключэнні гэтай опцыі ў неабходных форумах таксама павінна быць уключаная опцыя хуткага адказу.',
	'ALLOW_QUICK_REPLY_BUTTON'	=> 'Адправіць і ўключыць хуткі адказ ва ўсіх форумах',
	'ALLOW_SIG'					=> 'Дазволіць подпісы',
	'ALLOW_SIG_BBCODE'			=> 'Дазволіць BBCode у подпісах карыстальнікаў',
	'ALLOW_SIG_FLASH'			=> 'Дазволіць выкарыстанне тэга BBCode <code>[FLASH]</code> у подпісах карыстальнікаў',
	'ALLOW_SIG_IMG'				=> 'Дазволіць выкарыстанне тэга BBCode <code>[IMG]</code> у подпісах карыстальнікаў',
	'ALLOW_SIG_LINKS'			=> 'Дазволіць спасылкі ў подпісах карыстальнікаў',
	'ALLOW_SIG_LINKS_EXPLAIN'	=> 'У выпадку забароны тэг BBCode <code>[URL]</code> і аўтаматычнае ператварэнне тэксту ў спасылкі будуць адключаныя.',
	'ALLOW_SIG_SMILIES'			=> 'Дазволіць смайлікі ў подпісах карыстальнікаў',
	'ALLOW_SMILIES'				=> 'Дазволіць смайлікі',
	'ALLOW_TOPIC_NOTIFY'		=> 'Дазволіць падпіску на тэмы',
	'BOARD_PM'					=> 'Дазволіць асабістыя паведамленні',
	'BOARD_PM_EXPLAIN'			=> 'Ўключэнне абмену асабістымі паведамленнямі для ўсіх карыстальнікаў.',
));

// Avatar Settings
$lang = array_merge($lang, array(
	'ACP_AVATAR_SETTINGS_EXPLAIN'	=> 'Аватары — гэта невялікія індывідуальныя малюнкі, якія карыстальнікі могуць асацыяваць са сваімі ўліковымі запісамі. У залежнасці ад вылучанага стылю, аватары звычайна адлюстроўваюцца пад імем карыстальніка пры праглядзе тэм. Тут вы можаце наладзіць выкарыстанне аватар карыстальнікамі. Калі ласка, улічыце, што для загрузкі аватар неабходна стварыць папку, імя якой задаецца ніжэй, і пераканацца ў тым, што вэбсервер мае правы на запіс у гэтую папку. Улічыце таксама, што абмежаванне на памер файлаў накладваюцца толькі на загружаныя на сервер аватары, і не распаўсюджваюцца на выдаленыя малюнкі.',

	'ALLOW_AVATARS'					=> 'Дазволіць аватары',
	'ALLOW_AVATARS_EXPLAIN'			=> 'Глабальнае ўключэнне або адключэнне магчымасці выкарыстання аватар. <br /> Заўвага: калі вы адключыце аватары ў цэлым або забараніцк выкарыстанне некаторых рэжымаў аватар, то адключаныя аватары больш не будуць адлюстроўвацца на канферэнцыі, але карыстальнікі па-ранейшаму змогуць загружаць свае аватары ў карыстальніцкай панэлі кіравання.',
	'ALLOW_LOCAL'					=> 'Дазволіць галерэю аватараў',
	'ALLOW_REMOTE'					=> 'Дазволіць выдаленыя аватары',
	'ALLOW_REMOTE_EXPLAIN'			=> 'Спасылкі на аватары з іншых бачын.',
	'ALLOW_REMOTE_UPLOAD'			=> 'Дазволіць загрузку аддаленых аватараў',
	'ALLOW_REMOTE_UPLOAD_EXPLAIN'	=> 'Дазволіць загрузку аватараў з іншых сайтаў.',
	'ALLOW_UPLOAD'					=> 'Дазволіць загрузку аватараў',
	'AVATAR_GALLERY_PATH'			=> 'Шлях да галерэі аватараў',
	'AVATAR_GALLERY_PATH_EXPLAIN'	=> 'Шлях адносна каранёвай папкі phpBB для прадусталяваных аватараў, напрыклад <samp>images/avatars/gallery</samp>.',
	'AVATAR_STORAGE_PATH'			=> 'Шлях да аватараў',
	'AVATAR_STORAGE_PATH_EXPLAIN'	=> 'Шлях адносна каранёвай папкі phpBB, напрыклад  <samp>images/avatars/upload</samp>',
	'MAX_AVATAR_SIZE'				=> 'Максімальныя памеры аватары',
	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Шырыня x вышыня (у піксэлях).',
	'MAX_FILESIZE'					=> 'Максімальны памер файла аватары',
	'MAX_FILESIZE_EXPLAIN'			=> 'Максімальны памер файла для загружаных файлаў аватараў. Калі значэнне роўна 0, памер файла абмежаваны толькі канфігурацыяй PHP.',
	'MIN_AVATAR_SIZE'				=> 'Мінімальныя памеры аватары',
	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Шырыня x вышыня (у піксэлях).',
));

// Message Settings
$lang = array_merge($lang, array(
	'ACP_MESSAGE_SETTINGS_EXPLAIN'		=> 'Тут вы можаце задаць усе налады па змаўчанні для асабістых паведамленняў (АП).',

	'ALLOW_BBCODE_PM'			=> 'Дазволіць BBCode у АП',
	'ALLOW_FLASH_PM'			=> 'Дазволіць тэг BBCode <code>[FLASH]</code>',
	'ALLOW_FLASH_PM_EXPLAIN'	=> 'Улічыце, што магчымасць выкарыстання flash, калі яна ўключаная тут, залежыць таксама ад усталяваных праў доступу.',
	'ALLOW_FORWARD_PM'			=> 'Дазволіць перасыланне АП',
	'ALLOW_IMG_PM'				=> 'Дазволіць тэг BBCode <code>[IMG]</code>',
	'ALLOW_MASS_PM'				=> 'Дазволіць адпраўку АП некалькім карыстальнікам або групам карыстальнікаў',
	'ALLOW_MASS_PM_EXPLAIN'		=> 'Адпраўку групам можна наладзіць для кожный групы на старонцы групы.',
	'ALLOW_PRINT_PM'			=> 'Дазволіць друкаваны выгляд у АП',
	'ALLOW_QUOTE_PM'			=> 'Дазволіць цытаты ў АП',
	'ALLOW_SIG_PM'				=> 'Дазволіць подпісы ў АП',
	'ALLOW_SMILIES_PM'			=> 'Дазволіць смайлікі ў АП',
	'BOXES_LIMIT'				=> 'Максімальная колькасць АП у папцы',
	'BOXES_LIMIT_EXPLAIN'		=> 'Карыстальнікі не змогуць захоўваць больш, чым паказаная колькасць паведамленняў, у кожнай з папак для АП. Усталюеце 0 для здымання абмежаванняў.',
	'BOXES_MAX'					=> 'Максімальная колькасць папак для АП',
	'BOXES_MAX_EXPLAIN'			=> 'Па змаўчанні карыстальнікі не змогуць ствараць больш паказанай колькасці папак для АП.',
	'ENABLE_PM_ICONS'			=> 'Дазволіць выкарыстанне значкоў тэм у АП',
	'FULL_FOLDER_ACTION'		=> 'Дзеянне па змаўчанні для перапоўненай папкі',
	'FULL_FOLDER_ACTION_EXPLAIN'=> 'Дзеянне па змаўчанні, выконваемае для перапоўненай папкі карыстальніка, у выпадку, калі вылучанае карыстальнікам дзеянне для папкі непрыстасавальна. Адзіным выключэннем з\'яўляецца папка «Адпраўленыя», для якой дзеяннем па змаўчанні заўсёды з\'яўляецца выдаленне старых паведамленняў.',
	'HOLD_NEW_MESSAGES'			=> 'Адкласці новыя паведамленні',
	'PM_EDIT_TIME'				=> 'Абмежаваць час рэдагавання',
	'PM_EDIT_TIME_EXPLAIN'		=> 'Абмежаваць час, на працягу якога даступна рэдагаванне адпраўленага, але яшчэ не атрыманага адрасатам асабістага паведамлення. Усталюеце 0 для здымання абмежаванняў.',
	'PM_MAX_RECIPIENTS'			=> 'Максімальная колькасць адрасатаў',
	'PM_MAX_RECIPIENTS_EXPLAIN'	=> 'Максімальная колькасць адрасатаў для АП. Калі ўведзена 0 - то не абмежавана. Гэтую наладу можна вызначыць асобна для кожный групы на старонцы групы.',
));

// Post Settings
$lang = array_merge($lang, array(
	'ACP_POST_SETTINGS_EXPLAIN'			=> 'Тут вы можаце задаць налады па змаўчанні для якія размяшчаюцца паведамленняў.',
	'ALLOW_POST_LINKS'					=> 'Дазволіць спасылкі ў звычайных/асабістых паведамленнях',
	'ALLOW_POST_LINKS_EXPLAIN'			=> 'У выпадку забароны тэг BBCode <code>[URL]</code> і аўтаматычнае ператварэнне тэксту ў спасылкі будуць адключаныя.',
	'ALLOW_POST_FLASH'					=> 'Дазволіць тэг BBCode <code>[FLASH]</code> у паведамленнях. ',
	'ALLOW_POST_FLASH_EXPLAIN'			=> 'Калі тэг BBCode <code>[FLASH]</code> забаронены, ён будзе адключаны ў паведамленнях. Вызначыць карыстальнікаў, якія маюць права выкарыстаць тэг BBCode <code>[FLASH]</code>, можна з дапамогай сістэмы кіравання правамі доступу.',

	'BUMP_INTERVAL'					=> 'Затрымка ўзняцця тэмы',
	'BUMP_INTERVAL_EXPLAIN'			=> 'Колькасць хвілін, гадзін або дзён з апошняга паведамлення, па сканчэнні якіх можна паднімаць тэму. Увядзіце 0 для адключэння гэтай магчымасці.',
	'CHAR_LIMIT'					=> 'Максімальная колькасць сімвалаў у паведамленні',
	'CHAR_LIMIT_EXPLAIN'			=> 'Максімальную колькасць сімвалаў, дазволеных у паведамленнях і ў асабістых паведамленнях. Увядзіце 0 для зняцця абмежаванняў.',
	'DELETE_TIME'					=> 'Абмежаванне часу на выдаленне',
	'DELETE_TIME_EXPLAIN'			=> 'Абмежаванне часу, на працягу якога даступна выдаленне новых паведамленняў. Увядзіце 0 для адключэння гэтай магчымасці.',
	'DISPLAY_LAST_EDITED'			=> 'Адлюстроўваць звесткі аб апошнім рэдагаванні',
	'DISPLAY_LAST_EDITED_EXPLAIN'	=> 'Вылучыце для адлюстравання інфармацыі аб апошнім рэдагаванні паведамлення',
	'EDIT_TIME'						=> 'Абмежаваць час рэдагавання',
	'EDIT_TIME_EXPLAIN'				=> 'Абмежаваць час, на працягу якога даступна рэдагаванне новага паведамлення. Увядзіце 0 для адключэння гэтай магчымасці.',
	'FLOOD_INTERVAL'				=> 'Затрымка флуду',
	'FLOOD_INTERVAL_EXPLAIN'		=> 'Колькасць секунд, якое павінна прайсці паміж двума паведамленнямі карыстальніка. Каб дазволіць карыстальнікам ігнараваць гэтае абмежаванне, усталюеце ім адпаведныя правы.',
	'HOT_THRESHOLD'					=> 'Паведамленняў у папулярнай тэме',
	'HOT_THRESHOLD_EXPLAIN'			=> 'Неабходная колькасць паведамленняў у тэме для таго, каб яна набыла статут папулярнай. Увядзіце 0 для адключэння папулярных тэм.',
	'MAX_POLL_OPTIONS'				=> 'Максімальная колькасць варыянтаў адказу ў апытаннях',
	'MAX_POST_FONT_SIZE'			=> 'Максімальны памер шрыфта ў паведамленні',
	'MAX_POST_FONT_SIZE_EXPLAIN'	=> 'Максімальны памер шрыфта, дазволены ў паведамленні. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_POST_IMG_HEIGHT'			=> 'Максімальная вышыня малюнка ў паведамленні',
	'MAX_POST_IMG_HEIGHT_EXPLAIN'	=> 'Максімальная вышыня малюнкаў/flash у паведамленнях. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_POST_IMG_WIDTH'			=> 'Максімальная шырыня малюнка ў паведамленні',
	'MAX_POST_IMG_WIDTH_EXPLAIN'	=> 'Максімальная шырыня малюнкаў/flash у паведамленнях. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_POST_URLS'					=> 'Максімальная колькасць спасылак у паведамленні',
	'MAX_POST_URLS_EXPLAIN'			=> 'Максімальная колькасць спасылак у паведамленні. Увядзіце 0 для здымання абмежаванняў.',
	'MIN_CHAR_LIMIT'				=> 'Мінімальнае колькасць сімвалаў у паведамленнях',
	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'Мінімальнае колькасць сімвалаў, неабходная для публікацыі паведамленняў і асабістых паведамленняў.',
	'POSTING'						=> 'Размяшчэнне паведамленняў',
	'POSTS_PER_PAGE'				=> 'Паведамленняў на старонцы',
	'QUOTE_DEPTH_LIMIT'				=> 'Максімальная колькасць узроўняў укладання цытат у паведамленні',
	'QUOTE_DEPTH_LIMIT_EXPLAIN'		=> 'Максімальная колькасць узроўняў укладання цытат. Увядзіце 0 для здымання абмежаванняў.',
	'SMILIES_LIMIT'					=> 'Максімальная колькасць смайлікаў у паведамленні',
	'SMILIES_LIMIT_EXPLAIN'			=> 'Максімальная колькасць смайлікаў у паведамленні. Увядзіце 0 для здымання абмежаванняў.',
	'SMILIES_PER_PAGE'				=> 'Смайлікаў на старонцы',
	'TOPICS_PER_PAGE'				=> 'Тэм на старонцы',
));

// Signature Settings
$lang = array_merge($lang, array(
	'ACP_SIGNATURE_SETTINGS_EXPLAIN'	=> 'Тут вы можаце задаць налады па змаўчанні для подпісаў.',

	'MAX_SIG_FONT_SIZE'				=> 'Максімальны памер шрыфта ў подпісы',
	'MAX_SIG_FONT_SIZE_EXPLAIN'		=> 'Максімальны памер шрыфта, дазволены ў подпісах карыстальнікаў. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_SIG_IMG_HEIGHT'			=> 'Максімальная вышыня малюнка ў подпісы',
	'MAX_SIG_IMG_HEIGHT_EXPLAIN'	=> 'Максімальная вышыня малюнка/flash у подпісах карыстальнікаў. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_SIG_IMG_WIDTH'				=> 'Максімальная шырыня малюнка ў подпісы',
	'MAX_SIG_IMG_WIDTH_EXPLAIN'		=> 'Максімальная шырыня малюнка/flash у подпісах карыстальнікаў. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_SIG_LENGTH'				=> 'Максімальная даўжыня подпісу',
	'MAX_SIG_LENGTH_EXPLAIN'		=> 'Максімальная колькасць знакаў у подпісах карыстальнікаў.',
	'MAX_SIG_SMILIES'				=> 'Максімум смайлікаў у подпісы',
	'MAX_SIG_SMILIES_EXPLAIN'		=> 'Максімальная колькасць смайлікаў, дазволенае ў подпісах карыстальнікаў. Увядзіце 0 для здымання абмежаванняў.',
	'MAX_SIG_URLS'					=> 'Максімум спасылак у подпісы',
	'MAX_SIG_URLS_EXPLAIN'			=> 'Максімальная колькасць спасылак у подпісах карыстальнікаў. Увядзіце 0 для здымання абмежаванняў.',
));

// Registration Settings
$lang = array_merge($lang, array(
	'ACP_REGISTER_SETTINGS_EXPLAIN'		=> 'Тут вы можаце задаць налады, звязаныя з рэгістрацыяй карыстальнікаў.',

	'ACC_ACTIVATION'			=> 'Актывацыя ўліковых запісаў',
	'ACC_ACTIVATION_EXPLAIN'	=> 'Гэтая група настроек вызначае, ці могуць карыстальнікі мець доступ да канферэнцыі адразу пасля рэгістрацыі, або для гэтага патрабуецца пацверджанне рэгістрацыі. Таксама тут можна наогул адключыць рэгістрацыю.',
	'NEW_MEMBER_POST_LIMIT'				=> 'Ліміт паведамленняў для новых карыстальнікаў',
	'NEW_MEMBER_POST_LIMIT_EXPLAIN'		=> 'Зноў зарэгістраваныя карыстальнікі будуць знаходзіцца ў групе <em>Новыя карыстальнікі</em>, пакуль яны не апублікуюць названай тут колькасці паведамленняў. Вы можаце выкарыстоўваць гэтую групу, каб перашкодзіць новым карыстальнікам выкарыстоўваць сістэму асабістых паведамленняў, або для папярэдняга прагляду іх паведамленняў. Увядзіце 0, калі жадаеце адключыць гэтую магчымасць.',
	'NEW_MEMBER_GROUP_DEFAULT'			=> 'Ўсталяваць групу «Новыя карыстальнікі» як групу па змаўчанні',
	'NEW_MEMBER_GROUP_DEFAULT_EXPLAIN'	=> 'Пры ўключэнні гэтай опцыі і пры ўказаньні ліміту паведамленняў для новых карыстальнікаў усе зноў зарэгістраваныя карыстальнікі будуць не толькі ўваходзіць у групу «Новыя карыстальнікі», але гэтая група таксама будзе прызначаная ім у якасці групы па змоўчванні. Гэта можа быць зручна, напрыклад, калі вы жадаеце прызначыць на гэтую групу пэўнае званне або аватару, якія будуць успадкаваныя новымі карыстальнікамі.',

	'ACC_ADMIN'					=> 'Адміністратарам',
	'ACC_DISABLE'				=> 'Адключыць рэгістрацыю',
	'ACC_NONE'					=> 'Без актывацыі (неадкладны доступ)',
	'ACC_USER'					=> 'Карыстальнікам (email-пацверджанне)',
//	'ACC_USER_ADMIN'			=> 'User + Admin',
	'ALLOW_EMAIL_REUSE'			=> 'Дазволіць паўторнае выкарыстанне email-адрасы',
	'ALLOW_EMAIL_REUSE_EXPLAIN'	=> 'Розныя карыстальнікі змогуць рэгістравацца з аднолькавым email-адрасам.',
	'COPPA'						=> 'COPPA',
	'COPPA_FAX'					=> 'Нумар факса для COPPA',
	'COPPA_MAIL'				=> 'Паштовы адрас для COPPA',
	'COPPA_MAIL_EXPLAIN'		=> 'Паштовы адрас, на які бацькі павінны адпраўляць формы рэгістрацыі COPPA',
	'ENABLE_COPPA'				=> 'Уключыць COPPA',
	'ENABLE_COPPA_EXPLAIN'		=> 'Ад карыстальніка запатрабуецца пацвердзіць, ці дасягнуў ён узросту 13 гадоў або старэй, для адпаведнасці патрабаванням U.S. COPPA Act. Калі адключана, адмысловыя групы COPPA больш не будуць адлюстраваныя.',
	'MAX_CHARS'					=> 'макс.',
	'MIN_CHARS'					=> 'мін.',
	'NO_AUTH_PLUGIN'			=> 'Не знойдзена прыдатнага модуля аўтарызацыі.',
	'PASSWORD_LENGTH'			=> 'Даўжыня пароля',
	'PASSWORD_LENGTH_EXPLAIN'	=> 'Мінімальная і максімальная колькасць знакаў у паролях.',
	'REG_LIMIT'					=> 'Спробы рэгістрацыі',
	'REG_LIMIT_EXPLAIN'			=> 'Колькасць спроб вырашэння анты-спам задач, якое могуць зрабіць карыстальнікі на працягу адной сесіі.',
	'USERNAME_ALPHA_ONLY'		=> 'Толькі літарна-лічбавыя',
	'USERNAME_ALPHA_SPACERS'	=> 'Літарна-лічбавыя і падзельнікі',
	'USERNAME_ASCII'			=> 'ASCII (без міжнароднага юнікода)',
	'USERNAME_LETTER_NUM'		=> 'Любыя літары і лічбы',
	'USERNAME_LETTER_NUM_SPACERS'	=> 'Любыя літары, лічбы і падзельнікі',
	'USERNAME_CHARS'			=> 'Абмежаванні на знакі ў імі карыстальніка',
	'USERNAME_CHARS_ANY'		=> 'Любыя знакі',
	'USERNAME_CHARS_EXPLAIN'	=> 'Знакі, якія могуць быць скарыстаныя ў імёнах карыстальнікаў. Падзельнікамі лічацца знакі прабелу, -, +, _, [ і ]',
	'USERNAME_LENGTH'			=> 'Даўжыня імя карыстальніка',
	'USERNAME_LENGTH_EXPLAIN'	=> 'Мінімальная і максімальная колькасць знакаў у імёнах карыстальнікаў.',
));

// Feeds
$lang = array_merge($lang, array(
	'ACP_FEED_MANAGEMENT'				=> 'Агульныя параметры каналаў навін',
	'ACP_FEED_MANAGEMENT_EXPLAIN'		=> 'Дадзены модуль выдае розныя каналы навін у фармаце ATOM, апрацоўваючы BBCode у паведамленнях, і робячы іх чытабельнымі для знешніх праграм чытання каналаў навін.',

	'ACP_FEED_GENERAL' => 'Агульныя наладкі каналаў навін',
	'ACP_FEED_POST_BASED' => 'Наладкі каналаў паведамленняў',
	'ACP_FEED_TOPIC_BASED' => 'Наладкі каналаў тэм',
	'ACP_FEED_SETTINGS_OTHER' => 'Іншыя наладкі каналаў навін',

	'ACP_FEED_ENABLE'					=> 'Дазволіць каналы навін',
	'ACP_FEED_ENABLE_EXPLAIN'			=> 'Уключэнне або адключэнне каналаў навін для ўсёй канферэнцыі. Пры адключэнні гэтай опцыі будуць адключаныя ўсе каналы навін, незалежна ад названых ніжэй параметраў.',
	'ACP_FEED_LIMIT'					=> 'Колькасць элементаў',
	'ACP_FEED_LIMIT_EXPLAIN'			=> 'Максімальная колькасць элементаў канала навін для адлюстравання.',

	'ACP_FEED_OVERALL' => 'Уключыць агульны канал навін', 
	'ACP_FEED_OVERALL_EXPLAIN' => 'Новыя паведамленні канферэнцыі.', 
	'ACP_FEED_FORUM' => 'Дазволіць каналы форумаў', 
	'ACP_FEED_FORUM_EXPLAIN' => 'Новыя паведамленні асобных форумаў.', 
	'ACP_FEED_TOPIC' => 'Дазволіць каналы тэм', 
	'ACP_FEED_TOPIC_EXPLAIN' => 'Новыя паведамленні асобных тэм.', 

	'ACP_FEED_TOPICS_NEW' => 'Дазволіць канал новых тэм', 
	'ACP_FEED_TOPICS_NEW_EXPLAIN' => 'Уключае канал «Новыя тэмы», які дазваляе атрымліваць інфармацыю аб новых тэмах, з тэкстам першага паведамлення.', 
	'ACP_FEED_TOPICS_ACTIVE' => 'Дазволіць канал актыўных тым', 
	'ACP_FEED_TOPICS_ACTIVE_EXPLAIN' => 'Уключае канал Актыўныя тэмы », які дазваляе атрымліваць новыя актыўныя тэмы, з тэкстам апошняга паведамлення.', 
	'ACP_FEED_NEWS' => 'Канал навін', 
	'ACP_FEED_NEWS_EXPLAIN' => 'Першыя паведамленні новых тэм названых форумаў. Не выбірайце форумаў, каб адключыць канал навін. <br /> Каб выбраць некалькі форумаў, карыстайцеся мышшу, утрымліваючы кнопку <samp>CTRL</samp>.', 

	'ACP_FEED_OVERALL_FORUMS' => 'Дазволіць канал форумаў', 
	'ACP_FEED_OVERALL_FORUMS_EXPLAIN' => 'Уключае канал «Усе форумы», які дазваляе атрымаць спіс форумаў.',

	'ACP_FEED_HTTP_AUTH' => 'Дазволіць HTTP ідэнтыфікацыю',
	'ACP_FEED_HTTP_AUTH_EXPLAIN' => 'Уключае ідэнтыфікацыю праз HTTP, якая дазваляе карыстальнікам атрымліваць інфармацыю, недаступную для гасцей, з дабаўленнем параметра <samp>auth=http</samp> у адрасны радок канала навін. Майце на ўвазе, што для працы дадзенай функцыі на некаторых серверах можа запатрабавацца ўнясенне дадатковых змяненняў у файл .htaccess.',
	'ACP_FEED_ITEM_STATISTICS'			=> 'Статыстыка элементаў',
	'ACP_FEED_ITEM_STATISTICS_EXPLAIN'	=> 'Адлюстраванне індывідуальнай статыстыкі пад элементамі канала (аўтар паведамлення, дата і час публікацыі, колькасць адказаў і праглядаў).',
	'ACP_FEED_EXCLUDE_ID'				=> 'Выключыць гэтыя форумы',
	'ACP_FEED_EXCLUDE_ID_EXPLAIN'		=> 'Паведамленні з наступных форумаў не будуць уключацца ў каналы навін. Не выбірайце форумаў, калі жадаеце атрымліваць дадзеныя з усіх форумаў. Абярыце некалькі форумаў, утрымліваючы клавішу <samp>Ctrl</samp> і клікая мышшу па патрэбных форумах.',
));

// Visual Confirmation Settings
$lang = array_merge($lang, array(
	'ACP_VC_SETTINGS_EXPLAIN'				=> 'Тут вы можаце выбраць і настроіць анты-спам модулі, якія рэалізуюць розныя спосабы прадухілення аўтаматызаваных рэгістрацый. Гэтыя сродкі звычайна выкарыстоўваюць праверку карыстальніка з дапамогай <em>CAPTCHA</em> - спецыяльнага тэсту, які складзены для аўтаматычнага распазнавання.',
	'AVAILABLE_CAPTCHAS'					=> 'Даступныя модулі',
	'CAPTCHA_UNAVAILABLE'					=> 'Дадзены модуль не можа быць выбраны, паколькі патрабаванні для яго выкарыстання не выкананыя.',
	'CAPTCHA_GD'							=> 'GD выява',
	'CAPTCHA_GD_3D'							=> 'GD 3D выява',
	'CAPTCHA_GD_FOREGROUND_NOISE'			=> 'Шум на пярэднім плане',
	'CAPTCHA_GD_EXPLAIN'					=> 'Выкарыстаць бібліятэку GD для стварэння ўдасканаленай анты-спам выявы.',
	'CAPTCHA_GD_FOREGROUND_NOISE_EXPLAIN'	=> 'Выкарыстаць шум для стварэння ўскладненай для чытання выявы.',
	'CAPTCHA_GD_X_GRID'						=> 'Фонавы шум па восі X',
	'CAPTCHA_GD_X_GRID_EXPLAIN'				=> 'Выкарыстайце меншае значэнне для стварэння больш складанай анты-спам выявы. Увядзіце 0 для адключэння стварэння шуму па восі X.',
	'CAPTCHA_GD_Y_GRID'						=> 'Фонавы шум па восі Y',
	'CAPTCHA_GD_Y_GRID_EXPLAIN'				=> 'Выкарыстайце меншае значэнне для стварэння больш складанай анты-спам выявы. Увядзіце 0 для адключэння стварэння шуму па восі Y.',
	'CAPTCHA_GD_WAVE'						=> 'Хвалевае скажэнне',
	'CAPTCHA_GD_WAVE_EXPLAIN'				=> 'Выкарыстаць хвалевае скажэнне для выявы.',
	'CAPTCHA_GD_3D_NOISE'					=> 'Дадаць 3D-шум',
	'CAPTCHA_GD_3D_NOISE_EXPLAIN'			=> 'Опцыя дадае да выявы дадатковыя аб\'екты над сімваламі.',
	'CAPTCHA_GD_FONTS'						=> 'Выкарыстаць іншыя шрыфты',
	'CAPTCHA_GD_FONTS_EXPLAIN'				=> 'Дазваляе кіраваць колькасцю выкарыстоўваных форм для адлюстравання знакаў. Вы можаце выкарыстаць формы па змаўчанні або дадаць змененыя знакі. Таксама магчыма даданне знакаў у ніжнім рэгістры.',
	'CAPTCHA_FONT_DEFAULT'					=> 'Па змаўчанні',
	'CAPTCHA_FONT_NEW'						=> 'Новыя формы',
	'CAPTCHA_FONT_LOWER'					=> 'Таксама выкарыстаць ніжні рэгістр',
	'CAPTCHA_NO_GD'							=> 'Простая выява',
	'CAPTCHA_PREVIEW_MSG'					=> 'Гэта проста папярэдні прагляд. Змены ў настройках візуальнага пацверджання яшчэ не былі захаваныя.',
	'CAPTCHA_PREVIEW_EXPLAIN'				=> 'Тут паказваецца, як будзе выглядаць анты-спам выява пры выкарыстанні дзеючых настроек.',
	
	'CAPTCHA_SELECT'						=> 'Устаноўленыя модулі',
	'CAPTCHA_SELECT_EXPLAIN'				=> 'У гэтым спісе ўтрымліваюцца модулі, распазнаныя вашай канферэнцыяй. Модулі, пазначаныя шэрым колерам, магчыма, маюць патрэбу ў папярэдняй наладцы, і таму недаступныя для выкарыстання ў цяперашні час.',
	'CAPTCHA_CONFIGURE'						=> 'Налады модуляў',
	'CAPTCHA_CONFIGURE_EXPLAIN'				=> 'Змяненне наладаў абранага анты-спам модуля.',
	'CONFIGURE'								=> 'Налады',
	'CAPTCHA_NO_OPTIONS'					=> 'Дадзены анты-спам модуль не мае наладаў.',

	'VISUAL_CONFIRM_POST'					=> 'Анты-спам пацверджанне для госцяў',
	'VISUAL_CONFIRM_POST_EXPLAIN'			=> 'Для прадухілення масавай адпраўкі паведамленняў ананімныя карыстальнікі пры размяшчэнні паведамленняў павінны будуць прайсці анты-спам тэст.',
	'VISUAL_CONFIRM_REG'					=> 'Анты-спам пацверджанне пры рэгістрацыі',
	'VISUAL_CONFIRM_REG_EXPLAIN'			=> 'Для прадухілення аўтаматычных рэгістрацый новыя карыстальнікі пры рэгістрацыі павінны будуць прайсці анты-спам тэст.',
	'VISUAL_CONFIRM_REFRESH'				=> 'Дазволіць карыстальнікам абнаўляць анты-спам тэст',
	'VISUAL_CONFIRM_REFRESH_EXPLAIN'		=> 'Дазваляе карыстальнікам запытваць новы анты-спам тэст, калі яны не змаглі яго прачытаць пры рэгістрацыі.',
));

// Cookie Settings
$lang = array_merge($lang, array(
	'ACP_COOKIE_SETTINGS_EXPLAIN'		=> 'Тут вы можаце змяніць налады cookies, якія адпраўляюцца ў браўзэры карыстальнікаў. У большасці выпадкаў досыць наладаў па змаўчанні. Калі вам усё жа трэба змяніць налады, то рабіце гэта асцярожна — няслушныя значэнні могуць прывесці да немагчымасці ўваходу карыстальнікаў на канферэнцыю.',

	'COOKIE_DOMAIN'				=> 'Дамен cookie',
	'COOKIE_NAME'				=> 'Імя cookie',
	'COOKIE_PATH'				=> 'Шлях cookie',
	'COOKIE_SECURE'				=> 'Бяспечныя cookie [ https ]',
	'COOKIE_SECURE_EXPLAIN'		=> 'Калі ваш сервер працуе праз SSL, то ўключыце гэты параметр. У адваротным выпадку пакіньце выключаным. Уключэнне гэтага параметру, калі сервер працуе не праз SSL, прывядзе да памылак пры пераходах па старонках канферэнцыі і пры пераадрасаванні.',
	'ONLINE_LENGTH'				=> 'Часавы дыяпазон анлайн статыстыкі',
	'ONLINE_LENGTH_EXPLAIN'		=> 'Колькасць хвілін, па сканчэнні якіх неактыўныя карыстальнікі перастануць быць бачнымі ў спісе «Хто зараз на канферэнцыі». Павелічэнне гэтага значэння падвышае выдатак рэсурсаў сервера на стварэнне спісу.',
	'SESSION_LENGTH'			=> 'Працягласць сесіі',
	'SESSION_LENGTH_EXPLAIN'	=> 'Сесія будзе завершаная па сканчэнні паказанага часу ў секундах.',
));

// Load Settings
$lang = array_merge($lang, array(
	'ACP_LOAD_SETTINGS_EXPLAIN'	=> 'Тут вы можаце ўключаць і адключаць некаторыя функцыі канферэнцыі для паніжэння нагрузкі на сервер. Для большасці сервераў няма неабходнасці адключаць якія-небудзь функцыі. Тым не менш, на некаторых сістэмах або калектыўных хостынгах можа быць карысным адключэнне магчымасцяў, якія вам не патрабуюцца. Вы можаце таксама задаць абмежаванні для нагрузкі на сервер і актыўных сесій, пры перавышэнні якіх канферэнцыя будзе адключаная.',

	'CUSTOM_PROFILE_FIELDS'			=> 'Дадатковыя палі ў профілях',
	'LIMIT_LOAD'					=> 'Абмежаваць нагрузку на сервер',
	'LIMIT_LOAD_EXPLAIN'			=> 'Калі сярэдняя штохвілінная нагрузка на сервер перавышае зададзенае значэнне, канферэнцыя будзе аўтаматычна адключаная. Значэнне, роўнае 1.0, азначае ~100% выкарыстанне рэсурсаў аднаго працэсара. Гэтая магчымасць дастасавальная толькі для сервераў на аснове UNIX. Значэнне будзе скінута ў 0, калі phpBB не зможа атрымаць мяжу загрузкі сістэмы.',
	'LIMIT_SESSIONS'				=> 'Абмежаваць сесіі',
	'LIMIT_SESSIONS_EXPLAIN'		=> 'Калі колькасць сесій перавышае зададзенае значэнне на працягу адной хвіліны, канферэнцыя будзе аўтаматычна адключаная. Увядзіце 0 для здымання абмежаванняў.',
	'LOAD_CPF_MEMBERLIST'			=> 'Дазволіць адлюстраванне дадатковых палёў профіля ў спісе карыстальнікаў',
	'LOAD_CPF_VIEWPROFILE'			=> 'Паказваць дадатковыя палі ў профілях карыстальнікаў',
	'LOAD_CPF_VIEWTOPIC'			=> 'Паказваць дадатковыя палі на старонках тэм',
	'LOAD_USER_ACTIVITY'			=> 'Паказаць актыўнасць карыстальніка',
	'LOAD_USER_ACTIVITY_EXPLAIN'	=> 'Адлюстраванне тэмы/форума, у якіх карыстальнік найболей актыўны, у яго профілі і асабістым раздзеле. Рэкамендуецца адключыць гэтую функцыю на канферэнцыях з больш за адным мільёнам паведамленняў.',
	'RECOMPILE_STYLES'				=> 'Перакампіляваць старыя шаблоны',
	'RECOMPILE_STYLES_EXPLAIN'		=> 'Праверка абноўленых кампанентаў стыляў і паўторная іх кампіляцыя ў выпадку неабходнасці.',
	'YES_ANON_READ_MARKING'			=> 'Уключыць маркіроўку тэм для госцяў',
	'YES_ANON_READ_MARKING_EXPLAIN'	=> 'Захоўваць інфармацыю аб статуце «прачытана/не прачытана» для госцяў. Калі адключана, паведамленні для госцяў заўсёды пазначаныя як прачытаныя.',
	'YES_BIRTHDAYS'					=> 'Уключыць спіс дзён нараджэння',
	'YES_BIRTHDAYS_EXPLAIN'			=> 'Калі спіс дзён нараджэння адключаны, ён не будзе адлюстроўвацца. Для таго, каб гэтая налада працавала, павінна быць таксама ўключаная функцыя дзён нараджэння.',
	'YES_JUMPBOX'					=> 'Уключыць адлюстраванне хуткага пераходу',
	'YES_MODERATORS'				=> 'Уключыць адлюстраванне мадэратараў',
	'YES_ONLINE'					=> 'Уключыць інфармацыю аб актыўных карыстальніках',
	'YES_ONLINE_EXPLAIN'			=> 'Адлюстроўваць інфармацыю аб актыўных карыстальніках на галоўнай старонцы, пры праглядзе форумаў і тэм.',
	'YES_ONLINE_GUESTS'				=> 'Уключыць адлюстраванне госцяў у спісах актыўных карыстальнікаў',
	'YES_ONLINE_GUESTS_EXPLAIN'		=> 'Дазволіць адлюстраванне інфармацыі аб гасцях пры праглядзе «Хто зараз на канферэнцыі».',
	'YES_ONLINE_TRACK'				=> 'Уключыць адлюстраванне інфармацыі аб карыстальніку «у сеткі/не ў сеткі»',
	'YES_ONLINE_TRACK_EXPLAIN'		=> 'Адлюстроўваць інфармацыю аб знаходжанні карыстальніка ў сеткі ў профілях і пры праглядзе тэм.',
	'YES_POST_MARKING'				=> 'Уключыць свае тэмы',
	'YES_POST_MARKING_EXPLAIN'		=> 'Паказваць, ці пакідаў карыстальнік паведамлення ў тэме.',
	'YES_READ_MARKING'				=> 'Уключыць маркіроўку тэм на серверы',
	'YES_READ_MARKING_EXPLAIN'		=> 'Захоўваць інфармацыю аб статуце «прачытана/не прачытана» у базе дадзеных, а не ў cookies.',
	'YES_UNREAD_SEARCH'				=> 'Уключыць пошук па непрачытаных паведамленнях',
));

// Auth settings
$lang = array_merge($lang, array(
	'ACP_AUTH_SETTINGS_EXPLAIN'	=> 'phpBB падтрымлівае пашырэнні аўтэнтыфікацыі, або модулі. Яны дазваляюць вам усталяваць спосаб аўтэнтыфікацыі карыстальнікаў пры іх уваходзе на канферэнцыю. Па змаўчанні даступныя тры модуля: DB, LDAP і Apache. Не ўсе метады патрабуюць дадатковай інфармацыі, таму запаўняйце толькі тыя палі, якія неабходныя для вылучанага метаду.',

	'AUTH_METHOD'				=> 'Вылучыць метад аўтэнтыфікацыі',

	'APACHE_SETUP_BEFORE_USE'	=> 'Неабходна наладзіць ідэнтыфікацыі Apache пры пераключэньні phpBB на гэты метад ідэнтыфікацыі. Памятайце, што імя карыстальніка для ідэнтыфікацыі ў Apache павінна супадаць з вашым імем карыстальніка ў phpBB. Аўтэнтыфікацыя Apache можа выкарыстоўвацца толькі з mod_php (не з версіяй CGI) і з адключаным safe_mode.',

	'LDAP_DN'						=> 'Асноўнае імя LDAP [ <var>dn</var> ]',
	'LDAP_DN_EXPLAIN'				=> 'Унікальнае імя (Distinguished Name), якое вызначае інфармацыю аб карыстальніку, напрыклад <samp>o=My Company,c=US</samp>',
	'LDAP_EMAIL'					=> 'Email-атрыбут LDAP',
	'LDAP_EMAIL_EXPLAIN'			=> 'Задайце імя атрыбуту email карыстальніка (калі ён існуе) для аўтаматычнага прысваення email-адрасоў новым карыстальнікам. Калі гэтае поле пакінуць пустым, то email-адрасы карыстальнікаў, якія ўпершыню ўвайшлі на канферэнцыю, таксама будуць пустымі.',
	'LDAP_INCORRECT_USER_PASSWORD'	=> 'Спроба сувязі з серверам LDAP з паказаным імем або паролем не атрымалася.',
	'LDAP_NO_EMAIL'					=> 'Паказаны атрыбут email не існуе.',
	'LDAP_NO_IDENTITY'				=> 'Не атрымалася знайсці ідэнтыфікатар уваходу ў сістэму для %s.',
	'LDAP_PASSWORD'					=> 'Пароль LDAP',
	'LDAP_PASSWORD_EXPLAIN'			=> 'Пакіньце поле пустым для выкарыстання ананімнага злучэння. У адваротным выпадку ўвядзіце пароль для вышэйпаказанага карыстальніка. Патрабуецца для сервераў Active Directory. <strong>Увага:</strong> гэты пароль будзе захаваны ў базе дадзеных у незашыфраваным выглядзе, і будзе бачны ўсім, хто мае доступ да яе або да гэтай старонкі налад.',
	'LDAP_PORT'						=> 'Порт сервера LDAP',
	'LDAP_PORT_EXPLAIN'				=> 'Вы можаце паказаць порт, які павінен выкарыстоўвацца для злучэння з серверам LDAP замест порта па змаўчанні 389.',
	'LDAP_SERVER'					=> 'Імя сервера LDAP',
	'LDAP_SERVER_EXPLAIN'			=> 'Калі выкарыстоўваецца LDAP, пакажыце хост або IP-адрас сервера LDAP. Акрамя гэтага, вы можаце паказаць спасылку. Напрыклад, ldap://hostname:port/',
	'LDAP_UID'						=> 'Ідэнтыфікацыйны нумар LDAP [ <var>uid</var> ]',
	'LDAP_UID_EXPLAIN'				=> 'Гэта ключ, з дапамогай якога вырабляецца пошук зададзенага ідэнтыфікатара ўваходу ў сістэму. Напрыклад, <var>uid</var>, <var>sn</var>, і г.д.',
	'LDAP_USER'						=> 'Карыстальнік LDAP [ <var>dn</var> ]',
	'LDAP_USER_EXPLAIN'				=> 'Пакіньце поле пустым для выкарыстання ананімнага злучэння. Калі поле запоўнена, phpBB выкарыстае паказанае імя пры злучэнні з серверам LDAP для пошуку правільнага карыстальніка. Напрыклад, <samp>uid=Username,ou=MyUnit,o=MyCompany,c=US</samp>. Патрабуецца для сервераў Active Directory.',
	'LDAP_USER_FILTER'				=> 'Фільтр імя карыстальніка LDAP',
	'LDAP_USER_FILTER_EXPLAIN'		=> 'У далейшым вы можаце абмежаваць дыяпазон шуканых аб\'ектаў з дапамогай дадатковых фільтраў. Напрыклад, вынікам <samp>objectClass=posixGroup</samp> будзе <samp>(&(uid=$username)(objectClass=posixGroup))</samp>',
));

// Server Settings
$lang = array_merge($lang, array(
	'ACP_SERVER_SETTINGS_EXPLAIN'	=> 'Тут задаюцца налады, звязаныя з серверам і даменам. Пераканайцеся ў дакладнасці паказаных вамі дадзеных, памылкі прывядуць да рассылання email-паведамленняў, якія змяшчаюць няслушную інфармацыю. Задаючы імя дамена, падушыце, што яно павінна ўключаць  http:// або прэфікс іншага пратаколу. Змяняйце нумар порта толькі ў выпадку, калі вам сапраўды вядома, што сервер выкарыстае іншае значэнне, порт 80 падыходзіць у большасці выпадкаў.',

	'ENABLE_GZIP'				=> 'Уключыць сціск GZip',
	'ENABLE_GZIP_EXPLAIN'		=> 'Генеруемае змесціва будзе сціскацца з дапамогай GZip перад адпраўкай карыстальніку. Уключэнне гэтай опцыі дапамагае паменшыць выдатак сеткавага трафіку, але ў той жа час некалькі павялічвае выкарыстанне цэнтральнага працэсара, як на боку кліента, так і на серверы. Патрабуецца пашырэнне PHP zlib.',
	'FORCE_SERVER_VARS'			=> 'Прымусовыя налады URL сервера',
	'FORCE_SERVER_VARS_EXPLAIN'	=> 'Калі вылучана, то паказаныя тут налады будуць скарыстаныя замест аўтаматычна вызначаных значэнняў',
	'ICONS_PATH'				=> 'Шлях да значкоў паведамленняў',
	'ICONS_PATH_EXPLAIN'		=> 'Шлях адносна каранёвай папкі phpBB. Напрыклад, <samp>images/icons</samp>.',
	'PATH_SETTINGS'				=> 'Параметры шляхоў',
	'RANKS_PATH'				=> 'Шлях да малюначкаў званняў',
	'RANKS_PATH_EXPLAIN'		=> 'Шлях адносна каранёвай папкі phpBB. Напрыклад, <samp>images/ranks</samp>.',
	'SCRIPT_PATH'				=> 'Шлях да канферэнцыі',
	'SCRIPT_PATH_EXPLAIN'		=> 'Шлях да папкі, якая змяшчае phpBB, адносна імя дамена. Напрыклад, <samp>/phpBB3</samp>.',
	'SERVER_NAME'				=> 'Імя дамена',
	'SERVER_NAME_EXPLAIN'		=> 'Імя дамена, на якім працуе канферэнцыя. Напрыклад <samp>www.example.com</samp>.',
	'SERVER_PORT'				=> 'Порт сервера',
	'SERVER_PORT_EXPLAIN'		=> 'Порт, на якім запушчаны сервер, звычайна гэта порт 80, змяняйце толькі ў выпадку, калі сервер выкарыстае іншы порт.',
	'SERVER_PROTOCOL'			=> 'Пратакол сервера',
	'SERVER_PROTOCOL_EXPLAIN'	=> 'Выкарыстоўваецца ў якасці пратаколу сервера, калі гэтыя налады ўключаныя прымусова. Калі не зададзена або не ўключана прымусова, пратакол будзе вызначаны па наладах бяспечных cookie (<samp>http://</samp> або <samp>https://</samp>)',
	'SERVER_URL_SETTINGS'		=> 'Налады URL сервера',
	'SMILIES_PATH'				=> 'Шлях да смайлікаў',
	'SMILIES_PATH_EXPLAIN'		=> 'Шлях адносна каранёвай папкі phpBB. Напрыклад, <samp>images/smilies</samp>.',
	'UPLOAD_ICONS_PATH'			=> 'Шлях да значкоў груп пашырэнняў',
	'UPLOAD_ICONS_PATH_EXPLAIN'	=> 'Шлях адносна каранёвай папкі phpBB. Напрыклад, <samp>images/upload_icons</samp>.',
));

// Security Settings
$lang = array_merge($lang, array(
	'ACP_SECURITY_SETTINGS_EXPLAIN'		=> 'Тут вы можаце задаць усталёўкі, звязаныя з сесіяй і ўваходам карыстальнікаў на канферэнцыю.',

	'ALL'							=> 'Поўная',
	'ALLOW_AUTOLOGIN'				=> 'Дазволіць аўтаматычны ўваход на канферэнцыю',
	'ALLOW_AUTOLOGIN_EXPLAIN'		=> 'Опцыя вызначае, ці могуць карыстальнікі аўтаматычна ўваходзіць на канферэнцыю пры ёй чарговым наведванні.',
	'AUTOLOGIN_LENGTH'				=> 'Час дзеяння аўтаматычнага ўваходу (дзён)',
	'AUTOLOGIN_LENGTH_EXPLAIN'		=> 'Колькасць дзён, на працягу якога карыстальнік можа аўтаматычна ўваходзіць на канферэнцыю. Увядзіце 0 для здымання абмежаванняў.',
	'BROWSER_VALID'					=> 'Праверка браўзэра',
	'BROWSER_VALID_EXPLAIN'			=> 'Уключае праверку браўзэра пры кожнай сесіі для падвышэння бяспекі.',
	'CHECK_DNSBL'					=> 'Праверыць IP-адрас па чорным спісе DNS (DNS Blackhole List)',
	'CHECK_DNSBL_EXPLAIN'			=> 'Калі ўключана, IP-адрас карыстальніка будзе правераны з дапамогай наступных служб  DNSBL пры рэгістрацыі або адпраўцы паведамленняў: <a href="http://spamcop.net">spamcop.net</a>, <a href="http://dsbl.org">dsbl.org</a> і <a href="http://www.spamhaus.org">www.spamhaus.org</a>. Гэтая працэдура можа заняць некаторы час, у залежнасці ад канфігурацыі сервера. У выпадку запаволення працы сервера або вялікай колькасці ілжывых спрацоўванняў рэкамендуецца адключыць гэтую праверку.',
	'CLASS_B'						=> 'A.B',
	'CLASS_C'						=> 'A.B.C',
	'EMAIL_CHECK_MX'				=> 'Праверыць правільнасць паштовага запісу ў DNS (MX Record) дамена email-адрасы',
	'EMAIL_CHECK_MX_EXPLAIN'		=> 'Калі ўключана, дамен email-адрасы, паказаны пры рэгістрацыі або змене профіля, правяраецца на правільнасць  паштовага запісу ў DNS (MX Record).',
	'FORCE_PASS_CHANGE'				=> 'Прымусовая змена пароля',
	'FORCE_PASS_CHANGE_EXPLAIN'		=> 'Карыстальнік павінен будзе змяніць свой пароль па сканчэнні паказанай колькасці дзён. Увядзіце 0 для адключэння гэтай функцыі.',
	'FORM_TIME_MAX'					=> 'Максімальны час для адпраўкі формы',
	'FORM_TIME_MAX_EXPLAIN'			=> 'Час, за якое карыстальнік павінен адправіць форму. Усталюеце -1 для адключэння гэтай функцыі. Улічыце, што форма можа састарэць па заканчэнні сесіі, незалежна ад дадзенай налады.',
	'FORM_SID_GUESTS'				=> 'Прывязаць формы да гасцёўняў сесіям',
	'FORM_SID_GUESTS_EXPLAIN'		=> 'Калі ўключана, формы, якія адпраўляюцца гасцямі, будуць прывязаныя да пэўных сесій. Гэта можа выклікаць праблемы з некаторымі Інтэрнэт-правайдэрамі.',
	'FORWARDED_FOR_VALID'			=> 'Праверка загалоўка <var>X_FORWARDED_FOR</var>',
	'FORWARDED_FOR_VALID_EXPLAIN'	=> 'Сесія будзе працягнутая толькі ў тым выпадку, калі адпраўлены загаловак <var>X_FORWARDED_FOR</var> адпавядае адпраўленаму ў папярэднім запыце. Блакоўка доступу па IP-адрасу будзе здзяйсняцца па IP-адрасам з загалоўка <var>X_FORWARDED_FOR</var>.',
	'IP_VALID'						=> 'Праверка IP-адрасы сесіі',
	'IP_VALID_EXPLAIN'				=> 'Вызначае, якая частка IP-адрасы карыстальніка выкарыстоўваецца для праверкі сесіі. <samp>Поўная</samp> азначае праверку ўсяго адрасу, <samp>A.B.C</samp> — першых трох лікаў (x.x.x), <samp>A.B</samp> — першых двух лікаў (x.x), <samp>Не</samp> адключае праверку. У адрасах IPv6 <samp>A.B.C</samp> параўноўвае першыя 4 блока і <samp>A.B</samp> — першыя 3 блока.',
	'IP_LOGIN_LIMIT_MAX'			=> 'Максімальная колькасць спробаў ўваходу для аднаго IP адраса',
	'IP_LOGIN_LIMIT_MAX_EXPLAIN'	=> 'Парог дазволенага ліку спроб уваходу з аднаго IP адраса да ўключэння задання супраць спам-ботаў. Увядзіце 0 для адключэння гэтай функцыі.',
	'IP_LOGIN_LIMIT_TIME'			=> 'Час дзеяння для спробаў ўваходу з IP адраса',
	'IP_LOGIN_LIMIT_TIME_EXPLAIN'	=> 'Інфармацыя аб спробах ўваходу будзе скасавана па сканчэнні ўказанага часу.',
	'IP_LOGIN_LIMIT_USE_FORWARDED'	=> 'Абмежаваць колькасць спробаў уваходу па загалоўку <var>X_FORWARDED_FOR</var>',
	'IP_LOGIN_LIMIT_USE_FORWARDED_EXPLAIN'	=> 'Замест абмежавання колькасці спробаў ўваходу па IP адрасу, абмежаванне будзе вырабляцца па значэннях адрасу ў загалоўку <var>X_FORWARDED_FOR</var>.<br /><em><strong>Увага:</strong> Уключайце дадзеную функцыю толькі ў выпадку, калі выкарыстоўваецца проксі-сервер, які ўсталёўвае пэўныя значэння загалоўка <var>X_FORWARDED_FOR</var>.</em>',
	'MAX_LOGIN_ATTEMPTS'			=> 'Максімальная колькасць спробаў уваходу',
	'MAX_LOGIN_ATTEMPTS_EXPLAIN'	=> 'Парог дазволенай колькасці спробаў ўваходу для адной ўліковага запісу да ўключэння задання супраць спам-ботаў. Увядзіце 0 для адключэння гэтай функцыі.',
	'NO_IP_VALIDATION'				=> 'Не',
	'NO_REF_VALIDATION'				=> 'Не',
	'PASSWORD_TYPE'					=> 'Складанасць пароля',
	'PASSWORD_TYPE_EXPLAIN'			=> 'Вызначае, наколькі складаным павінен быць пароль пры ім усталёўцы або змене. Кожны наступны варыянт абмежавання ўключае ў сябе папярэднія.',
	'PASS_TYPE_ALPHA'				=> 'Павінен утрымоўваць літарна-лічбавыя знакі',
	'PASS_TYPE_ANY'					=> 'Патрабаванні адсутнічаюць',
	'PASS_TYPE_CASE'				=> 'Павінен утрымоўваць знакі рознага рэгістра',
	'PASS_TYPE_SYMBOL'				=> 'Павінен утрымоўваць знакі',
	'REF_HOST'						=> 'Правераць толькі хост',
	'REF_PATH'						=> 'Таксама правераць шлях',
	'REFERER_VALID'					=> 'Правераць рэферэр',
	'REFERER_VALID_EXPLAIN'			=> 'Калі ўключана, рэферэр POST запросаў будзе правераны на хост/шлях скрыпта. Гэта можа стварыць непремнасці на канферэнцыях, якія ўжываюць некалькі даменаў альбо знешнія лагіны.',
	'TPL_ALLOW_PHP'					=> 'Дазволіць php у шаблонах',
	'TPL_ALLOW_PHP_EXPLAIN'			=> 'Калі гэтая функцыя ўключаная, каманды <code>PHP</code> і <code>INCLUDEPHP</code> будуць распазнавацца і выконвацца ў шаблонах.',
));

// Email Settings
$lang = array_merge($lang, array(
	'ACP_EMAIL_SETTINGS_EXPLAIN'	=> 'Гэтая інфармацыя выкарыстоўваецца для адпраўкі канферэнцыяй email-паведамленняў карыстальнікам. Пераканайцеся ў правільнасці паказаных email-адрасоў, усе вернутыя або не дастаўленыя паведамленні будуць, верагодна, адпраўленыя на іх. Калі ваш сервер не забяспечвае выкарыстанне ўбудаванай (у PHP) службы email, вы можаце адпраўляць паведамленні напроста з выкарыстаннем SMTP. Для гэтага неабходны адрас прыдатнага сервера (калі трэба, спытаеце аб гэтым у правайдэра). Калі сервер патрабуе аўтэнтыфікацыі (і толькі ў гэтым выпадку), увядзіце неабходныя імя, пароль і метад аўтэнтыфікацыі.',

	'ADMIN_EMAIL'					=> 'Зваротны email-адрас',
	'ADMIN_EMAIL_EXPLAIN'			=> 'Гэты адрас будзе скарыстаны для звароту ўсіх email-паведамленняў, як email-адрас для тэхнічных кантактаў. Ён заўсёды будзе выкарыстоўвацца ў якасці адрасоў <samp>Return-Path</samp> і <samp>Sender</samp> у email-паведамленнях.',
	'BOARD_EMAIL_FORM'				=> 'Рассыланне email-паведамленняў праз канферэнцыю',
	'BOARD_EMAIL_FORM_EXPLAIN'		=> 'Карыстальнікі змогуць адпраўляць email-паведамленні праз канферэнцыю замест іх звычайнай адпраўкі.',
	'BOARD_HIDE_EMAILS'				=> 'Хаваць email-адрасы',
	'BOARD_HIDE_EMAILS_EXPLAIN'		=> 'Гэтая функцыя поўнасцю захоўвае ў таямніцы email-адрасы.',
	'CONTACT_EMAIL'					=> 'Кантактны email-адрас',
	'CONTACT_EMAIL_EXPLAIN'			=> 'Гэты адрас будзе выкарыстоўвацца пры кожнай неабходнасці кантакту, напрыклад, у выпадку спаму, памылак і т.п. Ён заўсёды будзе выкарыстоўвацца ў якасці адрасоў <samp>From</samp> і <samp>Reply-To</samp> у email-паведамленнях.',
	'EMAIL_FUNCTION_NAME'			=> 'Імя функцыі email',
	'EMAIL_FUNCTION_NAME_EXPLAIN'	=> 'Функцыя email, выкарыстоўваная для адпраўкі паведамленняў праз PHP.',
	'EMAIL_PACKAGE_SIZE'			=> 'Памер паштовага пакета',
	'EMAIL_PACKAGE_SIZE_EXPLAIN'	=> 'Максімальная колькасць email-паведамленняў, якія адпраўляюцца за адзін раз. Гэтая налада ўжываецца для ўнутранай чаргі паведамленняў; усталюеце 0 пры ўзнікненні праблем, звязаных з неадпраўленымі апавяшчэннямі па email.',
	'EMAIL_SIG'						=> 'Подпіс у email-паведамленні',
	'EMAIL_SIG_EXPLAIN'				=> 'Гэты тэкст будзе дададзены ва ўсё email-паведамленні, якія адпраўляюцца канферэнцыяй.',
	'ENABLE_EMAIL'					=> 'Уключыць email-паведамленні',
	'ENABLE_EMAIL_EXPLAIN'			=> 'Калі выключана, адпраўка любых email-паведамленняў з канферэнцыі вырабляцца не будзе. <em>Заўвага: дадзеная опцыя павінна быць уключаная, калі вы жадаеце задзейнічаць актывацыю ўліковага запісу адміністратарам або карыстальнікам. Пры адключэнні дадзенай опцыі варыянты актывацыі ўліковага запісу карыстальнікам або адміністратарам стануць недаступныя.</em>',
	'SMTP_AUTH_METHOD'				=> 'Метад аўтэнтыфікацыі для SMTP',
	'SMTP_AUTH_METHOD_EXPLAIN'		=> 'Выкарыстоўваецца толькі ў выпадку, калі зададзеныя імя/пароль. Спытаеце ў свайго правайдэра, калі не ўпэўненыя, які метад аўтэнтыфікацыі выкарыстаць.',
	'SMTP_CRAM_MD5'					=> 'CRAM-MD5',
	'SMTP_DIGEST_MD5'				=> 'DIGEST-MD5',
	'SMTP_LOGIN'					=> 'LOGIN',
	'SMTP_PASSWORD'					=> 'Пароль SMTP',
	'SMTP_PASSWORD_EXPLAIN'			=> 'Увядзіце пароль, калі SMTP патрабуе гэтага.<br /><em><strong> Увага:</strong> гэты пароль будзе захаваны ў базе дадзеных у незашыфраваным выглядзе і будзе бачны ўсім, хто мае доступ да яе або да гэтай старонкі налад.</em>',
	'SMTP_PLAIN'					=> 'PLAIN',
	'SMTP_POP_BEFORE_SMTP'			=> 'POP-BEFORE-SMTP',
	'SMTP_PORT'						=> 'Порт сервера SMTP',
	'SMTP_PORT_EXPLAIN'				=> 'Змяняйце порт толькі ў тым выпадку, калі вам сапраўды вядома, што сервер выкарыстае іншы порт.',
	'SMTP_SERVER'					=> 'Адрас сервера SMTP',
	'SMTP_SETTINGS'					=> 'Налады SMTP',
	'SMTP_USERNAME'					=> 'Імя карыстальніка SMTP',
	'SMTP_USERNAME_EXPLAIN'			=> 'Увядзіце імя толькі ў выпадку, калі сервер SMTP патрабуе гэтага.',
	'USE_SMTP'						=> 'Выкарыстаць SMTP для адпраўкі email-паведамленняў',
	'USE_SMTP_EXPLAIN'				=> 'Вылучыце «Так», калі жадаеце або павінны адпраўляць email-паведамленні праз сервер замест лакальнай функцыі mail.',
));

// Jabber settings
$lang = array_merge($lang, array(
	'ACP_JABBER_SETTINGS_EXPLAIN'	=> 'Тут вы можаце ўключыць і наладзіць выкарыстанне Jabber у якасці імгненных паведамленняў і апавяшчэнняў з канферэнцыі. Jabber — гэта пратакол з адчыненым зыходным кодам, і таму даступны для выкарыстання ўсімі жадаючымі. Некаторыя серверы Jabber маюць шлюзы і пратаколы перадачы, якія дазваляюць злучацца з карыстальнікамі іншых сетак. Не ўсе серверы падаюць усе выгляды пратаколаў перадачы, а змены ў пратаколах могуць перашкаджаць правільнай працы. Упэўніцеся ў тым, што вы ўвялі дадзеныя зарэгістраванага ўліковага запісу — phpBB будзе выкарыстаць гэтыя дадзеныя ў сваёй працы.',

	'JAB_ENABLE'				=> 'Уключыць Jabber',
	'JAB_ENABLE_EXPLAIN'		=> 'Уключэнне дазваліць выкарыстаць Jabber для адпраўкі імгненных паведамленняў і апавяшчэнняў.',
	'JAB_GTALK_NOTE'			=> 'GTalk не будзе працаваць, паколькі функцыя <samp>dns_get_record</samp> не знойдзеная. Дадзеная функцыя недаступная ў PHP4 і не рэалізаваная на платформах Windows. У цяперашні час функцыя таксама не працуе на сістэмах BSD, уключаючы Mac OS.',
	'JAB_PACKAGE_SIZE'			=> 'Памер пакета Jabber',
	'JAB_PACKAGE_SIZE_EXPLAIN'	=> 'Колькасць паведамленняў, якія адпраўляюцца ў адным пакеце. Калі ўвесці 0, то паведамленні будуць адпраўляцца неадкладна без пастаноўкі ў чаргу для наступнай адпраўкі.',
	'JAB_PASSWORD'				=> 'Пароль Jabber',
	'JAB_PASSWORD_EXPLAIN' 		=> '<em><strong>Увага:</strong> гэты пароль будзе захаваны ў базе дадзеных у незашыфраваным выглядзе і будзе бачны ўсім, хто мае доступ да яе або да гэтай старонцы наладаў.</em>',
	'JAB_PORT'					=> 'Порт Jabber',
	'JAB_PORT_EXPLAIN'			=> 'Пакіньце пустым, калі вам вядома, што выкарыстоўваецца порт, выдатны ад 5222',
	'JAB_SERVER'				=> 'Сервер Jabber',
	'JAB_SERVER_EXPLAIN'		=> 'Глядзіце спіс сервераў на %sjabber.org%s.',
	'JAB_SETTINGS_CHANGED'		=> 'Налады Jabber паспяхова змененыя.',
	'JAB_USE_SSL'				=> 'Выкарыстаць SSL для злучэння',
	'JAB_USE_SSL_EXPLAIN'		=> 'Пры ўключэнні опцыі будзе ажыццяўлена спроба ўстаноўкі бяспечнага злучэння. Порт Jabber будзе зменены на 5223, калі пазначаны порт 5222.',
	'JAB_USERNAME'				=> 'Імя карыстальніка Jabber',
	'JAB_USERNAME_EXPLAIN'		=> 'Увядзіце імя або існуючы JID (ідэнтыфікатар) зарэгістраванага карыстальніка. Праверка імя праводзіцца не будзе. Калі паказана толькі імя, то ваш JID (ідэнтыфікатар) будзе складзены з гэтага імя і паказанага вышэй імя сервера. У адваротным выпадку ўкажыце існуючы JID (ідэнтыфікатар), напрыклад, user@jabber.org.',
));

?>
